/****************************************************************************
** Meta object code from reading C++ file 'dquickiconimage_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/private/dquickiconimage_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickiconimage_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__DQuickIconImage_t {
    QByteArrayData data[30];
    char stringdata0[286];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickIconImage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickIconImage_t qt_meta_stringdata_Dtk__Quick__DQuickIconImage = {
    {
QT_MOC_LITERAL(0, 0, 27), // "Dtk::Quick::DQuickIconImage"
QT_MOC_LITERAL(1, 28, 11), // "nameChanged"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 12), // "stateChanged"
QT_MOC_LITERAL(4, 54, 11), // "modeChanged"
QT_MOC_LITERAL(5, 66, 12), // "colorChanged"
QT_MOC_LITERAL(6, 79, 21), // "fallbackSourceChanged"
QT_MOC_LITERAL(7, 101, 7), // "setName"
QT_MOC_LITERAL(8, 109, 4), // "name"
QT_MOC_LITERAL(9, 114, 8), // "setState"
QT_MOC_LITERAL(10, 123, 5), // "State"
QT_MOC_LITERAL(11, 129, 5), // "state"
QT_MOC_LITERAL(12, 135, 7), // "setMode"
QT_MOC_LITERAL(13, 143, 4), // "Mode"
QT_MOC_LITERAL(14, 148, 4), // "mode"
QT_MOC_LITERAL(15, 153, 8), // "setColor"
QT_MOC_LITERAL(16, 162, 5), // "color"
QT_MOC_LITERAL(17, 168, 17), // "setFallbackSource"
QT_MOC_LITERAL(18, 186, 9), // "newSource"
QT_MOC_LITERAL(19, 196, 8), // "setImage"
QT_MOC_LITERAL(20, 205, 3), // "img"
QT_MOC_LITERAL(21, 209, 14), // "maybeUpdateUrl"
QT_MOC_LITERAL(22, 224, 14), // "fallbackSource"
QT_MOC_LITERAL(23, 239, 7), // "Invalid"
QT_MOC_LITERAL(24, 247, 6), // "Normal"
QT_MOC_LITERAL(25, 254, 8), // "Disabled"
QT_MOC_LITERAL(26, 263, 6), // "Active"
QT_MOC_LITERAL(27, 270, 8), // "Selected"
QT_MOC_LITERAL(28, 279, 2), // "On"
QT_MOC_LITERAL(29, 282, 3) // "Off"

    },
    "Dtk::Quick::DQuickIconImage\0nameChanged\0"
    "\0stateChanged\0modeChanged\0colorChanged\0"
    "fallbackSourceChanged\0setName\0name\0"
    "setState\0State\0state\0setMode\0Mode\0"
    "mode\0setColor\0color\0setFallbackSource\0"
    "newSource\0setImage\0img\0maybeUpdateUrl\0"
    "fallbackSource\0Invalid\0Normal\0Disabled\0"
    "Active\0Selected\0On\0Off"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickIconImage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       5,   98, // properties
       2,  118, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,
       3,    0,   75,    2, 0x06 /* Public */,
       4,    0,   76,    2, 0x06 /* Public */,
       5,    0,   77,    2, 0x06 /* Public */,
       6,    0,   78,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   79,    2, 0x0a /* Public */,
       9,    1,   82,    2, 0x0a /* Public */,
      12,    1,   85,    2, 0x0a /* Public */,
      15,    1,   88,    2, 0x0a /* Public */,
      17,    1,   91,    2, 0x0a /* Public */,
      19,    1,   94,    2, 0x0a /* Public */,
      21,    0,   97,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, QMetaType::QColor,   16,
    QMetaType::Void, QMetaType::QUrl,   18,
    QMetaType::Void, QMetaType::QImage,   20,
    QMetaType::Void,

 // properties: name, type, flags
       8, QMetaType::QString, 0x00495903,
      14, 0x80000000 | 13, 0x0049590b,
      11, 0x80000000 | 10, 0x0049590b,
      16, QMetaType::QColor, 0x00495903,
      22, QMetaType::QUrl, 0x00495903,

 // properties: notify_signal_id
       0,
       2,
       1,
       3,
       4,

 // enums: name, alias, flags, count, data
      13,   13, 0x2,    5,  128,
      10,   10, 0x2,    2,  138,

 // enum data: key, value
      23, uint(Dtk::Quick::DQuickIconImage::Mode::Invalid),
      24, uint(Dtk::Quick::DQuickIconImage::Mode::Normal),
      25, uint(Dtk::Quick::DQuickIconImage::Mode::Disabled),
      26, uint(Dtk::Quick::DQuickIconImage::Mode::Active),
      27, uint(Dtk::Quick::DQuickIconImage::Mode::Selected),
      28, uint(Dtk::Quick::DQuickIconImage::State::On),
      29, uint(Dtk::Quick::DQuickIconImage::State::Off),

       0        // eod
};

void Dtk::Quick::DQuickIconImage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DQuickIconImage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->stateChanged(); break;
        case 2: _t->modeChanged(); break;
        case 3: _t->colorChanged(); break;
        case 4: _t->fallbackSourceChanged(); break;
        case 5: _t->setName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->setState((*reinterpret_cast< State(*)>(_a[1]))); break;
        case 7: _t->setMode((*reinterpret_cast< Mode(*)>(_a[1]))); break;
        case 8: _t->setColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 9: _t->setFallbackSource((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 10: _t->setImage((*reinterpret_cast< const QImage(*)>(_a[1]))); break;
        case 11: _t->d_func()->maybeUpdateUrl(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DQuickIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickIconImage::nameChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DQuickIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickIconImage::stateChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DQuickIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickIconImage::modeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DQuickIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickIconImage::colorChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DQuickIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickIconImage::fallbackSourceChanged)) {
                *result = 4;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DQuickIconImage *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast< Mode*>(_v) = _t->mode(); break;
        case 2: *reinterpret_cast< State*>(_v) = _t->state(); break;
        case 3: *reinterpret_cast< QColor*>(_v) = _t->color(); break;
        case 4: *reinterpret_cast< QUrl*>(_v) = _t->fallbackSource(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DQuickIconImage *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setMode(*reinterpret_cast< Mode*>(_v)); break;
        case 2: _t->setState(*reinterpret_cast< State*>(_v)); break;
        case 3: _t->setColor(*reinterpret_cast< QColor*>(_v)); break;
        case 4: _t->setFallbackSource(*reinterpret_cast< QUrl*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickIconImage::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickImage::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DQuickIconImage.data,
    qt_meta_data_Dtk__Quick__DQuickIconImage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::DQuickIconImage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickIconImage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DQuickIconImage.stringdata0))
        return static_cast<void*>(this);
    return QQuickImage::qt_metacast(_clname);
}

int Dtk::Quick::DQuickIconImage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickImage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickIconImage::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickIconImage::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickIconImage::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickIconImage::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickIconImage::fallbackSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
