/****************************************************************************
** Meta object code from reading C++ file 'dquickwaterprogressattribute_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/private/dquickwaterprogressattribute_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickwaterprogressattribute_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick17WaterPopAttributeE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::WaterPopAttribute::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick17WaterPopAttributeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::WaterPopAttribute",
        "QML.Element",
        "anonymous",
        "xSpeedChanged",
        "",
        "ySpeedChanged",
        "xChanged",
        "yChanged",
        "widthChanged",
        "heightChanged",
        "width",
        "height",
        "xSpeed",
        "ySpeed",
        "x",
        "y"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'xSpeedChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ySpeedChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'width'
        QtMocHelpers::PropertyData<qreal>(10, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'height'
        QtMocHelpers::PropertyData<qreal>(11, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'xSpeed'
        QtMocHelpers::PropertyData<qreal>(12, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'ySpeed'
        QtMocHelpers::PropertyData<qreal>(13, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'x'
        QtMocHelpers::PropertyData<qreal>(14, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2),
        // property 'y'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<WaterPopAttribute, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::WaterPopAttribute::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick17WaterPopAttributeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick17WaterPopAttributeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick17WaterPopAttributeE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::WaterPopAttribute::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WaterPopAttribute *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->xSpeedChanged(); break;
        case 1: _t->ySpeedChanged(); break;
        case 2: _t->xChanged(); break;
        case 3: _t->yChanged(); break;
        case 4: _t->widthChanged(); break;
        case 5: _t->heightChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WaterPopAttribute::*)()>(_a, &WaterPopAttribute::xSpeedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WaterPopAttribute::*)()>(_a, &WaterPopAttribute::ySpeedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WaterPopAttribute::*)()>(_a, &WaterPopAttribute::xChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WaterPopAttribute::*)()>(_a, &WaterPopAttribute::yChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WaterPopAttribute::*)()>(_a, &WaterPopAttribute::widthChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WaterPopAttribute::*)()>(_a, &WaterPopAttribute::heightChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->width(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->height(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->xSpeed(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->ySpeed(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->x(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->y(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 1: _t->setHeight(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setXSpeed(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setYSpeed(*reinterpret_cast<qreal*>(_v)); break;
        case 4: _t->setX(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setY(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::WaterPopAttribute::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::WaterPopAttribute::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick17WaterPopAttributeE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::WaterPopAttribute::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::WaterPopAttribute::xSpeedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::WaterPopAttribute::ySpeedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::WaterPopAttribute::xChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::WaterPopAttribute::yChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::WaterPopAttribute::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::WaterPopAttribute::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
namespace {
struct qt_meta_tag_ZN3Dtk5Quick28DQuickWaterProgressAttributeE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickWaterProgressAttribute::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick28DQuickWaterProgressAttributeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickWaterProgressAttribute",
        "QML.Element",
        "WaterProgressAttribute",
        "frontXOffsetChanged",
        "",
        "backXOffsetChanged",
        "popsChanged",
        "runningChanged",
        "waterProgressChanged",
        "imageWidthChanged",
        "imageHeightChanged",
        "frontXOffset",
        "backXOffset",
        "imageWidth",
        "imageHeight",
        "pops",
        "QQmlListProperty<Dtk::Quick::WaterPopAttribute>",
        "running",
        "waterProgress",
        "QQuickItem*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'frontXOffsetChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backXOffsetChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'popsChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'runningChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'waterProgressChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageWidthChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageHeightChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'frontXOffset'
        QtMocHelpers::PropertyData<qreal>(11, QMetaType::QReal, QMC::DefaultPropertyFlags, 0),
        // property 'backXOffset'
        QtMocHelpers::PropertyData<qreal>(12, QMetaType::QReal, QMC::DefaultPropertyFlags, 1),
        // property 'imageWidth'
        QtMocHelpers::PropertyData<qreal>(13, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'imageHeight'
        QtMocHelpers::PropertyData<qreal>(14, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'pops'
        QtMocHelpers::PropertyData<QQmlListProperty<Dtk::Quick::WaterPopAttribute>>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'running'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'waterProgress'
        QtMocHelpers::PropertyData<QQuickItem*>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DQuickWaterProgressAttribute, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickWaterProgressAttribute::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick28DQuickWaterProgressAttributeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick28DQuickWaterProgressAttributeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick28DQuickWaterProgressAttributeE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickWaterProgressAttribute::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickWaterProgressAttribute *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->frontXOffsetChanged(); break;
        case 1: _t->backXOffsetChanged(); break;
        case 2: _t->popsChanged(); break;
        case 3: _t->runningChanged(); break;
        case 4: _t->waterProgressChanged(); break;
        case 5: _t->imageWidthChanged(); break;
        case 6: _t->imageHeightChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQuickWaterProgressAttribute::*)()>(_a, &DQuickWaterProgressAttribute::frontXOffsetChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWaterProgressAttribute::*)()>(_a, &DQuickWaterProgressAttribute::backXOffsetChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWaterProgressAttribute::*)()>(_a, &DQuickWaterProgressAttribute::popsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWaterProgressAttribute::*)()>(_a, &DQuickWaterProgressAttribute::runningChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWaterProgressAttribute::*)()>(_a, &DQuickWaterProgressAttribute::waterProgressChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWaterProgressAttribute::*)()>(_a, &DQuickWaterProgressAttribute::imageWidthChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWaterProgressAttribute::*)()>(_a, &DQuickWaterProgressAttribute::imageHeightChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->frontXOffset(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->backXOffset(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->imageWidth(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->imageHeight(); break;
        case 4: *reinterpret_cast<QQmlListProperty<Dtk::Quick::WaterPopAttribute>*>(_v) = _t->pops(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->running(); break;
        case 6: *reinterpret_cast<QQuickItem**>(_v) = _t->waterProgress(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setImageWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setImageHeight(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setRunning(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setWaterProgress(*reinterpret_cast<QQuickItem**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::DQuickWaterProgressAttribute::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickWaterProgressAttribute::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick28DQuickWaterProgressAttributeE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Core::DObject"))
        return static_cast< Core::DObject*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DQuickWaterProgressAttribute::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickWaterProgressAttribute::frontXOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickWaterProgressAttribute::backXOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickWaterProgressAttribute::popsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickWaterProgressAttribute::runningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickWaterProgressAttribute::waterProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickWaterProgressAttribute::imageWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQuickWaterProgressAttribute::imageHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
