/****************************************************************************
** Meta object code from reading C++ file 'dquickiconlabel_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/private/dquickiconlabel_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickiconlabel_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__DQuickIconLabel_t {
    QByteArrayData data[23];
    char stringdata0[258];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickIconLabel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickIconLabel_t qt_meta_stringdata_Dtk__Quick__DQuickIconLabel = {
    {
QT_MOC_LITERAL(0, 0, 27), // "Dtk::Quick::DQuickIconLabel"
QT_MOC_LITERAL(1, 28, 12), // "colorChanged"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 5), // "color"
QT_MOC_LITERAL(4, 48, 4), // "icon"
QT_MOC_LITERAL(5, 53, 25), // "Dtk::Quick::DQuickDciIcon"
QT_MOC_LITERAL(6, 79, 4), // "text"
QT_MOC_LITERAL(7, 84, 4), // "font"
QT_MOC_LITERAL(8, 89, 7), // "display"
QT_MOC_LITERAL(9, 97, 7), // "Display"
QT_MOC_LITERAL(10, 105, 7), // "spacing"
QT_MOC_LITERAL(11, 113, 8), // "mirrored"
QT_MOC_LITERAL(12, 122, 9), // "alignment"
QT_MOC_LITERAL(13, 132, 13), // "Qt::Alignment"
QT_MOC_LITERAL(14, 146, 10), // "topPadding"
QT_MOC_LITERAL(15, 157, 11), // "leftPadding"
QT_MOC_LITERAL(16, 169, 12), // "rightPadding"
QT_MOC_LITERAL(17, 182, 13), // "bottomPadding"
QT_MOC_LITERAL(18, 196, 8), // "IconOnly"
QT_MOC_LITERAL(19, 205, 8), // "TextOnly"
QT_MOC_LITERAL(20, 214, 14), // "TextBesideIcon"
QT_MOC_LITERAL(21, 229, 13), // "TextUnderIcon"
QT_MOC_LITERAL(22, 243, 14) // "IconBesideText"

    },
    "Dtk::Quick::DQuickIconLabel\0colorChanged\0"
    "\0color\0icon\0Dtk::Quick::DQuickDciIcon\0"
    "text\0font\0display\0Display\0spacing\0"
    "mirrored\0alignment\0Qt::Alignment\0"
    "topPadding\0leftPadding\0rightPadding\0"
    "bottomPadding\0IconOnly\0TextOnly\0"
    "TextBesideIcon\0TextUnderIcon\0"
    "IconBesideText"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickIconLabel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
      12,   22, // properties
       1,   70, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QColor,    3,

 // properties: name, type, flags
       4, 0x80000000 | 5, 0x0009590b,
       6, QMetaType::QString, 0x00095903,
       7, QMetaType::QFont, 0x00095903,
       3, QMetaType::QColor, 0x00495903,
       8, 0x80000000 | 9, 0x0009590b,
      10, QMetaType::QReal, 0x00095903,
      11, QMetaType::Bool, 0x00095903,
      12, 0x80000000 | 13, 0x0009590b,
      14, QMetaType::QReal, 0x00095907,
      15, QMetaType::QReal, 0x00095907,
      16, QMetaType::QReal, 0x00095907,
      17, QMetaType::QReal, 0x00095907,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,

 // enums: name, alias, flags, count, data
       9,    9, 0x0,    5,   75,

 // enum data: key, value
      18, uint(Dtk::Quick::DQuickIconLabel::IconOnly),
      19, uint(Dtk::Quick::DQuickIconLabel::TextOnly),
      20, uint(Dtk::Quick::DQuickIconLabel::TextBesideIcon),
      21, uint(Dtk::Quick::DQuickIconLabel::TextUnderIcon),
      22, uint(Dtk::Quick::DQuickIconLabel::IconBesideText),

       0        // eod
};

void Dtk::Quick::DQuickIconLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DQuickIconLabel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->colorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DQuickIconLabel::*)(const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickIconLabel::colorChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DQuickIconLabel *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< Dtk::Quick::DQuickDciIcon*>(_v) = _t->icon(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->text(); break;
        case 2: *reinterpret_cast< QFont*>(_v) = _t->font(); break;
        case 3: *reinterpret_cast< QColor*>(_v) = _t->color(); break;
        case 4: *reinterpret_cast< Display*>(_v) = _t->display(); break;
        case 5: *reinterpret_cast< qreal*>(_v) = _t->spacing(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->isMirrored(); break;
        case 7: *reinterpret_cast< Qt::Alignment*>(_v) = _t->alignment(); break;
        case 8: *reinterpret_cast< qreal*>(_v) = _t->topPadding(); break;
        case 9: *reinterpret_cast< qreal*>(_v) = _t->leftPadding(); break;
        case 10: *reinterpret_cast< qreal*>(_v) = _t->rightPadding(); break;
        case 11: *reinterpret_cast< qreal*>(_v) = _t->bottomPadding(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DQuickIconLabel *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIcon(*reinterpret_cast< Dtk::Quick::DQuickDciIcon*>(_v)); break;
        case 1: _t->setText(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setFont(*reinterpret_cast< QFont*>(_v)); break;
        case 3: _t->setColor(*reinterpret_cast< QColor*>(_v)); break;
        case 4: _t->setDisplay(*reinterpret_cast< Display*>(_v)); break;
        case 5: _t->setSpacing(*reinterpret_cast< qreal*>(_v)); break;
        case 6: _t->setMirrored(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setAlignment(*reinterpret_cast< Qt::Alignment*>(_v)); break;
        case 8: _t->setTopPadding(*reinterpret_cast< qreal*>(_v)); break;
        case 9: _t->setLeftPadding(*reinterpret_cast< qreal*>(_v)); break;
        case 10: _t->setRightPadding(*reinterpret_cast< qreal*>(_v)); break;
        case 11: _t->setBottomPadding(*reinterpret_cast< qreal*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
        DQuickIconLabel *_t = static_cast<DQuickIconLabel *>(_o);
        (void)_t;
        switch (_id) {
        case 8: _t->resetTopPadding(); break;
        case 9: _t->resetLeftPadding(); break;
        case 10: _t->resetRightPadding(); break;
        case 11: _t->resetBottomPadding(); break;
        default: break;
        }
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickIconLabel::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DQuickIconLabel.data,
    qt_meta_data_Dtk__Quick__DQuickIconLabel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::DQuickIconLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickIconLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DQuickIconLabel.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Dtk::Quick::DQuickIconLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 12;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickIconLabel::colorChanged(const QColor & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
