/****************************************************************************
** Meta object code from reading C++ file 'dquickiconlabel_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/private/dquickiconlabel_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickiconlabel_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick15DQuickIconLabelE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickIconLabel::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick15DQuickIconLabelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickIconLabel",
        "QML.Element",
        "IconLabel",
        "colorChanged",
        "",
        "QColor",
        "color",
        "icon",
        "Dtk::Quick::DQuickDciIcon",
        "text",
        "font",
        "QFont",
        "display",
        "Display",
        "spacing",
        "mirrored",
        "alignment",
        "Qt::Alignment",
        "topPadding",
        "leftPadding",
        "rightPadding",
        "bottomPadding",
        "IconOnly",
        "TextOnly",
        "TextBesideIcon",
        "TextUnderIcon",
        "IconBesideText"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'icon'
        QtMocHelpers::PropertyData<Dtk::Quick::DQuickDciIcon>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final),
        // property 'font'
        QtMocHelpers::PropertyData<QFont>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'display'
        QtMocHelpers::PropertyData<enum Display>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
        // property 'spacing'
        QtMocHelpers::PropertyData<qreal>(14, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final),
        // property 'mirrored'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final),
        // property 'alignment'
        QtMocHelpers::PropertyData<Qt::Alignment>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
        // property 'topPadding'
        QtMocHelpers::PropertyData<qreal>(18, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final),
        // property 'leftPadding'
        QtMocHelpers::PropertyData<qreal>(19, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final),
        // property 'rightPadding'
        QtMocHelpers::PropertyData<qreal>(20, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final),
        // property 'bottomPadding'
        QtMocHelpers::PropertyData<qreal>(21, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Display'
        QtMocHelpers::EnumData<enum Display>(13, 13, QMC::EnumFlags{}).add({
            {   22, Display::IconOnly },
            {   23, Display::TextOnly },
            {   24, Display::TextBesideIcon },
            {   25, Display::TextUnderIcon },
            {   26, Display::IconBesideText },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DQuickIconLabel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickIconLabel::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick15DQuickIconLabelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick15DQuickIconLabelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick15DQuickIconLabelE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickIconLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickIconLabel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQuickIconLabel::*)(const QColor & )>(_a, &DQuickIconLabel::colorChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Dtk::Quick::DQuickDciIcon*>(_v) = _t->icon(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 2: *reinterpret_cast<QFont*>(_v) = _t->font(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 4: *reinterpret_cast<enum Display*>(_v) = _t->display(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->spacing(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isMirrored(); break;
        case 7: *reinterpret_cast<Qt::Alignment*>(_v) = _t->alignment(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->topPadding(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->leftPadding(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->rightPadding(); break;
        case 11: *reinterpret_cast<qreal*>(_v) = _t->bottomPadding(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIcon(*reinterpret_cast<Dtk::Quick::DQuickDciIcon*>(_v)); break;
        case 1: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setFont(*reinterpret_cast<QFont*>(_v)); break;
        case 3: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 4: _t->setDisplay(*reinterpret_cast<enum Display*>(_v)); break;
        case 5: _t->setSpacing(*reinterpret_cast<qreal*>(_v)); break;
        case 6: _t->setMirrored(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setAlignment(*reinterpret_cast<Qt::Alignment*>(_v)); break;
        case 8: _t->setTopPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 9: _t->setLeftPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 10: _t->setRightPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 11: _t->setBottomPadding(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 8: _t->resetTopPadding(); break;
        case 9: _t->resetLeftPadding(); break;
        case 10: _t->resetRightPadding(); break;
        case 11: _t->resetBottomPadding(); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::DQuickIconLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickIconLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick15DQuickIconLabelE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Dtk::Quick::DQuickIconLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickIconLabel::colorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
