/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<dconfigwrapper_p.h>)
#  include <dconfigwrapper_p.h>
#endif
#if __has_include(<dhandlecontextmenuwindow_p.h>)
#  include <dhandlecontextmenuwindow_p.h>
#endif
#if __has_include(<dlicenseinfoprovider_p.h>)
#  include <dlicenseinfoprovider_p.h>
#endif
#if __has_include(<dmessagemanager_p.h>)
#  include <dmessagemanager_p.h>
#endif
#if __has_include(<dobjectmodelproxy_p.h>)
#  include <dobjectmodelproxy_p.h>
#endif
#if __has_include(<dpopupwindowhandle_p.h>)
#  include <dpopupwindowhandle_p.h>
#endif
#if __has_include(<dqmlglobalobject_p.h>)
#  include <dqmlglobalobject_p.h>
#endif
#if __has_include(<dquickapploaderitem_p.h>)
#  include <dquickapploaderitem_p.h>
#endif
#if __has_include(<dquickarrowboxpath_p.h>)
#  include <dquickarrowboxpath_p.h>
#endif
#if __has_include(<dquickbackdropblitter_p.h>)
#  include <dquickbackdropblitter_p.h>
#endif
#if __has_include(<dquickbehindwindowblur_p.h>)
#  include <dquickbehindwindowblur_p.h>
#endif
#if __has_include(<dquickblitframebuffer.h>)
#  include <dquickblitframebuffer.h>
#endif
#if __has_include(<dquickborderimage_p.h>)
#  include <dquickborderimage_p.h>
#endif
#if __has_include(<dquickcoloroverlay_p.h>)
#  include <dquickcoloroverlay_p.h>
#endif
#if __has_include(<dquickcontrolpalette_p.h>)
#  include <dquickcontrolpalette_p.h>
#endif
#if __has_include(<dquickdciicon_p.h>)
#  include <dquickdciicon_p.h>
#endif
#if __has_include(<dquickdciiconimage_p.h>)
#  include <dquickdciiconimage_p.h>
#endif
#if __has_include(<dquickextendregister_p.h>)
#  include <dquickextendregister_p.h>
#endif
#if __has_include(<dquickglow_p.h>)
#  include <dquickglow_p.h>
#endif
#if __has_include(<dquickiconimage_p.h>)
#  include <dquickiconimage_p.h>
#endif
#if __has_include(<dquickiconlabel_p.h>)
#  include <dquickiconlabel_p.h>
#endif
#if __has_include(<dquickinwindowblur_p.h>)
#  include <dquickinwindowblur_p.h>
#endif
#if __has_include(<dquickitemviewport.h>)
#  include <dquickitemviewport.h>
#endif
#if __has_include(<dquickkeylistener_p.h>)
#  include <dquickkeylistener_p.h>
#endif
#if __has_include(<dquickopacitymask_p.h>)
#  include <dquickopacitymask_p.h>
#endif
#if __has_include(<dquickrectangle_p.h>)
#  include <dquickrectangle_p.h>
#endif
#if __has_include(<dquickwaterprogressattribute_p.h>)
#  include <dquickwaterprogressattribute_p.h>
#endif
#if __has_include(<dquickwindow.h>)
#  include <dquickwindow.h>
#endif
#if __has_include(<dsettingscontainer_p.h>)
#  include <dsettingscontainer_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_deepin_dtk()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<DConfigWrapper>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<DHandleContextMenuWindow>("org.deepin.dtk", 1);
    qmlRegisterAnonymousType<QQuickWindow, 254>("org.deepin.dtk", 1);
    qmlRegisterAnonymousType<QWindow, 254>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DColor>("org.deepin.dtk", 1);
    qmlRegisterEnum<Dtk::Quick::DColor::Type>("Dtk::Quick::DColor::Type");
    QMetaType::fromType<DTK_QUICK_NAMESPACE::DColor>().id();
    qmlRegisterNamespaceAndRevisions(&DTK_QUICK_NAMESPACE::DColor::staticMetaObject, "org.deepin.dtk", 1, nullptr, &Dtk::Quick::DColorForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DFontManagerForeign>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DGuiApplicationHelperForeign>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DLicenseInfoProvider>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DPlatformHandleForeign>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DPopupWindowHandle>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQMLGlobalObject>("org.deepin.dtk", 1);
    qmlRegisterEnum<Dtk::Quick::DQMLGlobalObject::ControlState>("Dtk::Quick::DQMLGlobalObject::ControlState");
    qmlRegisterEnum<Dtk::Quick::DQMLGlobalObject::ZOrder>("Dtk::Quick::DQMLGlobalObject::ZOrder");
    qmlRegisterEnum<Dtk::Quick::DQMLGlobalObject::CompositionMode>("Dtk::Quick::DQMLGlobalObject::CompositionMode");
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickAppLoaderItem>("org.deepin.dtk", 1);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickArrowBoxPath>("org.deepin.dtk", 1);
    qmlRegisterEnum<Dtk::Quick::DQuickArrowBoxPath::Direction>("Dtk::Quick::DQuickArrowBoxPath::Direction");
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickBackdropBlitter>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickBehindWindowBlur>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickBlitFramebuffer>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickBorderImage>("org.deepin.dtk", 1);
    qmlRegisterAnonymousType<QQuickImageBase, 254>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickColorOverlay>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickControlColor>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickControlColorSelector>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickControlPalette>("org.deepin.dtk", 1);
    qmlRegisterEnum<Dtk::Quick::DQuickControlPalette::ColorFamily>("Dtk::Quick::DQuickControlPalette::ColorFamily");
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickDciIcon>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickDciIconImage>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickGlow>("org.deepin.dtk", 1);
    QMetaType::fromType<Dtk::Quick::DQuickIconAttached *>().id();
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickIconImage>("org.deepin.dtk", 1);
    qmlRegisterAnonymousType<QQuickImage, 254>("org.deepin.dtk", 1);
    qmlRegisterEnum<Dtk::Quick::DQuickIconImage::Mode>("Dtk::Quick::DQuickIconImage::Mode");
    qmlRegisterEnum<Dtk::Quick::DQuickIconImage::State>("Dtk::Quick::DQuickIconImage::State");
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickIconLabel>("org.deepin.dtk", 1);
    qmlRegisterEnum<Dtk::Quick::DQuickIconLabel::Display>("Dtk::Quick::DQuickIconLabel::Display");
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickInWindowBlur>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickItemViewport>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickKeyListener>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickOpacityMask>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickRectangle>("org.deepin.dtk", 1);
    qmlRegisterEnum<Dtk::Quick::DQuickRectangle::Corners>("Dtk::Quick::DQuickRectangle::Corners");
    qmlRegisterEnum<Dtk::Quick::DQuickRectangle::Corner>("Dtk::Quick::DQuickRectangle::Corner");
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickWaterProgressAttribute>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickWindow>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::DQuickWindowAttached>("org.deepin.dtk", 1);
    QMetaType::fromType<DTK_CORE_NAMESPACE::DSysInfo>().id();
    qmlRegisterNamespaceAndRevisions(&DTK_CORE_NAMESPACE::DSysInfo::staticMetaObject, "org.deepin.dtk", 1, nullptr, &Dtk::Quick::DSysInfoForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<Dtk::Quick::FloatingMessageContainer>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::MessageManager>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::ObjectModelProxy>("org.deepin.dtk", 1);
    qmlRegisterAnonymousType<QQmlInstanceModel, 254>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::SettingsContainer>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::SettingsGroup>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::SettingsOption>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::WaterPopAttribute>("org.deepin.dtk", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::WindowManagerHelperForeign>("org.deepin.dtk", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.deepin.dtk", 1, 0);
}

static const QQmlModuleRegistration orgdeepindtkRegistration("org.deepin.dtk", qml_register_types_org_deepin_dtk);
