/****************************************************************************
** Meta object code from reading C++ file 'dqmlglobalobject_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/private/dqmlglobalobject_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dqmlglobalobject_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick6DColorE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DColor::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick6DColorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DColor",
        "QML.Element",
        "dcolor",
        "toColor",
        "QColor",
        "",
        "QPalette",
        "palette",
        "color",
        "hue",
        "floatValue",
        "saturation",
        "lightness",
        "opacity",
        "Type",
        "Invalid",
        "Highlight",
        "HighlightedText"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'toColor'
        QtMocHelpers::MethodData<QColor(const QPalette &) const>(3, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Method 'color'
        QtMocHelpers::MethodData<QColor() const>(8, 5, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'hue'
        QtMocHelpers::MethodData<Dtk::Quick::DColor(qint8) const>(9, 5, QMC::AccessPublic, 0x80000000 | 0, {{
            { QMetaType::SChar, 10 },
        }}),
        // Method 'saturation'
        QtMocHelpers::MethodData<Dtk::Quick::DColor(qint8) const>(11, 5, QMC::AccessPublic, 0x80000000 | 0, {{
            { QMetaType::SChar, 10 },
        }}),
        // Method 'lightness'
        QtMocHelpers::MethodData<Dtk::Quick::DColor(qint8) const>(12, 5, QMC::AccessPublic, 0x80000000 | 0, {{
            { QMetaType::SChar, 10 },
        }}),
        // Method 'opacity'
        QtMocHelpers::MethodData<Dtk::Quick::DColor(qint8) const>(13, 5, QMC::AccessPublic, 0x80000000 | 0, {{
            { QMetaType::SChar, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(14, 14, QMC::EnumFlags{}).add({
            {   15, Type::Invalid },
            {   16, Type::Highlight },
            {   17, Type::HighlightedText },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DColor, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::DColor::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick6DColorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick6DColorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick6DColorE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DColor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<DColor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QColor _r = _t->toColor((*reinterpret_cast<std::add_pointer_t<QPalette>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 1: { QColor _r = _t->color();
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 2: { Dtk::Quick::DColor _r = _t->hue((*reinterpret_cast<std::add_pointer_t<qint8>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Dtk::Quick::DColor*>(_a[0]) = std::move(_r); }  break;
        case 3: { Dtk::Quick::DColor _r = _t->saturation((*reinterpret_cast<std::add_pointer_t<qint8>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Dtk::Quick::DColor*>(_a[0]) = std::move(_r); }  break;
        case 4: { Dtk::Quick::DColor _r = _t->lightness((*reinterpret_cast<std::add_pointer_t<qint8>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Dtk::Quick::DColor*>(_a[0]) = std::move(_r); }  break;
        case 5: { Dtk::Quick::DColor _r = _t->opacity((*reinterpret_cast<std::add_pointer_t<qint8>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Dtk::Quick::DColor*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}
namespace {
struct qt_meta_tag_ZN3Dtk5Quick16DQMLGlobalObjectE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQMLGlobalObject::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick16DQMLGlobalObjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQMLGlobalObject",
        "QML.Element",
        "DTK",
        "QML.Singleton",
        "true",
        "hasBlurWindowChanged",
        "",
        "hasCompositeChanged",
        "hasNoTitlebarChanged",
        "hasAnimationChanged",
        "hasInWindowBlurChanged",
        "paletteChanged",
        "inactivePaletteChanged",
        "themeTypeChanged",
        "Dtk::Gui::DGuiApplicationHelper::ColorType",
        "themeType",
        "_q_onPaletteChanged",
        "blendColor",
        "QColor",
        "substrate",
        "superstratum",
        "makeColor",
        "Dtk::Quick::DColor",
        "Dtk::Quick::DColor::Type",
        "type",
        "color",
        "makeShadowImageUrl",
        "QUrl",
        "boxSize",
        "cornerRadius",
        "shadowBlur",
        "xOffset",
        "yOffset",
        "spread",
        "hollow",
        "inner",
        "topLeftRadius",
        "topRightRadius",
        "bottomLeftRadius",
        "bottomRightRadius",
        "toColorType",
        "selectColor",
        "windowColor",
        "light",
        "dark",
        "cursorPosition",
        "QPoint",
        "makeIcon",
        "Dtk::Quick::DQuickDciIcon",
        "QJSValue",
        "qicon",
        "iconExtra",
        "makeIconPalette",
        "Dtk::Gui::DDciIconPalette",
        "const QQuickPalette*",
        "palette",
        "sendMessage",
        "target",
        "content",
        "iconName",
        "duration",
        "msgId",
        "QQmlComponent*",
        "delegate",
        "QVariant",
        "message",
        "closeMessage",
        "Dtk::Quick::FloatingMessageContainer*",
        "sendSystemMessage",
        "summary",
        "body",
        "appIcon",
        "actions",
        "QVariantMap",
        "hints",
        "timeout",
        "replaceId",
        "hasBlurWindow",
        "hasComposite",
        "hasNoTitlebar",
        "hasAnimation",
        "hasInWindowBlur",
        "isSoftwareRender",
        "windowManagerName",
        "Dtk::Gui::DWindowManagerHelper::WMName",
        "windowManagerNameString",
        "platformTheme",
        "DPlatformThemeProxy*",
        "fontManager",
        "Dtk::Gui::DFontManager*",
        "QQuickPalette*",
        "inactivePalette",
        "deepinDistributionOrgLogo",
        "deepinWebsiteName",
        "deepinWebsiteLink",
        "ControlState",
        "NormalState",
        "HoveredState",
        "PressedState",
        "DisabledState",
        "InactiveState",
        "ZOrder",
        "BottomOrder",
        "BelowOrder",
        "NormalOrder",
        "AboveOrder",
        "TopOrder",
        "CompositionMode",
        "Source",
        "SourceOver",
        "Destination",
        "DestinationOver",
        "Clear"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hasBlurWindowChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasCompositeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasNoTitlebarChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasAnimationChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasInWindowBlurChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paletteChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inactivePaletteChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'themeTypeChanged'
        QtMocHelpers::SignalData<void(Dtk::Gui::DGuiApplicationHelper::ColorType)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot '_q_onPaletteChanged'
        QtMocHelpers::SlotData<void()>(16, 6, QMC::AccessPrivate, QMetaType::Void),
        // Method 'blendColor'
        QtMocHelpers::MethodData<QColor(const QColor &, const QColor &)>(17, 6, QMC::AccessPublic, 0x80000000 | 18, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 18, 20 },
        }}),
        // Method 'makeColor'
        QtMocHelpers::MethodData<Dtk::Quick::DColor(Dtk::Quick::DColor::Type)>(21, 6, QMC::AccessPublic, 0x80000000 | 22, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Method 'makeColor'
        QtMocHelpers::MethodData<Dtk::Quick::DColor(const QColor &)>(21, 6, QMC::AccessPublic, 0x80000000 | 22, {{
            { 0x80000000 | 18, 25 },
        }}),
        // Method 'makeShadowImageUrl'
        QtMocHelpers::MethodData<QUrl(qreal, qreal, qreal, QColor, qreal, qreal, qreal, bool, bool)>(26, 6, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QReal, 28 }, { QMetaType::QReal, 29 }, { QMetaType::QReal, 30 }, { 0x80000000 | 18, 25 },
            { QMetaType::QReal, 31 }, { QMetaType::QReal, 32 }, { QMetaType::QReal, 33 }, { QMetaType::Bool, 34 },
            { QMetaType::Bool, 35 },
        }}),
        // Method 'makeShadowImageUrl'
        QtMocHelpers::MethodData<QUrl(qreal, qreal, qreal, qreal, qreal, qreal, QColor, qreal, qreal, qreal, bool, bool)>(26, 6, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QReal, 28 }, { QMetaType::QReal, 36 }, { QMetaType::QReal, 37 }, { QMetaType::QReal, 38 },
            { QMetaType::QReal, 39 }, { QMetaType::QReal, 30 }, { 0x80000000 | 18, 25 }, { QMetaType::QReal, 31 },
            { QMetaType::QReal, 32 }, { QMetaType::QReal, 33 }, { QMetaType::Bool, 34 }, { QMetaType::Bool, 35 },
        }}),
        // Method 'toColorType'
        QtMocHelpers::MethodData<Dtk::Gui::DGuiApplicationHelper::ColorType(const QColor &)>(40, 6, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 18, 25 },
        }}),
        // Method 'selectColor'
        QtMocHelpers::MethodData<QColor(const QColor &, const QColor &, const QColor &)>(41, 6, QMC::AccessPublic, 0x80000000 | 18, {{
            { 0x80000000 | 18, 42 }, { 0x80000000 | 18, 43 }, { 0x80000000 | 18, 44 },
        }}),
        // Method 'cursorPosition'
        QtMocHelpers::MethodData<QPoint() const>(45, 6, QMC::AccessPublic, 0x80000000 | 46),
        // Method 'makeIcon'
        QtMocHelpers::MethodData<Dtk::Quick::DQuickDciIcon(const QJSValue &, const QJSValue &)>(47, 6, QMC::AccessPublic, 0x80000000 | 48, {{
            { 0x80000000 | 49, 50 }, { 0x80000000 | 49, 51 },
        }}),
        // Method 'makeIconPalette'
        QtMocHelpers::MethodData<Dtk::Gui::DDciIconPalette(const QQuickPalette *)>(52, 6, QMC::AccessPublic, 0x80000000 | 53, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Method 'sendMessage'
        QtMocHelpers::MethodData<bool(QObject *, const QString &, const QString &, int, const QString &)>(56, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QObjectStar, 57 }, { QMetaType::QString, 58 }, { QMetaType::QString, 59 }, { QMetaType::Int, 60 },
            { QMetaType::QString, 61 },
        }}),
        // Method 'sendMessage'
        QtMocHelpers::MethodData<bool(QObject *, const QString &, const QString &, int)>(56, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QObjectStar, 57 }, { QMetaType::QString, 58 }, { QMetaType::QString, 59 }, { QMetaType::Int, 60 },
        }}),
        // Method 'sendMessage'
        QtMocHelpers::MethodData<bool(QObject *, const QString &, const QString &)>(56, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QObjectStar, 57 }, { QMetaType::QString, 58 }, { QMetaType::QString, 59 },
        }}),
        // Method 'sendMessage'
        QtMocHelpers::MethodData<bool(QObject *, const QString &)>(56, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QObjectStar, 57 }, { QMetaType::QString, 58 },
        }}),
        // Method 'sendMessage'
        QtMocHelpers::MethodData<bool(QObject *, QQmlComponent *, const QVariant &, int, const QString &)>(56, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QObjectStar, 57 }, { 0x80000000 | 62, 63 }, { 0x80000000 | 64, 65 }, { QMetaType::Int, 60 },
            { QMetaType::QString, 61 },
        }}),
        // Method 'sendMessage'
        QtMocHelpers::MethodData<bool(QObject *, QQmlComponent *, const QVariant &, int)>(56, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QObjectStar, 57 }, { 0x80000000 | 62, 63 }, { 0x80000000 | 64, 65 }, { QMetaType::Int, 60 },
        }}),
        // Method 'sendMessage'
        QtMocHelpers::MethodData<bool(QObject *, QQmlComponent *, const QVariant &)>(56, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QObjectStar, 57 }, { 0x80000000 | 62, 63 }, { 0x80000000 | 64, 65 },
        }}),
        // Method 'closeMessage'
        QtMocHelpers::MethodData<void(Dtk::Quick::FloatingMessageContainer *)>(66, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 67, 65 },
        }}),
        // Method 'closeMessage'
        QtMocHelpers::MethodData<void(QObject *, const QString &)>(66, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 57 }, { QMetaType::QString, 61 },
        }}),
        // Method 'sendSystemMessage'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &, const QStringList &, const QVariantMap, const int, const uint)>(68, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 69 }, { QMetaType::QString, 70 }, { QMetaType::QString, 71 }, { QMetaType::QStringList, 72 },
            { 0x80000000 | 73, 74 }, { QMetaType::Int, 75 }, { QMetaType::UInt, 76 },
        }}),
        // Method 'sendSystemMessage'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &, const QStringList &, const QVariantMap, const int)>(68, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 69 }, { QMetaType::QString, 70 }, { QMetaType::QString, 71 }, { QMetaType::QStringList, 72 },
            { 0x80000000 | 73, 74 }, { QMetaType::Int, 75 },
        }}),
        // Method 'sendSystemMessage'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &, const QStringList &, const QVariantMap)>(68, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 69 }, { QMetaType::QString, 70 }, { QMetaType::QString, 71 }, { QMetaType::QStringList, 72 },
            { 0x80000000 | 73, 74 },
        }}),
        // Method 'sendSystemMessage'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &, const QStringList &)>(68, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 69 }, { QMetaType::QString, 70 }, { QMetaType::QString, 71 }, { QMetaType::QStringList, 72 },
        }}),
        // Method 'sendSystemMessage'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &)>(68, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 69 }, { QMetaType::QString, 70 }, { QMetaType::QString, 71 },
        }}),
        // Method 'sendSystemMessage'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(68, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 69 }, { QMetaType::QString, 70 },
        }}),
        // Method 'sendSystemMessage'
        QtMocHelpers::MethodData<void(const QString &)>(68, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 69 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hasBlurWindow'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'hasComposite'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'hasNoTitlebar'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'hasAnimation'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'hasInWindowBlur'
        QtMocHelpers::PropertyData<bool>(81, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'isSoftwareRender'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'windowManagerName'
        QtMocHelpers::PropertyData<Dtk::Gui::DWindowManagerHelper::WMName>(83, 0x80000000 | 84, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'themeType'
        QtMocHelpers::PropertyData<Dtk::Gui::DGuiApplicationHelper::ColorType>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'windowManagerNameString'
        QtMocHelpers::PropertyData<QString>(85, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'platformTheme'
        QtMocHelpers::PropertyData<DPlatformThemeProxy*>(86, 0x80000000 | 87, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'fontManager'
        QtMocHelpers::PropertyData<Dtk::Gui::DFontManager*>(88, 0x80000000 | 89, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'palette'
        QtMocHelpers::PropertyData<QQuickPalette*>(55, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'inactivePalette'
        QtMocHelpers::PropertyData<QQuickPalette*>(91, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'deepinDistributionOrgLogo'
        QtMocHelpers::PropertyData<QString>(92, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'deepinWebsiteName'
        QtMocHelpers::PropertyData<QString>(93, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'deepinWebsiteLink'
        QtMocHelpers::PropertyData<QString>(94, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ControlState'
        QtMocHelpers::EnumData<enum ControlState>(95, 95, QMC::EnumFlags{}).add({
            {   96, ControlState::NormalState },
            {   97, ControlState::HoveredState },
            {   98, ControlState::PressedState },
            {   99, ControlState::DisabledState },
            {  100, ControlState::InactiveState },
        }),
        // enum 'ZOrder'
        QtMocHelpers::EnumData<enum ZOrder>(101, 101, QMC::EnumFlags{}).add({
            {  102, ZOrder::BottomOrder },
            {  103, ZOrder::BelowOrder },
            {  104, ZOrder::NormalOrder },
            {  105, ZOrder::AboveOrder },
            {  106, ZOrder::TopOrder },
        }),
        // enum 'CompositionMode'
        QtMocHelpers::EnumData<enum CompositionMode>(107, 107, QMC::EnumIsScoped).add({
            {  108, CompositionMode::Source },
            {  109, CompositionMode::SourceOver },
            {  110, CompositionMode::Destination },
            {  111, CompositionMode::DestinationOver },
            {  112, CompositionMode::Clear },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DQMLGlobalObject, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3Dtk5Quick16DQMLGlobalObjectE[] = {
    QMetaObject::SuperData::link<Dtk::Gui::DWindowManagerHelper::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Gui::DGuiApplicationHelper::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Dtk::Quick::DQMLGlobalObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick16DQMLGlobalObjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick16DQMLGlobalObjectE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3Dtk5Quick16DQMLGlobalObjectE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick16DQMLGlobalObjectE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQMLGlobalObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQMLGlobalObject *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->hasBlurWindowChanged(); break;
        case 1: _t->hasCompositeChanged(); break;
        case 2: _t->hasNoTitlebarChanged(); break;
        case 3: _t->hasAnimationChanged(); break;
        case 4: _t->hasInWindowBlurChanged(); break;
        case 5: _t->paletteChanged(); break;
        case 6: _t->inactivePaletteChanged(); break;
        case 7: _t->themeTypeChanged((*reinterpret_cast<std::add_pointer_t<Dtk::Gui::DGuiApplicationHelper::ColorType>>(_a[1]))); break;
        case 8: _t->d_func()->_q_onPaletteChanged(); break;
        case 9: { QColor _r = _t->blendColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 10: { Dtk::Quick::DColor _r = _t->makeColor((*reinterpret_cast<std::add_pointer_t<Dtk::Quick::DColor::Type>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Dtk::Quick::DColor*>(_a[0]) = std::move(_r); }  break;
        case 11: { Dtk::Quick::DColor _r = _t->makeColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Dtk::Quick::DColor*>(_a[0]) = std::move(_r); }  break;
        case 12: { QUrl _r = _t->makeShadowImageUrl((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 13: { QUrl _r = _t->makeShadowImageUrl((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 14: { Dtk::Gui::DGuiApplicationHelper::ColorType _r = _t->toColorType((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Dtk::Gui::DGuiApplicationHelper::ColorType*>(_a[0]) = std::move(_r); }  break;
        case 15: { QColor _r = _t->selectColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 16: { QPoint _r = _t->cursorPosition();
            if (_a[0]) *reinterpret_cast<QPoint*>(_a[0]) = std::move(_r); }  break;
        case 17: { Dtk::Quick::DQuickDciIcon _r = _t->makeIcon((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Dtk::Quick::DQuickDciIcon*>(_a[0]) = std::move(_r); }  break;
        case 18: { Dtk::Gui::DDciIconPalette _r = _t->makeIconPalette((*reinterpret_cast<std::add_pointer_t<const QQuickPalette*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Dtk::Gui::DDciIconPalette*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->closeMessage((*reinterpret_cast<std::add_pointer_t<Dtk::Quick::FloatingMessageContainer*>>(_a[1]))); break;
        case 27: _t->closeMessage((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 28: _t->sendSystemMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[7]))); break;
        case 29: _t->sendSystemMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6]))); break;
        case 30: _t->sendSystemMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5]))); break;
        case 31: _t->sendSystemMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4]))); break;
        case 32: _t->sendSystemMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 33: _t->sendSystemMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 34: _t->sendSystemMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQmlComponent* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQmlComponent* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQmlComponent* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQMLGlobalObject::*)()>(_a, &DQMLGlobalObject::hasBlurWindowChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQMLGlobalObject::*)()>(_a, &DQMLGlobalObject::hasCompositeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQMLGlobalObject::*)()>(_a, &DQMLGlobalObject::hasNoTitlebarChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQMLGlobalObject::*)()>(_a, &DQMLGlobalObject::hasAnimationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQMLGlobalObject::*)()>(_a, &DQMLGlobalObject::hasInWindowBlurChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQMLGlobalObject::*)()>(_a, &DQMLGlobalObject::paletteChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQMLGlobalObject::*)()>(_a, &DQMLGlobalObject::inactivePaletteChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQMLGlobalObject::*)(Dtk::Gui::DGuiApplicationHelper::ColorType )>(_a, &DQMLGlobalObject::themeTypeChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DPlatformThemeProxy* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->hasBlurWindow(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasComposite(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasNoTitlebar(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasAnimation(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hasInWindowBlur(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isSoftwareRender(); break;
        case 6: *reinterpret_cast<Dtk::Gui::DWindowManagerHelper::WMName*>(_v) = _t->windowManagerName(); break;
        case 7: *reinterpret_cast<Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v) = _t->themeType(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->windowManagerNameString(); break;
        case 9: *reinterpret_cast<DPlatformThemeProxy**>(_v) = _t->platformTheme(); break;
        case 10: *reinterpret_cast<Dtk::Gui::DFontManager**>(_v) = _t->fontManager(); break;
        case 11: *reinterpret_cast<QQuickPalette**>(_v) = _t->quickPalette(); break;
        case 12: *reinterpret_cast<QQuickPalette**>(_v) = _t->inactiveQuickPalette(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->deepinDistributionOrgLogo(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->deepinWebsiteName(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->deepinWebsiteLink(); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::DQMLGlobalObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQMLGlobalObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick16DQMLGlobalObjectE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DQMLGlobalObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQMLGlobalObject::hasBlurWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQMLGlobalObject::hasCompositeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQMLGlobalObject::hasNoTitlebarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQMLGlobalObject::hasAnimationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQMLGlobalObject::hasInWindowBlurChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQMLGlobalObject::paletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQMLGlobalObject::inactivePaletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Quick::DQMLGlobalObject::themeTypeChanged(Dtk::Gui::DGuiApplicationHelper::ColorType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
