/****************************************************************************
** Meta object code from reading C++ file 'dquickdciiconimage_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/private/dquickdciiconimage_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickdciiconimage_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick18DQuickDciIconImageE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickDciIconImage::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick18DQuickDciIconImageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickDciIconImage",
        "QML.Element",
        "DciIcon",
        "QML.Attached",
        "DQuickIconAttached",
        "nameChanged",
        "",
        "modeChanged",
        "themeChanged",
        "paletteChanged",
        "sourceSizeChanged",
        "mirrorChanged",
        "fallbackToQIconChanged",
        "asynchronousChanged",
        "cacheChanged",
        "fillModeChanged",
        "retainWhileLoadingChanged",
        "play",
        "DQMLGlobalObject::ControlState",
        "mode",
        "name",
        "Dtk::Quick::DQMLGlobalObject::ControlState",
        "theme",
        "Dtk::Gui::DGuiApplicationHelper::ColorType",
        "palette",
        "Dtk::Gui::DDciIconPalette",
        "sourceSize",
        "QSize",
        "mirror",
        "fallbackToQIcon",
        "asynchronous",
        "cache",
        "retainWhileLoading",
        "fillMode",
        "QQuickImage::FillMode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'themeChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paletteChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceSizeChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mirrorChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackToQIconChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'asynchronousChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cacheChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fillModeChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'retainWhileLoadingChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'play'
        QtMocHelpers::MethodData<void(DQMLGlobalObject::ControlState)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'mode'
        QtMocHelpers::PropertyData<Dtk::Quick::DQMLGlobalObject::ControlState>(19, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'theme'
        QtMocHelpers::PropertyData<Dtk::Gui::DGuiApplicationHelper::ColorType>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'palette'
        QtMocHelpers::PropertyData<Dtk::Gui::DDciIconPalette>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'sourceSize'
        QtMocHelpers::PropertyData<QSize>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'mirror'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'fallbackToQIcon'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'asynchronous'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'cache'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 8),
        // property 'retainWhileLoading'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'fillMode'
        QtMocHelpers::PropertyData<QQuickImage::FillMode>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DQuickDciIconImage, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3Dtk5Quick18DQuickDciIconImageE[] = {
    QMetaObject::SuperData::link<Dtk::Quick::DQMLGlobalObject::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Gui::DGuiApplicationHelper::staticMetaObject>(),
    QMetaObject::SuperData::link<QQuickImage::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickDciIconImage::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickDciIconImageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickDciIconImageE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3Dtk5Quick18DQuickDciIconImageE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick18DQuickDciIconImageE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickDciIconImage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickDciIconImage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->modeChanged(); break;
        case 2: _t->themeChanged(); break;
        case 3: _t->paletteChanged(); break;
        case 4: _t->sourceSizeChanged(); break;
        case 5: _t->mirrorChanged(); break;
        case 6: _t->fallbackToQIconChanged(); break;
        case 7: _t->asynchronousChanged(); break;
        case 8: _t->cacheChanged(); break;
        case 9: _t->fillModeChanged(); break;
        case 10: _t->retainWhileLoadingChanged(); break;
        case 11: _t->play((*reinterpret_cast<std::add_pointer_t<DQMLGlobalObject::ControlState>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQuickDciIconImage::*)()>(_a, &DQuickDciIconImage::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDciIconImage::*)()>(_a, &DQuickDciIconImage::modeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDciIconImage::*)()>(_a, &DQuickDciIconImage::themeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDciIconImage::*)()>(_a, &DQuickDciIconImage::paletteChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDciIconImage::*)()>(_a, &DQuickDciIconImage::sourceSizeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDciIconImage::*)()>(_a, &DQuickDciIconImage::mirrorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDciIconImage::*)()>(_a, &DQuickDciIconImage::fallbackToQIconChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDciIconImage::*)()>(_a, &DQuickDciIconImage::asynchronousChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDciIconImage::*)()>(_a, &DQuickDciIconImage::cacheChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDciIconImage::*)()>(_a, &DQuickDciIconImage::fillModeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDciIconImage::*)()>(_a, &DQuickDciIconImage::retainWhileLoadingChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<Dtk::Quick::DQMLGlobalObject::ControlState*>(_v) = _t->mode(); break;
        case 2: *reinterpret_cast<Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v) = _t->theme(); break;
        case 3: *reinterpret_cast<Dtk::Gui::DDciIconPalette*>(_v) = _t->palette(); break;
        case 4: *reinterpret_cast<QSize*>(_v) = _t->sourceSize(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->mirror(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->fallbackToQIcon(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->asynchronous(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->cache(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->retainWhileLoading(); break;
        case 10: *reinterpret_cast<QQuickImage::FillMode*>(_v) = _t->fillMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setMode(*reinterpret_cast<Dtk::Quick::DQMLGlobalObject::ControlState*>(_v)); break;
        case 2: _t->setTheme(*reinterpret_cast<Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v)); break;
        case 3: _t->setPalette(*reinterpret_cast<Dtk::Gui::DDciIconPalette*>(_v)); break;
        case 4: _t->setSourceSize(*reinterpret_cast<QSize*>(_v)); break;
        case 5: _t->setMirror(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setFallbackToQIcon(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setAsynchronous(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setCache(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setRetainWhileLoading(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setFillMode(*reinterpret_cast<QQuickImage::FillMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::DQuickDciIconImage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickDciIconImage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickDciIconImageE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Core::DObject"))
        return static_cast< Core::DObject*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Dtk::Quick::DQuickDciIconImage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickDciIconImage::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickDciIconImage::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickDciIconImage::themeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickDciIconImage::paletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickDciIconImage::sourceSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickDciIconImage::mirrorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQuickDciIconImage::fallbackToQIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Quick::DQuickDciIconImage::asynchronousChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Quick::DQuickDciIconImage::cacheChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Dtk::Quick::DQuickDciIconImage::fillModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Dtk::Quick::DQuickDciIconImage::retainWhileLoadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
namespace {
struct qt_meta_tag_ZN3Dtk5Quick18DQuickIconAttachedE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickIconAttached::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick18DQuickIconAttachedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickIconAttached",
        "modeChanged",
        "",
        "themeChanged",
        "paletteChanged",
        "fallbackToQIconChanged",
        "mode",
        "Dtk::Quick::DQMLGlobalObject::ControlState",
        "theme",
        "Dtk::Gui::DGuiApplicationHelper::ColorType",
        "palette",
        "Dtk::Gui::DDciIconPalette",
        "fallbackToQIcon"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'themeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paletteChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackToQIconChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mode'
        QtMocHelpers::PropertyData<Dtk::Quick::DQMLGlobalObject::ControlState>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'theme'
        QtMocHelpers::PropertyData<Dtk::Gui::DGuiApplicationHelper::ColorType>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'palette'
        QtMocHelpers::PropertyData<Dtk::Gui::DDciIconPalette>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'fallbackToQIcon'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DQuickIconAttached, qt_meta_tag_ZN3Dtk5Quick18DQuickIconAttachedE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3Dtk5Quick18DQuickIconAttachedE[] = {
    QMetaObject::SuperData::link<Dtk::Quick::DQMLGlobalObject::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Gui::DGuiApplicationHelper::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickIconAttached::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickIconAttachedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickIconAttachedE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3Dtk5Quick18DQuickIconAttachedE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick18DQuickIconAttachedE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickIconAttached::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickIconAttached *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modeChanged(); break;
        case 1: _t->themeChanged(); break;
        case 2: _t->paletteChanged(); break;
        case 3: _t->fallbackToQIconChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQuickIconAttached::*)()>(_a, &DQuickIconAttached::modeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickIconAttached::*)()>(_a, &DQuickIconAttached::themeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickIconAttached::*)()>(_a, &DQuickIconAttached::paletteChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickIconAttached::*)()>(_a, &DQuickIconAttached::fallbackToQIconChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Dtk::Quick::DQMLGlobalObject::ControlState*>(_v) = _t->mode(); break;
        case 1: *reinterpret_cast<Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v) = _t->theme(); break;
        case 2: *reinterpret_cast<Dtk::Gui::DDciIconPalette*>(_v) = _t->palette(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->fallbackToQIcon(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMode(*reinterpret_cast<Dtk::Quick::DQMLGlobalObject::ControlState*>(_v)); break;
        case 1: _t->setTheme(*reinterpret_cast<Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v)); break;
        case 2: _t->setPalette(*reinterpret_cast<Dtk::Gui::DDciIconPalette*>(_v)); break;
        case 3: _t->setFallbackToQIcon(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::DQuickIconAttached::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickIconAttached::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickIconAttachedE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Core::DObject"))
        return static_cast< Core::DObject*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DQuickIconAttached::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickIconAttached::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickIconAttached::themeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickIconAttached::paletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickIconAttached::fallbackToQIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
