#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>

namespace QmlCacheGeneratedCode {
namespace _0x5f__DelayButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__CheckDelegate_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__Button_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__PageIndicator_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__MenuItem_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__ScrollIndicator_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__SpinBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__MenuSeparator_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__ComboBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__GroupBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__DialogButtonBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__Control_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__Slider_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__Popup_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__ScrollBar_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__Pane_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__StackView_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__CheckBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__Switch_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__ToolTip_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__RadioButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__RoundButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__TextField_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__ItemDelegate_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__Menu_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__TextArea_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__ProgressBar_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__ApplicationWindow_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__Frame_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__BusyIndicator_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__Dial_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _0x5f__ScrollView_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
        resourcePathToCachedUnit.insert(QStringLiteral("/DelayButton.qml"), &QmlCacheGeneratedCode::_0x5f__DelayButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/CheckDelegate.qml"), &QmlCacheGeneratedCode::_0x5f__CheckDelegate_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/Button.qml"), &QmlCacheGeneratedCode::_0x5f__Button_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/PageIndicator.qml"), &QmlCacheGeneratedCode::_0x5f__PageIndicator_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/MenuItem.qml"), &QmlCacheGeneratedCode::_0x5f__MenuItem_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/ScrollIndicator.qml"), &QmlCacheGeneratedCode::_0x5f__ScrollIndicator_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/SpinBox.qml"), &QmlCacheGeneratedCode::_0x5f__SpinBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/MenuSeparator.qml"), &QmlCacheGeneratedCode::_0x5f__MenuSeparator_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/ComboBox.qml"), &QmlCacheGeneratedCode::_0x5f__ComboBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/GroupBox.qml"), &QmlCacheGeneratedCode::_0x5f__GroupBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/DialogButtonBox.qml"), &QmlCacheGeneratedCode::_0x5f__DialogButtonBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/Control.qml"), &QmlCacheGeneratedCode::_0x5f__Control_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/Slider.qml"), &QmlCacheGeneratedCode::_0x5f__Slider_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/Popup.qml"), &QmlCacheGeneratedCode::_0x5f__Popup_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/ScrollBar.qml"), &QmlCacheGeneratedCode::_0x5f__ScrollBar_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/Pane.qml"), &QmlCacheGeneratedCode::_0x5f__Pane_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/StackView.qml"), &QmlCacheGeneratedCode::_0x5f__StackView_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/CheckBox.qml"), &QmlCacheGeneratedCode::_0x5f__CheckBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/Switch.qml"), &QmlCacheGeneratedCode::_0x5f__Switch_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/ToolTip.qml"), &QmlCacheGeneratedCode::_0x5f__ToolTip_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/RadioButton.qml"), &QmlCacheGeneratedCode::_0x5f__RadioButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/RoundButton.qml"), &QmlCacheGeneratedCode::_0x5f__RoundButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/TextField.qml"), &QmlCacheGeneratedCode::_0x5f__TextField_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/ItemDelegate.qml"), &QmlCacheGeneratedCode::_0x5f__ItemDelegate_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/Menu.qml"), &QmlCacheGeneratedCode::_0x5f__Menu_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/TextArea.qml"), &QmlCacheGeneratedCode::_0x5f__TextArea_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/ProgressBar.qml"), &QmlCacheGeneratedCode::_0x5f__ProgressBar_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/ApplicationWindow.qml"), &QmlCacheGeneratedCode::_0x5f__ApplicationWindow_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/Frame.qml"), &QmlCacheGeneratedCode::_0x5f__Frame_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/BusyIndicator.qml"), &QmlCacheGeneratedCode::_0x5f__BusyIndicator_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/Dial.qml"), &QmlCacheGeneratedCode::_0x5f__Dial_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/ScrollView.qml"), &QmlCacheGeneratedCode::_0x5f__ScrollView_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.version = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qml)() {
    ::unitRegistry();
    Q_INIT_RESOURCE(qml_qmlcache);
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qml))
int QT_MANGLE_NAMESPACE(qCleanupResources_qml)() {
    Q_CLEANUP_RESOURCE(qml_qmlcache);
    return 1;
}
