/****************************************************************************
** Meta object code from reading C++ file 'dquickwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/dquickwindow.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick12DQuickWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickWindow::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick12DQuickWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickWindow",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "DQuickWindow Attached.",
        "QML.Element",
        "DWindow",
        "QML.Attached",
        "DQuickWindowAttached"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<DQuickWindow, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick12DQuickWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick12DQuickWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick12DQuickWindowE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickWindow *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Dtk::Quick::DQuickWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick12DQuickWindowE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QQuickWindow::qt_metacast(_clname);
}

int Dtk::Quick::DQuickWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickWindow::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Dtk5Quick20DQuickWindowAttachedE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickWindowAttached::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick20DQuickWindowAttachedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickWindowAttached",
        "QML.Element",
        "anonymous",
        "enabledChanged",
        "",
        "windowRadiusChanged",
        "borderWidthChanged",
        "borderColorChanged",
        "shadowRadiusChanged",
        "shadowOffsetChanged",
        "shadowColorChanged",
        "translucentBackgroundChanged",
        "enableSystemResizeChanged",
        "enableSystemMoveChanged",
        "enableBlurWindowChanged",
        "wmWindowTypesChanged",
        "motifFunctionsChanged",
        "motifDecorationsChanged",
        "alphaBufferSizeChanged",
        "clipPathChanged",
        "overlayExitedChanged",
        "loadingOverlayChanged",
        "appLoaderChanged",
        "themeTypeChanged",
        "windowEffectChanged",
        "windowStartUpEffectChanged",
        "setEnabled",
        "e",
        "setWindowRadius",
        "windowRadius",
        "setBorderWidth",
        "borderWidth",
        "setBorderColor",
        "QColor",
        "borderColor",
        "setShadowRadius",
        "shadowRadius",
        "setShadowOffset",
        "QPoint",
        "shadowOffset",
        "setShadowColor",
        "shadowColor",
        "setTranslucentBackground",
        "translucentBackground",
        "setEnableSystemResize",
        "enableSystemResize",
        "setEnableSystemMove",
        "enableSystemMove",
        "setEnableBlurWindow",
        "enableBlurWindow",
        "setAlphaBufferSize",
        "size",
        "setWmWindowTypes",
        "Dtk::Gui::DWindowManagerHelper::WmWindowTypes",
        "wmWindowTypes",
        "setMotifFunctions",
        "Dtk::Gui::DWindowManagerHelper::MotifFunctions",
        "motifFunctions",
        "setMotifDecorations",
        "Dtk::Gui::DWindowManagerHelper::MotifDecorations",
        "motifDecorations",
        "popupSystemWindowMenu",
        "setWindowBlurAreaByWM",
        "QList<DPlatformHandle::WMBlurArea>",
        "area",
        "QList<QPainterPath>",
        "setClipPathByWM",
        "QPainterPath",
        "clipPath",
        "setClipPath",
        "QQuickPath*",
        "path",
        "setOverlayExited",
        "QQuickTransition*",
        "exit",
        "setLoadingOverlay",
        "QQmlComponent*",
        "component",
        "setWindowEffect",
        "Dtk::Gui::DPlatformHandle::EffectScenes",
        "effect",
        "setWindowStartUpEffect",
        "Dtk::Gui::DPlatformHandle::EffectTypes",
        "type",
        "showMinimized",
        "showMaximized",
        "showFullScreen",
        "showNormal",
        "_q_onWindowMotifHintsChanged",
        "_q_updateBlurAreaForWindow",
        "_q_updateClipPath",
        "_q_ensurePlatformHandle",
        "_q_onPaletteChanged",
        "_q_updateWindowPalette",
        "window",
        "QQuickWindow*",
        "enabled",
        "alphaBufferSize",
        "overlayExited",
        "loadingOverlay",
        "appLoader",
        "Dtk::Quick::DQuickAppLoaderItem*",
        "themeType",
        "Dtk::Gui::DGuiApplicationHelper::ColorType",
        "windowEffect",
        "Dtk::Gui::DPlatformHandle::EffectScene",
        "windowStartUpEffect",
        "Dtk::Gui::DPlatformHandle::EffectType"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowRadiusChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderWidthChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderColorChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowRadiusChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowOffsetChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowColorChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'translucentBackgroundChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableSystemResizeChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableSystemMoveChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableBlurWindowChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wmWindowTypesChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'motifFunctionsChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'motifDecorationsChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alphaBufferSizeChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipPathChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'overlayExitedChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingOverlayChanged'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appLoaderChanged'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'themeTypeChanged'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowEffectChanged'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowStartUpEffectChanged'
        QtMocHelpers::SignalData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setEnabled'
        QtMocHelpers::SlotData<void(bool)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setWindowRadius'
        QtMocHelpers::SlotData<void(int)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Slot 'setBorderWidth'
        QtMocHelpers::SlotData<void(int)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Slot 'setBorderColor'
        QtMocHelpers::SlotData<void(const QColor &)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'setShadowRadius'
        QtMocHelpers::SlotData<void(int)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Slot 'setShadowOffset'
        QtMocHelpers::SlotData<void(const QPoint &)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'setShadowColor'
        QtMocHelpers::SlotData<void(const QColor &)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 41 },
        }}),
        // Slot 'setTranslucentBackground'
        QtMocHelpers::SlotData<void(bool)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 43 },
        }}),
        // Slot 'setEnableSystemResize'
        QtMocHelpers::SlotData<void(bool)>(44, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'setEnableSystemMove'
        QtMocHelpers::SlotData<void(bool)>(46, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 47 },
        }}),
        // Slot 'setEnableBlurWindow'
        QtMocHelpers::SlotData<void(bool)>(48, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 49 },
        }}),
        // Slot 'setAlphaBufferSize'
        QtMocHelpers::SlotData<void(int)>(50, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 51 },
        }}),
        // Slot 'setWmWindowTypes'
        QtMocHelpers::SlotData<void(Dtk::Gui::DWindowManagerHelper::WmWindowTypes)>(52, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'setMotifFunctions'
        QtMocHelpers::SlotData<void(Dtk::Gui::DWindowManagerHelper::MotifFunctions)>(55, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Slot 'setMotifDecorations'
        QtMocHelpers::SlotData<void(Dtk::Gui::DWindowManagerHelper::MotifDecorations)>(58, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'popupSystemWindowMenu'
        QtMocHelpers::SlotData<void()>(61, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setWindowBlurAreaByWM'
        QtMocHelpers::SlotData<bool(const QVector<DPlatformHandle::WMBlurArea> &)>(62, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'setWindowBlurAreaByWM'
        QtMocHelpers::SlotData<bool(const QList<QPainterPath> &)>(62, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 65, 64 },
        }}),
        // Slot 'setClipPathByWM'
        QtMocHelpers::SlotData<void(const QPainterPath &)>(66, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 67, 68 },
        }}),
        // Slot 'setClipPath'
        QtMocHelpers::SlotData<void(QQuickPath *)>(69, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 70, 71 },
        }}),
        // Slot 'setOverlayExited'
        QtMocHelpers::SlotData<void(QQuickTransition *)>(72, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 73, 74 },
        }}),
        // Slot 'setLoadingOverlay'
        QtMocHelpers::SlotData<void(QQmlComponent *)>(75, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 76, 77 },
        }}),
        // Slot 'setWindowEffect'
        QtMocHelpers::SlotData<void(Dtk::Gui::DPlatformHandle::EffectScenes)>(78, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 79, 80 },
        }}),
        // Slot 'setWindowStartUpEffect'
        QtMocHelpers::SlotData<void(Dtk::Gui::DPlatformHandle::EffectTypes)>(81, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 82, 83 },
        }}),
        // Slot 'showMinimized'
        QtMocHelpers::SlotData<void()>(84, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showMaximized'
        QtMocHelpers::SlotData<void()>(85, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showFullScreen'
        QtMocHelpers::SlotData<void()>(86, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showNormal'
        QtMocHelpers::SlotData<void()>(87, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot '_q_onWindowMotifHintsChanged'
        QtMocHelpers::SlotData<void(quint32)>(88, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 4 },
        }}),
        // Slot '_q_updateBlurAreaForWindow'
        QtMocHelpers::SlotData<void()>(89, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_updateClipPath'
        QtMocHelpers::SlotData<void()>(90, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_ensurePlatformHandle'
        QtMocHelpers::SlotData<void()>(91, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_onPaletteChanged'
        QtMocHelpers::SlotData<void()>(92, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_updateWindowPalette'
        QtMocHelpers::SlotData<void()>(93, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'window'
        QtMocHelpers::PropertyData<QQuickWindow*>(94, 0x80000000 | 95, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'windowRadius'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'borderWidth'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'borderColor'
        QtMocHelpers::PropertyData<QColor>(34, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'shadowRadius'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'shadowOffset'
        QtMocHelpers::PropertyData<QPoint>(39, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'shadowColor'
        QtMocHelpers::PropertyData<QColor>(41, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'translucentBackground'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'enableSystemResize'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'enableSystemMove'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'enableBlurWindow'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'alphaBufferSize'
        QtMocHelpers::PropertyData<int>(97, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'clipPath'
        QtMocHelpers::PropertyData<QQuickPath*>(68, 0x80000000 | 70, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 15),
        // property 'wmWindowTypes'
        QtMocHelpers::PropertyData<Dtk::Gui::DWindowManagerHelper::WmWindowTypes>(54, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'motifFunctions'
        QtMocHelpers::PropertyData<Dtk::Gui::DWindowManagerHelper::MotifFunctions>(57, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
        // property 'motifDecorations'
        QtMocHelpers::PropertyData<Dtk::Gui::DWindowManagerHelper::MotifDecorations>(60, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'overlayExited'
        QtMocHelpers::PropertyData<QQuickTransition*>(98, 0x80000000 | 73, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 16),
        // property 'loadingOverlay'
        QtMocHelpers::PropertyData<QQmlComponent*>(99, 0x80000000 | 76, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 17),
        // property 'appLoader'
        QtMocHelpers::PropertyData<Dtk::Quick::DQuickAppLoaderItem*>(100, 0x80000000 | 101, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 18),
        // property 'themeType'
        QtMocHelpers::PropertyData<Dtk::Gui::DGuiApplicationHelper::ColorType>(102, 0x80000000 | 103, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 19),
        // property 'windowEffect'
        QtMocHelpers::PropertyData<Dtk::Gui::DPlatformHandle::EffectScene>(104, 0x80000000 | 105, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 20),
        // property 'windowStartUpEffect'
        QtMocHelpers::PropertyData<Dtk::Gui::DPlatformHandle::EffectType>(106, 0x80000000 | 107, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 21),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DQuickWindowAttached, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3Dtk5Quick20DQuickWindowAttachedE[] = {
    QMetaObject::SuperData::link<Dtk::Gui::DWindowManagerHelper::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Gui::DGuiApplicationHelper::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Gui::DPlatformHandle::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickWindowAttached::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick20DQuickWindowAttachedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick20DQuickWindowAttachedE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3Dtk5Quick20DQuickWindowAttachedE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick20DQuickWindowAttachedE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickWindowAttached::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickWindowAttached *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->windowRadiusChanged(); break;
        case 2: _t->borderWidthChanged(); break;
        case 3: _t->borderColorChanged(); break;
        case 4: _t->shadowRadiusChanged(); break;
        case 5: _t->shadowOffsetChanged(); break;
        case 6: _t->shadowColorChanged(); break;
        case 7: _t->translucentBackgroundChanged(); break;
        case 8: _t->enableSystemResizeChanged(); break;
        case 9: _t->enableSystemMoveChanged(); break;
        case 10: _t->enableBlurWindowChanged(); break;
        case 11: _t->wmWindowTypesChanged(); break;
        case 12: _t->motifFunctionsChanged(); break;
        case 13: _t->motifDecorationsChanged(); break;
        case 14: _t->alphaBufferSizeChanged(); break;
        case 15: _t->clipPathChanged(); break;
        case 16: _t->overlayExitedChanged(); break;
        case 17: _t->loadingOverlayChanged(); break;
        case 18: _t->appLoaderChanged(); break;
        case 19: _t->themeTypeChanged(); break;
        case 20: _t->windowEffectChanged(); break;
        case 21: _t->windowStartUpEffectChanged(); break;
        case 22: _t->setEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->setWindowRadius((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->setBorderWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->setBorderColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 26: _t->setShadowRadius((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->setShadowOffset((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 28: _t->setShadowColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 29: _t->setTranslucentBackground((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->setEnableSystemResize((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->setEnableSystemMove((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->setEnableBlurWindow((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->setAlphaBufferSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->setWmWindowTypes((*reinterpret_cast<std::add_pointer_t<Dtk::Gui::DWindowManagerHelper::WmWindowTypes>>(_a[1]))); break;
        case 35: _t->setMotifFunctions((*reinterpret_cast<std::add_pointer_t<Dtk::Gui::DWindowManagerHelper::MotifFunctions>>(_a[1]))); break;
        case 36: _t->setMotifDecorations((*reinterpret_cast<std::add_pointer_t<Dtk::Gui::DWindowManagerHelper::MotifDecorations>>(_a[1]))); break;
        case 37: _t->popupSystemWindowMenu(); break;
        case 38: { bool _r = _t->setWindowBlurAreaByWM((*reinterpret_cast<std::add_pointer_t<QList<DPlatformHandle::WMBlurArea>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: { bool _r = _t->setWindowBlurAreaByWM((*reinterpret_cast<std::add_pointer_t<QList<QPainterPath>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 40: _t->setClipPathByWM((*reinterpret_cast<std::add_pointer_t<QPainterPath>>(_a[1]))); break;
        case 41: _t->setClipPath((*reinterpret_cast<std::add_pointer_t<QQuickPath*>>(_a[1]))); break;
        case 42: _t->setOverlayExited((*reinterpret_cast<std::add_pointer_t<QQuickTransition*>>(_a[1]))); break;
        case 43: _t->setLoadingOverlay((*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[1]))); break;
        case 44: _t->setWindowEffect((*reinterpret_cast<std::add_pointer_t<Dtk::Gui::DPlatformHandle::EffectScenes>>(_a[1]))); break;
        case 45: _t->setWindowStartUpEffect((*reinterpret_cast<std::add_pointer_t<Dtk::Gui::DPlatformHandle::EffectTypes>>(_a[1]))); break;
        case 46: _t->showMinimized(); break;
        case 47: _t->showMaximized(); break;
        case 48: _t->showFullScreen(); break;
        case 49: _t->showNormal(); break;
        case 50: _t->d_func()->_q_onWindowMotifHintsChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 51: _t->d_func()->_q_updateBlurAreaForWindow(); break;
        case 52: _t->d_func()->_q_updateClipPath(); break;
        case 53: _t->d_func()->_q_ensurePlatformHandle(); break;
        case 54: _t->d_func()->_q_onPaletteChanged(); break;
        case 55: _t->d_func()->_q_updateWindowPalette(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::windowRadiusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::borderWidthChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::borderColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::shadowRadiusChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::shadowOffsetChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::shadowColorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::translucentBackgroundChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::enableSystemResizeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::enableSystemMoveChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::enableBlurWindowChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::wmWindowTypesChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::motifFunctionsChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::motifDecorationsChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::alphaBufferSizeChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::clipPathChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::overlayExitedChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::loadingOverlayChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::appLoaderChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::themeTypeChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::windowEffectChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickWindowAttached::*)()>(_a, &DQuickWindowAttached::windowStartUpEffectChanged, 21))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickWindow* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickWindow**>(_v) = _t->window(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->windowRadius(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->borderWidth(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->borderColor(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->shadowRadius(); break;
        case 6: *reinterpret_cast<QPoint*>(_v) = _t->shadowOffset(); break;
        case 7: *reinterpret_cast<QColor*>(_v) = _t->shadowColor(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->translucentBackground(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->enableSystemResize(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->enableSystemMove(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->enableBlurWindow(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->alphaBufferSize(); break;
        case 13: *reinterpret_cast<QQuickPath**>(_v) = _t->clipPath(); break;
        case 14: *reinterpret_cast<Dtk::Gui::DWindowManagerHelper::WmWindowTypes*>(_v) = _t->wmWindowTypes(); break;
        case 15: *reinterpret_cast<Dtk::Gui::DWindowManagerHelper::MotifFunctions*>(_v) = _t->motifFunctions(); break;
        case 16: *reinterpret_cast<Dtk::Gui::DWindowManagerHelper::MotifDecorations*>(_v) = _t->motifDecorations(); break;
        case 17: *reinterpret_cast<QQuickTransition**>(_v) = _t->overlayExited(); break;
        case 18: *reinterpret_cast<QQmlComponent**>(_v) = _t->loadingOverlay(); break;
        case 19: *reinterpret_cast<Dtk::Quick::DQuickAppLoaderItem**>(_v) = _t->appLoader(); break;
        case 20: *reinterpret_cast<Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v) = _t->themeType(); break;
        case 21: *reinterpret_cast<Dtk::Gui::DPlatformHandle::EffectScene*>(_v) = _t->windowEffect(); break;
        case 22: *reinterpret_cast<Dtk::Gui::DPlatformHandle::EffectType*>(_v) = _t->windowStartUpEffect(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setWindowRadius(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setBorderWidth(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setBorderColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setShadowRadius(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setShadowOffset(*reinterpret_cast<QPoint*>(_v)); break;
        case 7: _t->setShadowColor(*reinterpret_cast<QColor*>(_v)); break;
        case 8: _t->setTranslucentBackground(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setEnableSystemResize(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setEnableSystemMove(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setEnableBlurWindow(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setAlphaBufferSize(*reinterpret_cast<int*>(_v)); break;
        case 13: _t->setClipPath(*reinterpret_cast<QQuickPath**>(_v)); break;
        case 14: _t->setWmWindowTypes(*reinterpret_cast<Dtk::Gui::DWindowManagerHelper::WmWindowTypes*>(_v)); break;
        case 15: _t->setMotifFunctions(*reinterpret_cast<Dtk::Gui::DWindowManagerHelper::MotifFunctions*>(_v)); break;
        case 16: _t->setMotifDecorations(*reinterpret_cast<Dtk::Gui::DWindowManagerHelper::MotifDecorations*>(_v)); break;
        case 17: _t->setOverlayExited(*reinterpret_cast<QQuickTransition**>(_v)); break;
        case 18: _t->setLoadingOverlay(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 20: _t->setThemeType(*reinterpret_cast<Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v)); break;
        case 21: _t->setWindowEffect(*reinterpret_cast<Dtk::Gui::DPlatformHandle::EffectScene*>(_v)); break;
        case 22: _t->setWindowStartUpEffect(*reinterpret_cast<Dtk::Gui::DPlatformHandle::EffectType*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 20: _t->resetThemeType(); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::DQuickWindowAttached::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickWindowAttached::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick20DQuickWindowAttachedE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DQuickWindowAttached::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 56)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 56;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 56)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 56;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickWindowAttached::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickWindowAttached::windowRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickWindowAttached::borderWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickWindowAttached::borderColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickWindowAttached::shadowRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickWindowAttached::shadowOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQuickWindowAttached::shadowColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Quick::DQuickWindowAttached::translucentBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Quick::DQuickWindowAttached::enableSystemResizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Dtk::Quick::DQuickWindowAttached::enableSystemMoveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Dtk::Quick::DQuickWindowAttached::enableBlurWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Dtk::Quick::DQuickWindowAttached::wmWindowTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Dtk::Quick::DQuickWindowAttached::motifFunctionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Dtk::Quick::DQuickWindowAttached::motifDecorationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Dtk::Quick::DQuickWindowAttached::alphaBufferSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Dtk::Quick::DQuickWindowAttached::clipPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Dtk::Quick::DQuickWindowAttached::overlayExitedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Dtk::Quick::DQuickWindowAttached::loadingOverlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Dtk::Quick::DQuickWindowAttached::appLoaderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Dtk::Quick::DQuickWindowAttached::themeTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Dtk::Quick::DQuickWindowAttached::windowEffectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Dtk::Quick::DQuickWindowAttached::windowStartUpEffectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}
QT_WARNING_POP
