/****************************************************************************
** Meta object code from reading C++ file 'dquickdciicon_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/private/dquickdciicon_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickdciicon_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__DQuickDciIcon_t {
    QByteArrayData data[12];
    char stringdata0[198];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickDciIcon_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickDciIcon_t qt_meta_stringdata_Dtk__Quick__DQuickDciIcon = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Dtk::Quick::DQuickDciIcon"
QT_MOC_LITERAL(1, 26, 4), // "name"
QT_MOC_LITERAL(2, 31, 5), // "width"
QT_MOC_LITERAL(3, 37, 6), // "height"
QT_MOC_LITERAL(4, 44, 4), // "mode"
QT_MOC_LITERAL(5, 49, 42), // "Dtk::Quick::DQMLGlobalObject:..."
QT_MOC_LITERAL(6, 92, 5), // "theme"
QT_MOC_LITERAL(7, 98, 42), // "Dtk::Gui::DGuiApplicationHelp..."
QT_MOC_LITERAL(8, 141, 7), // "palette"
QT_MOC_LITERAL(9, 149, 25), // "Dtk::Gui::DDciIconPalette"
QT_MOC_LITERAL(10, 175, 6), // "source"
QT_MOC_LITERAL(11, 182, 15) // "fallbackToQIcon"

    },
    "Dtk::Quick::DQuickDciIcon\0name\0width\0"
    "height\0mode\0Dtk::Quick::DQMLGlobalObject::ControlState\0"
    "theme\0Dtk::Gui::DGuiApplicationHelper::ColorType\0"
    "palette\0Dtk::Gui::DDciIconPalette\0"
    "source\0fallbackToQIcon"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickDciIcon[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       8,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::QString, 0x00095907,
       2, QMetaType::Int, 0x00095907,
       3, QMetaType::Int, 0x00095907,
       4, 0x80000000 | 5, 0x0009590f,
       6, 0x80000000 | 7, 0x0009590f,
       8, 0x80000000 | 9, 0x0009590f,
      10, QMetaType::QUrl, 0x00095907,
      11, QMetaType::Bool, 0x00095107,

       0        // eod
};

void Dtk::Quick::DQuickDciIcon::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = reinterpret_cast<DQuickDciIcon *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->width(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->height(); break;
        case 3: *reinterpret_cast< Dtk::Quick::DQMLGlobalObject::ControlState*>(_v) = _t->mode(); break;
        case 4: *reinterpret_cast< Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v) = _t->theme(); break;
        case 5: *reinterpret_cast< Dtk::Gui::DDciIconPalette*>(_v) = _t->palette(); break;
        case 6: *reinterpret_cast< QUrl*>(_v) = _t->source(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->fallbackToQIcon(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = reinterpret_cast<DQuickDciIcon *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setWidth(*reinterpret_cast< int*>(_v)); break;
        case 2: _t->setHeight(*reinterpret_cast< int*>(_v)); break;
        case 3: _t->setMode(*reinterpret_cast< Dtk::Quick::DQMLGlobalObject::ControlState*>(_v)); break;
        case 4: _t->setTheme(*reinterpret_cast< Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v)); break;
        case 5: _t->setPalette(*reinterpret_cast< Dtk::Gui::DDciIconPalette*>(_v)); break;
        case 6: _t->setSource(*reinterpret_cast< QUrl*>(_v)); break;
        case 7: _t->setFallbackToQIcon(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
        DQuickDciIcon *_t = reinterpret_cast<DQuickDciIcon *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->resetName(); break;
        case 1: _t->resetWidth(); break;
        case 2: _t->resetHeight(); break;
        case 3: _t->resetMode(); break;
        case 4: _t->resetTheme(); break;
        case 5: _t->resetTheme(); break;
        case 6: _t->resetSource(); break;
        case 7: _t->resetFallbackToQIcon(); break;
        default: break;
        }
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

static const QMetaObject::SuperData qt_meta_extradata_Dtk__Quick__DQuickDciIcon[] = {
    QMetaObject::SuperData::link<Dtk::Quick::DQMLGlobalObject::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Gui::DGuiApplicationHelper::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickDciIcon::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_Dtk__Quick__DQuickDciIcon.data,
    qt_meta_data_Dtk__Quick__DQuickDciIcon,
    qt_static_metacall,
    qt_meta_extradata_Dtk__Quick__DQuickDciIcon,
    nullptr
} };

QT_WARNING_POP
QT_END_MOC_NAMESPACE
