/****************************************************************************
** Meta object code from reading C++ file 'dqmlglobalobject_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/private/dqmlglobalobject_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dqmlglobalobject_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__DColor_t {
    QByteArrayData data[14];
    char stringdata0[125];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DColor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DColor_t qt_meta_stringdata_Dtk__Quick__DColor = {
    {
QT_MOC_LITERAL(0, 0, 18), // "Dtk::Quick::DColor"
QT_MOC_LITERAL(1, 19, 7), // "toColor"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 7), // "palette"
QT_MOC_LITERAL(4, 36, 5), // "color"
QT_MOC_LITERAL(5, 42, 3), // "hue"
QT_MOC_LITERAL(6, 46, 10), // "floatValue"
QT_MOC_LITERAL(7, 57, 10), // "saturation"
QT_MOC_LITERAL(8, 68, 9), // "lightness"
QT_MOC_LITERAL(9, 78, 7), // "opacity"
QT_MOC_LITERAL(10, 86, 4), // "Type"
QT_MOC_LITERAL(11, 91, 7), // "Invalid"
QT_MOC_LITERAL(12, 99, 9), // "Highlight"
QT_MOC_LITERAL(13, 109, 15) // "HighlightedText"

    },
    "Dtk::Quick::DColor\0toColor\0\0palette\0"
    "color\0hue\0floatValue\0saturation\0"
    "lightness\0opacity\0Type\0Invalid\0Highlight\0"
    "HighlightedText"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DColor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       1,   60, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x02 /* Public */,
       4,    0,   47,    2, 0x02 /* Public */,
       5,    1,   48,    2, 0x02 /* Public */,
       7,    1,   51,    2, 0x02 /* Public */,
       8,    1,   54,    2, 0x02 /* Public */,
       9,    1,   57,    2, 0x02 /* Public */,

 // methods: parameters
    QMetaType::QColor, QMetaType::QPalette,    3,
    QMetaType::QColor,
    0x80000000 | 0, QMetaType::SChar,    6,
    0x80000000 | 0, QMetaType::SChar,    6,
    0x80000000 | 0, QMetaType::SChar,    6,
    0x80000000 | 0, QMetaType::SChar,    6,

 // enums: name, alias, flags, count, data
      10,   10, 0x0,    3,   65,

 // enum data: key, value
      11, uint(Dtk::Quick::DColor::Invalid),
      12, uint(Dtk::Quick::DColor::Highlight),
      13, uint(Dtk::Quick::DColor::HighlightedText),

       0        // eod
};

void Dtk::Quick::DColor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = reinterpret_cast<DColor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QColor _r = _t->toColor((*reinterpret_cast< const QPalette(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QColor*>(_a[0]) = std::move(_r); }  break;
        case 1: { QColor _r = _t->color();
            if (_a[0]) *reinterpret_cast< QColor*>(_a[0]) = std::move(_r); }  break;
        case 2: { Dtk::Quick::DColor _r = _t->hue((*reinterpret_cast< qint8(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Dtk::Quick::DColor*>(_a[0]) = std::move(_r); }  break;
        case 3: { Dtk::Quick::DColor _r = _t->saturation((*reinterpret_cast< qint8(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Dtk::Quick::DColor*>(_a[0]) = std::move(_r); }  break;
        case 4: { Dtk::Quick::DColor _r = _t->lightness((*reinterpret_cast< qint8(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Dtk::Quick::DColor*>(_a[0]) = std::move(_r); }  break;
        case 5: { Dtk::Quick::DColor _r = _t->opacity((*reinterpret_cast< qint8(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Dtk::Quick::DColor*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DColor::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_Dtk__Quick__DColor.data,
    qt_meta_data_Dtk__Quick__DColor,
    qt_static_metacall,
    nullptr,
    nullptr
} };

struct qt_meta_stringdata_Dtk__Quick__DQMLGlobalObject_t {
    QByteArrayData data[96];
    char stringdata0[1348];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQMLGlobalObject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQMLGlobalObject_t qt_meta_stringdata_Dtk__Quick__DQMLGlobalObject = {
    {
QT_MOC_LITERAL(0, 0, 28), // "Dtk::Quick::DQMLGlobalObject"
QT_MOC_LITERAL(1, 29, 20), // "hasBlurWindowChanged"
QT_MOC_LITERAL(2, 50, 0), // ""
QT_MOC_LITERAL(3, 51, 19), // "hasCompositeChanged"
QT_MOC_LITERAL(4, 71, 20), // "hasNoTitlebarChanged"
QT_MOC_LITERAL(5, 92, 19), // "hasAnimationChanged"
QT_MOC_LITERAL(6, 112, 22), // "hasInWindowBlurChanged"
QT_MOC_LITERAL(7, 135, 14), // "paletteChanged"
QT_MOC_LITERAL(8, 150, 22), // "inactivePaletteChanged"
QT_MOC_LITERAL(9, 173, 16), // "themeTypeChanged"
QT_MOC_LITERAL(10, 190, 42), // "Dtk::Gui::DGuiApplicationHelp..."
QT_MOC_LITERAL(11, 233, 9), // "themeType"
QT_MOC_LITERAL(12, 243, 19), // "_q_onPaletteChanged"
QT_MOC_LITERAL(13, 263, 10), // "blendColor"
QT_MOC_LITERAL(14, 274, 9), // "substrate"
QT_MOC_LITERAL(15, 284, 12), // "superstratum"
QT_MOC_LITERAL(16, 297, 9), // "makeColor"
QT_MOC_LITERAL(17, 307, 18), // "Dtk::Quick::DColor"
QT_MOC_LITERAL(18, 326, 24), // "Dtk::Quick::DColor::Type"
QT_MOC_LITERAL(19, 351, 4), // "type"
QT_MOC_LITERAL(20, 356, 5), // "color"
QT_MOC_LITERAL(21, 362, 18), // "makeShadowImageUrl"
QT_MOC_LITERAL(22, 381, 7), // "boxSize"
QT_MOC_LITERAL(23, 389, 12), // "cornerRadius"
QT_MOC_LITERAL(24, 402, 10), // "shadowBlur"
QT_MOC_LITERAL(25, 413, 7), // "xOffset"
QT_MOC_LITERAL(26, 421, 7), // "yOffset"
QT_MOC_LITERAL(27, 429, 6), // "spread"
QT_MOC_LITERAL(28, 436, 6), // "hollow"
QT_MOC_LITERAL(29, 443, 5), // "inner"
QT_MOC_LITERAL(30, 449, 13), // "topLeftRadius"
QT_MOC_LITERAL(31, 463, 14), // "topRightRadius"
QT_MOC_LITERAL(32, 478, 16), // "bottomLeftRadius"
QT_MOC_LITERAL(33, 495, 17), // "bottomRightRadius"
QT_MOC_LITERAL(34, 513, 11), // "toColorType"
QT_MOC_LITERAL(35, 525, 11), // "selectColor"
QT_MOC_LITERAL(36, 537, 11), // "windowColor"
QT_MOC_LITERAL(37, 549, 5), // "light"
QT_MOC_LITERAL(38, 555, 4), // "dark"
QT_MOC_LITERAL(39, 560, 14), // "cursorPosition"
QT_MOC_LITERAL(40, 575, 8), // "makeIcon"
QT_MOC_LITERAL(41, 584, 25), // "Dtk::Quick::DQuickDciIcon"
QT_MOC_LITERAL(42, 610, 8), // "QJSValue"
QT_MOC_LITERAL(43, 619, 5), // "qicon"
QT_MOC_LITERAL(44, 625, 9), // "iconExtra"
QT_MOC_LITERAL(45, 635, 15), // "makeIconPalette"
QT_MOC_LITERAL(46, 651, 25), // "Dtk::Gui::DDciIconPalette"
QT_MOC_LITERAL(47, 677, 7), // "palette"
QT_MOC_LITERAL(48, 685, 11), // "sendMessage"
QT_MOC_LITERAL(49, 697, 6), // "target"
QT_MOC_LITERAL(50, 704, 7), // "content"
QT_MOC_LITERAL(51, 712, 8), // "iconName"
QT_MOC_LITERAL(52, 721, 8), // "duration"
QT_MOC_LITERAL(53, 730, 5), // "msgId"
QT_MOC_LITERAL(54, 736, 14), // "QQmlComponent*"
QT_MOC_LITERAL(55, 751, 8), // "delegate"
QT_MOC_LITERAL(56, 760, 7), // "message"
QT_MOC_LITERAL(57, 768, 12), // "closeMessage"
QT_MOC_LITERAL(58, 781, 37), // "Dtk::Quick::FloatingMessageCo..."
QT_MOC_LITERAL(59, 819, 17), // "sendSystemMessage"
QT_MOC_LITERAL(60, 837, 7), // "summary"
QT_MOC_LITERAL(61, 845, 4), // "body"
QT_MOC_LITERAL(62, 850, 7), // "appIcon"
QT_MOC_LITERAL(63, 858, 7), // "actions"
QT_MOC_LITERAL(64, 866, 5), // "hints"
QT_MOC_LITERAL(65, 872, 7), // "timeout"
QT_MOC_LITERAL(66, 880, 9), // "replaceId"
QT_MOC_LITERAL(67, 890, 13), // "hasBlurWindow"
QT_MOC_LITERAL(68, 904, 12), // "hasComposite"
QT_MOC_LITERAL(69, 917, 13), // "hasNoTitlebar"
QT_MOC_LITERAL(70, 931, 12), // "hasAnimation"
QT_MOC_LITERAL(71, 944, 15), // "hasInWindowBlur"
QT_MOC_LITERAL(72, 960, 16), // "isSoftwareRender"
QT_MOC_LITERAL(73, 977, 17), // "windowManagerName"
QT_MOC_LITERAL(74, 995, 38), // "Dtk::Gui::DWindowManagerHelpe..."
QT_MOC_LITERAL(75, 1034, 23), // "windowManagerNameString"
QT_MOC_LITERAL(76, 1058, 13), // "platformTheme"
QT_MOC_LITERAL(77, 1072, 20), // "DPlatformThemeProxy*"
QT_MOC_LITERAL(78, 1093, 11), // "fontManager"
QT_MOC_LITERAL(79, 1105, 23), // "Dtk::Gui::DFontManager*"
QT_MOC_LITERAL(80, 1129, 15), // "inactivePalette"
QT_MOC_LITERAL(81, 1145, 25), // "deepinDistributionOrgLogo"
QT_MOC_LITERAL(82, 1171, 17), // "deepinWebsiteName"
QT_MOC_LITERAL(83, 1189, 17), // "deepinWebsiteLink"
QT_MOC_LITERAL(84, 1207, 12), // "ControlState"
QT_MOC_LITERAL(85, 1220, 11), // "NormalState"
QT_MOC_LITERAL(86, 1232, 12), // "HoveredState"
QT_MOC_LITERAL(87, 1245, 12), // "PressedState"
QT_MOC_LITERAL(88, 1258, 13), // "DisabledState"
QT_MOC_LITERAL(89, 1272, 13), // "InactiveState"
QT_MOC_LITERAL(90, 1286, 6), // "ZOrder"
QT_MOC_LITERAL(91, 1293, 11), // "BottomOrder"
QT_MOC_LITERAL(92, 1305, 10), // "BelowOrder"
QT_MOC_LITERAL(93, 1316, 11), // "NormalOrder"
QT_MOC_LITERAL(94, 1328, 10), // "AboveOrder"
QT_MOC_LITERAL(95, 1339, 8) // "TopOrder"

    },
    "Dtk::Quick::DQMLGlobalObject\0"
    "hasBlurWindowChanged\0\0hasCompositeChanged\0"
    "hasNoTitlebarChanged\0hasAnimationChanged\0"
    "hasInWindowBlurChanged\0paletteChanged\0"
    "inactivePaletteChanged\0themeTypeChanged\0"
    "Dtk::Gui::DGuiApplicationHelper::ColorType\0"
    "themeType\0_q_onPaletteChanged\0blendColor\0"
    "substrate\0superstratum\0makeColor\0"
    "Dtk::Quick::DColor\0Dtk::Quick::DColor::Type\0"
    "type\0color\0makeShadowImageUrl\0boxSize\0"
    "cornerRadius\0shadowBlur\0xOffset\0yOffset\0"
    "spread\0hollow\0inner\0topLeftRadius\0"
    "topRightRadius\0bottomLeftRadius\0"
    "bottomRightRadius\0toColorType\0selectColor\0"
    "windowColor\0light\0dark\0cursorPosition\0"
    "makeIcon\0Dtk::Quick::DQuickDciIcon\0"
    "QJSValue\0qicon\0iconExtra\0makeIconPalette\0"
    "Dtk::Gui::DDciIconPalette\0palette\0"
    "sendMessage\0target\0content\0iconName\0"
    "duration\0msgId\0QQmlComponent*\0delegate\0"
    "message\0closeMessage\0"
    "Dtk::Quick::FloatingMessageContainer*\0"
    "sendSystemMessage\0summary\0body\0appIcon\0"
    "actions\0hints\0timeout\0replaceId\0"
    "hasBlurWindow\0hasComposite\0hasNoTitlebar\0"
    "hasAnimation\0hasInWindowBlur\0"
    "isSoftwareRender\0windowManagerName\0"
    "Dtk::Gui::DWindowManagerHelper::WMName\0"
    "windowManagerNameString\0platformTheme\0"
    "DPlatformThemeProxy*\0fontManager\0"
    "Dtk::Gui::DFontManager*\0inactivePalette\0"
    "deepinDistributionOrgLogo\0deepinWebsiteName\0"
    "deepinWebsiteLink\0ControlState\0"
    "NormalState\0HoveredState\0PressedState\0"
    "DisabledState\0InactiveState\0ZOrder\0"
    "BottomOrder\0BelowOrder\0NormalOrder\0"
    "AboveOrder\0TopOrder"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQMLGlobalObject[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      35,   14, // methods
      16,  404, // properties
       2,  468, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  189,    2, 0x06 /* Public */,
       3,    0,  190,    2, 0x06 /* Public */,
       4,    0,  191,    2, 0x06 /* Public */,
       5,    0,  192,    2, 0x06 /* Public */,
       6,    0,  193,    2, 0x06 /* Public */,
       7,    0,  194,    2, 0x06 /* Public */,
       8,    0,  195,    2, 0x06 /* Public */,
       9,    1,  196,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    0,  199,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      13,    2,  200,    2, 0x02 /* Public */,
      16,    1,  205,    2, 0x02 /* Public */,
      16,    1,  208,    2, 0x02 /* Public */,
      21,    9,  211,    2, 0x02 /* Public */,
      21,   12,  230,    2, 0x02 /* Public */,
      34,    1,  255,    2, 0x02 /* Public */,
      35,    3,  258,    2, 0x02 /* Public */,
      39,    0,  265,    2, 0x02 /* Public */,
      40,    2,  266,    2, 0x02 /* Public */,
      45,    1,  271,    2, 0x02 /* Public */,
      48,    5,  274,    2, 0x02 /* Public */,
      48,    4,  285,    2, 0x22 /* Public | MethodCloned */,
      48,    3,  294,    2, 0x22 /* Public | MethodCloned */,
      48,    2,  301,    2, 0x22 /* Public | MethodCloned */,
      48,    5,  306,    2, 0x02 /* Public */,
      48,    4,  317,    2, 0x22 /* Public | MethodCloned */,
      48,    3,  326,    2, 0x22 /* Public | MethodCloned */,
      57,    1,  333,    2, 0x02 /* Public */,
      57,    2,  336,    2, 0x02 /* Public */,
      59,    7,  341,    2, 0x02 /* Public */,
      59,    6,  356,    2, 0x22 /* Public | MethodCloned */,
      59,    5,  369,    2, 0x22 /* Public | MethodCloned */,
      59,    4,  380,    2, 0x22 /* Public | MethodCloned */,
      59,    3,  389,    2, 0x22 /* Public | MethodCloned */,
      59,    2,  396,    2, 0x22 /* Public | MethodCloned */,
      59,    1,  401,    2, 0x22 /* Public | MethodCloned */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,   11,

 // slots: parameters
    QMetaType::Void,

 // methods: parameters
    QMetaType::QColor, QMetaType::QColor, QMetaType::QColor,   14,   15,
    0x80000000 | 17, 0x80000000 | 18,   19,
    0x80000000 | 17, QMetaType::QColor,   20,
    QMetaType::QUrl, QMetaType::QReal, QMetaType::QReal, QMetaType::QReal, QMetaType::QColor, QMetaType::QReal, QMetaType::QReal, QMetaType::QReal, QMetaType::Bool, QMetaType::Bool,   22,   23,   24,   20,   25,   26,   27,   28,   29,
    QMetaType::QUrl, QMetaType::QReal, QMetaType::QReal, QMetaType::QReal, QMetaType::QReal, QMetaType::QReal, QMetaType::QReal, QMetaType::QColor, QMetaType::QReal, QMetaType::QReal, QMetaType::QReal, QMetaType::Bool, QMetaType::Bool,   22,   30,   31,   32,   33,   24,   20,   25,   26,   27,   28,   29,
    0x80000000 | 10, QMetaType::QColor,   20,
    QMetaType::QColor, QMetaType::QColor, QMetaType::QColor, QMetaType::QColor,   36,   37,   38,
    QMetaType::QPoint,
    0x80000000 | 41, 0x80000000 | 42, 0x80000000 | 42,   43,   44,
    0x80000000 | 46, QMetaType::QPalette,   47,
    QMetaType::Bool, QMetaType::QObjectStar, QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::QString,   49,   50,   51,   52,   53,
    QMetaType::Bool, QMetaType::QObjectStar, QMetaType::QString, QMetaType::QString, QMetaType::Int,   49,   50,   51,   52,
    QMetaType::Bool, QMetaType::QObjectStar, QMetaType::QString, QMetaType::QString,   49,   50,   51,
    QMetaType::Bool, QMetaType::QObjectStar, QMetaType::QString,   49,   50,
    QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 54, QMetaType::QVariant, QMetaType::Int, QMetaType::QString,   49,   55,   56,   52,   53,
    QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 54, QMetaType::QVariant, QMetaType::Int,   49,   55,   56,   52,
    QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 54, QMetaType::QVariant,   49,   55,   56,
    QMetaType::Void, 0x80000000 | 58,   56,
    QMetaType::Void, QMetaType::QObjectStar, QMetaType::QString,   49,   53,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QStringList, QMetaType::QVariantMap, QMetaType::Int, QMetaType::UInt,   60,   61,   62,   63,   64,   65,   66,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QStringList, QMetaType::QVariantMap, QMetaType::Int,   60,   61,   62,   63,   64,   65,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QStringList, QMetaType::QVariantMap,   60,   61,   62,   63,   64,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QStringList,   60,   61,   62,   63,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,   60,   61,   62,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   60,   61,
    QMetaType::Void, QMetaType::QString,   60,

 // properties: name, type, flags
      67, QMetaType::Bool, 0x00495001,
      68, QMetaType::Bool, 0x00495001,
      69, QMetaType::Bool, 0x00495001,
      70, QMetaType::Bool, 0x00495001,
      71, QMetaType::Bool, 0x00495001,
      72, QMetaType::Bool, 0x00095c01,
      73, 0x80000000 | 74, 0x00095409,
      11, 0x80000000 | 10, 0x00495009,
      75, QMetaType::QString, 0x00095401,
      76, 0x80000000 | 77, 0x00095c09,
      78, 0x80000000 | 79, 0x00095c09,
      47, QMetaType::QPalette, 0x00495001,
      80, QMetaType::QPalette, 0x00495001,
      81, QMetaType::QString, 0x00095401,
      82, QMetaType::QString, 0x00095401,
      83, QMetaType::QString, 0x00095401,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       0,
       0,
       7,
       0,
       0,
       0,
       5,
       6,
       0,
       0,
       0,

 // enums: name, alias, flags, count, data
      84,   84, 0x0,    5,  478,
      90,   90, 0x0,    5,  488,

 // enum data: key, value
      85, uint(Dtk::Quick::DQMLGlobalObject::NormalState),
      86, uint(Dtk::Quick::DQMLGlobalObject::HoveredState),
      87, uint(Dtk::Quick::DQMLGlobalObject::PressedState),
      88, uint(Dtk::Quick::DQMLGlobalObject::DisabledState),
      89, uint(Dtk::Quick::DQMLGlobalObject::InactiveState),
      91, uint(Dtk::Quick::DQMLGlobalObject::BottomOrder),
      92, uint(Dtk::Quick::DQMLGlobalObject::BelowOrder),
      93, uint(Dtk::Quick::DQMLGlobalObject::NormalOrder),
      94, uint(Dtk::Quick::DQMLGlobalObject::AboveOrder),
      95, uint(Dtk::Quick::DQMLGlobalObject::TopOrder),

       0        // eod
};

void Dtk::Quick::DQMLGlobalObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DQMLGlobalObject *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->hasBlurWindowChanged(); break;
        case 1: _t->hasCompositeChanged(); break;
        case 2: _t->hasNoTitlebarChanged(); break;
        case 3: _t->hasAnimationChanged(); break;
        case 4: _t->hasInWindowBlurChanged(); break;
        case 5: _t->paletteChanged(); break;
        case 6: _t->inactivePaletteChanged(); break;
        case 7: _t->themeTypeChanged((*reinterpret_cast< Dtk::Gui::DGuiApplicationHelper::ColorType(*)>(_a[1]))); break;
        case 8: _t->d_func()->_q_onPaletteChanged(); break;
        case 9: { QColor _r = _t->blendColor((*reinterpret_cast< const QColor(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QColor*>(_a[0]) = std::move(_r); }  break;
        case 10: { Dtk::Quick::DColor _r = _t->makeColor((*reinterpret_cast< Dtk::Quick::DColor::Type(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Dtk::Quick::DColor*>(_a[0]) = std::move(_r); }  break;
        case 11: { Dtk::Quick::DColor _r = _t->makeColor((*reinterpret_cast< const QColor(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Dtk::Quick::DColor*>(_a[0]) = std::move(_r); }  break;
        case 12: { QUrl _r = _t->makeShadowImageUrl((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3])),(*reinterpret_cast< QColor(*)>(_a[4])),(*reinterpret_cast< qreal(*)>(_a[5])),(*reinterpret_cast< qreal(*)>(_a[6])),(*reinterpret_cast< qreal(*)>(_a[7])),(*reinterpret_cast< bool(*)>(_a[8])),(*reinterpret_cast< bool(*)>(_a[9])));
            if (_a[0]) *reinterpret_cast< QUrl*>(_a[0]) = std::move(_r); }  break;
        case 13: { QUrl _r = _t->makeShadowImageUrl((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3])),(*reinterpret_cast< qreal(*)>(_a[4])),(*reinterpret_cast< qreal(*)>(_a[5])),(*reinterpret_cast< qreal(*)>(_a[6])),(*reinterpret_cast< QColor(*)>(_a[7])),(*reinterpret_cast< qreal(*)>(_a[8])),(*reinterpret_cast< qreal(*)>(_a[9])),(*reinterpret_cast< qreal(*)>(_a[10])),(*reinterpret_cast< bool(*)>(_a[11])),(*reinterpret_cast< bool(*)>(_a[12])));
            if (_a[0]) *reinterpret_cast< QUrl*>(_a[0]) = std::move(_r); }  break;
        case 14: { Dtk::Gui::DGuiApplicationHelper::ColorType _r = _t->toColorType((*reinterpret_cast< const QColor(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Dtk::Gui::DGuiApplicationHelper::ColorType*>(_a[0]) = std::move(_r); }  break;
        case 15: { QColor _r = _t->selectColor((*reinterpret_cast< const QColor(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QColor*>(_a[0]) = std::move(_r); }  break;
        case 16: { QPoint _r = _t->cursorPosition();
            if (_a[0]) *reinterpret_cast< QPoint*>(_a[0]) = std::move(_r); }  break;
        case 17: { Dtk::Quick::DQuickDciIcon _r = _t->makeIcon((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< const QJSValue(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< Dtk::Quick::DQuickDciIcon*>(_a[0]) = std::move(_r); }  break;
        case 18: { Dtk::Gui::DDciIconPalette _r = _t->makeIconPalette((*reinterpret_cast< const QPalette(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Dtk::Gui::DDciIconPalette*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->sendMessage((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->sendMessage((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->sendMessage((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->sendMessage((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->sendMessage((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< QQmlComponent*(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->sendMessage((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< QQmlComponent*(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->sendMessage((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< QQmlComponent*(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->closeMessage((*reinterpret_cast< Dtk::Quick::FloatingMessageContainer*(*)>(_a[1]))); break;
        case 27: _t->closeMessage((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 28: _t->sendSystemMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4])),(*reinterpret_cast< const QVariantMap(*)>(_a[5])),(*reinterpret_cast< const int(*)>(_a[6])),(*reinterpret_cast< const uint(*)>(_a[7]))); break;
        case 29: _t->sendSystemMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4])),(*reinterpret_cast< const QVariantMap(*)>(_a[5])),(*reinterpret_cast< const int(*)>(_a[6]))); break;
        case 30: _t->sendSystemMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4])),(*reinterpret_cast< const QVariantMap(*)>(_a[5]))); break;
        case 31: _t->sendSystemMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4]))); break;
        case 32: _t->sendSystemMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 33: _t->sendSystemMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 34: _t->sendSystemMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DQMLGlobalObject::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQMLGlobalObject::hasBlurWindowChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DQMLGlobalObject::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQMLGlobalObject::hasCompositeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DQMLGlobalObject::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQMLGlobalObject::hasNoTitlebarChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DQMLGlobalObject::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQMLGlobalObject::hasAnimationChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DQMLGlobalObject::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQMLGlobalObject::hasInWindowBlurChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DQMLGlobalObject::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQMLGlobalObject::paletteChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DQMLGlobalObject::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQMLGlobalObject::inactivePaletteChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DQMLGlobalObject::*)(Dtk::Gui::DGuiApplicationHelper::ColorType );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQMLGlobalObject::themeTypeChanged)) {
                *result = 7;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DPlatformThemeProxy* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DQMLGlobalObject *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->hasBlurWindow(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->hasComposite(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->hasNoTitlebar(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->hasAnimation(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->hasInWindowBlur(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->isSoftwareRender(); break;
        case 6: *reinterpret_cast< Dtk::Gui::DWindowManagerHelper::WMName*>(_v) = _t->windowManagerName(); break;
        case 7: *reinterpret_cast< Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v) = _t->themeType(); break;
        case 8: *reinterpret_cast< QString*>(_v) = _t->windowManagerNameString(); break;
        case 9: *reinterpret_cast< DPlatformThemeProxy**>(_v) = _t->platformTheme(); break;
        case 10: *reinterpret_cast< Dtk::Gui::DFontManager**>(_v) = _t->fontManager(); break;
        case 11: *reinterpret_cast< QPalette*>(_v) = _t->palette(); break;
        case 12: *reinterpret_cast< QPalette*>(_v) = _t->inactivePalette(); break;
        case 13: *reinterpret_cast< QString*>(_v) = _t->deepinDistributionOrgLogo(); break;
        case 14: *reinterpret_cast< QString*>(_v) = _t->deepinWebsiteName(); break;
        case 15: *reinterpret_cast< QString*>(_v) = _t->deepinWebsiteLink(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_Dtk__Quick__DQMLGlobalObject[] = {
    QMetaObject::SuperData::link<Dtk::Gui::DWindowManagerHelper::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Gui::DGuiApplicationHelper::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQMLGlobalObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DQMLGlobalObject.data,
    qt_meta_data_Dtk__Quick__DQMLGlobalObject,
    qt_static_metacall,
    qt_meta_extradata_Dtk__Quick__DQMLGlobalObject,
    nullptr
} };


const QMetaObject *Dtk::Quick::DQMLGlobalObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQMLGlobalObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DQMLGlobalObject.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DQMLGlobalObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 16;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQMLGlobalObject::hasBlurWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQMLGlobalObject::hasCompositeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQMLGlobalObject::hasNoTitlebarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQMLGlobalObject::hasAnimationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQMLGlobalObject::hasInWindowBlurChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQMLGlobalObject::paletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQMLGlobalObject::inactivePaletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Quick::DQMLGlobalObject::themeTypeChanged(Dtk::Gui::DGuiApplicationHelper::ColorType _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
