/****************************************************************************
** Meta object code from reading C++ file 'dquickwaterprogressattribute_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/private/dquickwaterprogressattribute_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickwaterprogressattribute_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__WaterPopAttribute_t {
    QByteArrayData data[14];
    char stringdata0[135];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__WaterPopAttribute_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__WaterPopAttribute_t qt_meta_stringdata_Dtk__Quick__WaterPopAttribute = {
    {
QT_MOC_LITERAL(0, 0, 29), // "Dtk::Quick::WaterPopAttribute"
QT_MOC_LITERAL(1, 30, 13), // "xSpeedChanged"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 13), // "ySpeedChanged"
QT_MOC_LITERAL(4, 59, 8), // "xChanged"
QT_MOC_LITERAL(5, 68, 8), // "yChanged"
QT_MOC_LITERAL(6, 77, 12), // "widthChanged"
QT_MOC_LITERAL(7, 90, 13), // "heightChanged"
QT_MOC_LITERAL(8, 104, 5), // "width"
QT_MOC_LITERAL(9, 110, 6), // "height"
QT_MOC_LITERAL(10, 117, 6), // "xSpeed"
QT_MOC_LITERAL(11, 124, 6), // "ySpeed"
QT_MOC_LITERAL(12, 131, 1), // "x"
QT_MOC_LITERAL(13, 133, 1) // "y"

    },
    "Dtk::Quick::WaterPopAttribute\0"
    "xSpeedChanged\0\0ySpeedChanged\0xChanged\0"
    "yChanged\0widthChanged\0heightChanged\0"
    "width\0height\0xSpeed\0ySpeed\0x\0y"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__WaterPopAttribute[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       6,   50, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x06 /* Public */,
       3,    0,   45,    2, 0x06 /* Public */,
       4,    0,   46,    2, 0x06 /* Public */,
       5,    0,   47,    2, 0x06 /* Public */,
       6,    0,   48,    2, 0x06 /* Public */,
       7,    0,   49,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       8, QMetaType::QReal, 0x00495903,
       9, QMetaType::QReal, 0x00495903,
      10, QMetaType::QReal, 0x00495903,
      11, QMetaType::QReal, 0x00495903,
      12, QMetaType::QReal, 0x00495903,
      13, QMetaType::QReal, 0x00495903,

 // properties: notify_signal_id
       4,
       5,
       0,
       1,
       2,
       3,

       0        // eod
};

void Dtk::Quick::WaterPopAttribute::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<WaterPopAttribute *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->xSpeedChanged(); break;
        case 1: _t->ySpeedChanged(); break;
        case 2: _t->xChanged(); break;
        case 3: _t->yChanged(); break;
        case 4: _t->widthChanged(); break;
        case 5: _t->heightChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (WaterPopAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WaterPopAttribute::xSpeedChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (WaterPopAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WaterPopAttribute::ySpeedChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (WaterPopAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WaterPopAttribute::xChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (WaterPopAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WaterPopAttribute::yChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (WaterPopAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WaterPopAttribute::widthChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (WaterPopAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WaterPopAttribute::heightChanged)) {
                *result = 5;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<WaterPopAttribute *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qreal*>(_v) = _t->width(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->height(); break;
        case 2: *reinterpret_cast< qreal*>(_v) = _t->xSpeed(); break;
        case 3: *reinterpret_cast< qreal*>(_v) = _t->ySpeed(); break;
        case 4: *reinterpret_cast< qreal*>(_v) = _t->x(); break;
        case 5: *reinterpret_cast< qreal*>(_v) = _t->y(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<WaterPopAttribute *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 1: _t->setHeight(*reinterpret_cast< qreal*>(_v)); break;
        case 2: _t->setXSpeed(*reinterpret_cast< qreal*>(_v)); break;
        case 3: _t->setYSpeed(*reinterpret_cast< qreal*>(_v)); break;
        case 4: _t->setX(*reinterpret_cast< qreal*>(_v)); break;
        case 5: _t->setY(*reinterpret_cast< qreal*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::WaterPopAttribute::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__WaterPopAttribute.data,
    qt_meta_data_Dtk__Quick__WaterPopAttribute,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::WaterPopAttribute::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::WaterPopAttribute::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__WaterPopAttribute.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::WaterPopAttribute::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 6;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::WaterPopAttribute::xSpeedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::WaterPopAttribute::ySpeedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::WaterPopAttribute::xChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::WaterPopAttribute::yChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::WaterPopAttribute::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::WaterPopAttribute::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
struct qt_meta_stringdata_Dtk__Quick__DQuickWaterProgressAttribute_t {
    QByteArrayData data[18];
    char stringdata0[301];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickWaterProgressAttribute_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickWaterProgressAttribute_t qt_meta_stringdata_Dtk__Quick__DQuickWaterProgressAttribute = {
    {
QT_MOC_LITERAL(0, 0, 40), // "Dtk::Quick::DQuickWaterProgre..."
QT_MOC_LITERAL(1, 41, 19), // "frontXOffsetChanged"
QT_MOC_LITERAL(2, 61, 0), // ""
QT_MOC_LITERAL(3, 62, 18), // "backXOffsetChanged"
QT_MOC_LITERAL(4, 81, 11), // "popsChanged"
QT_MOC_LITERAL(5, 93, 14), // "runningChanged"
QT_MOC_LITERAL(6, 108, 20), // "waterProgressChanged"
QT_MOC_LITERAL(7, 129, 17), // "imageWidthChanged"
QT_MOC_LITERAL(8, 147, 18), // "imageHeightChanged"
QT_MOC_LITERAL(9, 166, 12), // "frontXOffset"
QT_MOC_LITERAL(10, 179, 11), // "backXOffset"
QT_MOC_LITERAL(11, 191, 10), // "imageWidth"
QT_MOC_LITERAL(12, 202, 11), // "imageHeight"
QT_MOC_LITERAL(13, 214, 4), // "pops"
QT_MOC_LITERAL(14, 219, 47), // "QQmlListProperty<Dtk::Quick::..."
QT_MOC_LITERAL(15, 267, 7), // "running"
QT_MOC_LITERAL(16, 275, 13), // "waterProgress"
QT_MOC_LITERAL(17, 289, 11) // "QQuickItem*"

    },
    "Dtk::Quick::DQuickWaterProgressAttribute\0"
    "frontXOffsetChanged\0\0backXOffsetChanged\0"
    "popsChanged\0runningChanged\0"
    "waterProgressChanged\0imageWidthChanged\0"
    "imageHeightChanged\0frontXOffset\0"
    "backXOffset\0imageWidth\0imageHeight\0"
    "pops\0QQmlListProperty<Dtk::Quick::WaterPopAttribute>\0"
    "running\0waterProgress\0QQuickItem*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickWaterProgressAttribute[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       7,   56, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,
       3,    0,   50,    2, 0x06 /* Public */,
       4,    0,   51,    2, 0x06 /* Public */,
       5,    0,   52,    2, 0x06 /* Public */,
       6,    0,   53,    2, 0x06 /* Public */,
       7,    0,   54,    2, 0x06 /* Public */,
       8,    0,   55,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       9, QMetaType::QReal, 0x00495001,
      10, QMetaType::QReal, 0x00495001,
      11, QMetaType::QReal, 0x00495103,
      12, QMetaType::QReal, 0x00495103,
      13, 0x80000000 | 14, 0x00495009,
      15, QMetaType::Bool, 0x00495103,
      16, 0x80000000 | 17, 0x0049510b,

 // properties: notify_signal_id
       0,
       1,
       5,
       6,
       2,
       3,
       4,

       0        // eod
};

void Dtk::Quick::DQuickWaterProgressAttribute::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DQuickWaterProgressAttribute *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->frontXOffsetChanged(); break;
        case 1: _t->backXOffsetChanged(); break;
        case 2: _t->popsChanged(); break;
        case 3: _t->runningChanged(); break;
        case 4: _t->waterProgressChanged(); break;
        case 5: _t->imageWidthChanged(); break;
        case 6: _t->imageHeightChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DQuickWaterProgressAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWaterProgressAttribute::frontXOffsetChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DQuickWaterProgressAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWaterProgressAttribute::backXOffsetChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DQuickWaterProgressAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWaterProgressAttribute::popsChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DQuickWaterProgressAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWaterProgressAttribute::runningChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DQuickWaterProgressAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWaterProgressAttribute::waterProgressChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DQuickWaterProgressAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWaterProgressAttribute::imageWidthChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DQuickWaterProgressAttribute::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWaterProgressAttribute::imageHeightChanged)) {
                *result = 6;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DQuickWaterProgressAttribute *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qreal*>(_v) = _t->frontXOffset(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->backXOffset(); break;
        case 2: *reinterpret_cast< qreal*>(_v) = _t->imageWidth(); break;
        case 3: *reinterpret_cast< qreal*>(_v) = _t->imageHeight(); break;
        case 4: *reinterpret_cast< QQmlListProperty<Dtk::Quick::WaterPopAttribute>*>(_v) = _t->pops(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->running(); break;
        case 6: *reinterpret_cast< QQuickItem**>(_v) = _t->waterProgress(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DQuickWaterProgressAttribute *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setImageWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 3: _t->setImageHeight(*reinterpret_cast< qreal*>(_v)); break;
        case 5: _t->setRunning(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setWaterProgress(*reinterpret_cast< QQuickItem**>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickWaterProgressAttribute::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DQuickWaterProgressAttribute.data,
    qt_meta_data_Dtk__Quick__DQuickWaterProgressAttribute,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::DQuickWaterProgressAttribute::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickWaterProgressAttribute::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DQuickWaterProgressAttribute.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Core::DObject"))
        return static_cast< Core::DObject*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DQuickWaterProgressAttribute::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickWaterProgressAttribute::frontXOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickWaterProgressAttribute::backXOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickWaterProgressAttribute::popsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickWaterProgressAttribute::runningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickWaterProgressAttribute::waterProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickWaterProgressAttribute::imageWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQuickWaterProgressAttribute::imageHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
