/****************************************************************************
** Meta object code from reading C++ file 'dquickcontrolpalette_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/private/dquickcontrolpalette_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickcontrolpalette_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__DQuickControlColor_t {
    QByteArrayData data[4];
    char stringdata0[65];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickControlColor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickControlColor_t qt_meta_stringdata_Dtk__Quick__DQuickControlColor = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Dtk::Quick::DQuickControlColor"
QT_MOC_LITERAL(1, 31, 6), // "common"
QT_MOC_LITERAL(2, 38, 18), // "Dtk::Quick::DColor"
QT_MOC_LITERAL(3, 57, 7) // "crystal"

    },
    "Dtk::Quick::DQuickControlColor\0common\0"
    "Dtk::Quick::DColor\0crystal"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickControlColor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       2,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, 0x80000000 | 2, 0x0009590b,
       3, 0x80000000 | 2, 0x0009590b,

       0        // eod
};

void Dtk::Quick::DQuickControlColor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Dtk::Quick::DColor >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = reinterpret_cast<DQuickControlColor *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< Dtk::Quick::DColor*>(_v) = _t->common(); break;
        case 1: *reinterpret_cast< Dtk::Quick::DColor*>(_v) = _t->crystal(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = reinterpret_cast<DQuickControlColor *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCommon(*reinterpret_cast< Dtk::Quick::DColor*>(_v)); break;
        case 1: _t->setCrystal(*reinterpret_cast< Dtk::Quick::DColor*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickControlColor::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_Dtk__Quick__DQuickControlColor.data,
    qt_meta_data_Dtk__Quick__DQuickControlColor,
    qt_static_metacall,
    nullptr,
    nullptr
} };

struct qt_meta_stringdata_Dtk__Quick__DQuickControlPalette_t {
    QByteArrayData data[26];
    char stringdata0[366];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickControlPalette_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickControlPalette_t qt_meta_stringdata_Dtk__Quick__DQuickControlPalette = {
    {
QT_MOC_LITERAL(0, 0, 32), // "Dtk::Quick::DQuickControlPalette"
QT_MOC_LITERAL(1, 33, 14), // "enabledChanged"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 13), // "normalChanged"
QT_MOC_LITERAL(4, 63, 17), // "normalDarkChanged"
QT_MOC_LITERAL(5, 81, 14), // "hoveredChanged"
QT_MOC_LITERAL(6, 96, 18), // "hoveredDarkChanged"
QT_MOC_LITERAL(7, 115, 14), // "pressedChanged"
QT_MOC_LITERAL(8, 130, 18), // "pressedDarkChanged"
QT_MOC_LITERAL(9, 149, 15), // "disabledChanged"
QT_MOC_LITERAL(10, 165, 19), // "disabledDarkChanged"
QT_MOC_LITERAL(11, 185, 7), // "changed"
QT_MOC_LITERAL(12, 193, 7), // "enabled"
QT_MOC_LITERAL(13, 201, 6), // "normal"
QT_MOC_LITERAL(14, 208, 30), // "Dtk::Quick::DQuickControlColor"
QT_MOC_LITERAL(15, 239, 10), // "normalDark"
QT_MOC_LITERAL(16, 250, 7), // "hovered"
QT_MOC_LITERAL(17, 258, 11), // "hoveredDark"
QT_MOC_LITERAL(18, 270, 7), // "pressed"
QT_MOC_LITERAL(19, 278, 11), // "pressedDark"
QT_MOC_LITERAL(20, 290, 8), // "disabled"
QT_MOC_LITERAL(21, 299, 12), // "disabledDark"
QT_MOC_LITERAL(22, 312, 11), // "ColorFamily"
QT_MOC_LITERAL(23, 324, 11), // "CommonColor"
QT_MOC_LITERAL(24, 336, 12), // "CrystalColor"
QT_MOC_LITERAL(25, 349, 16) // "ColorFamilyCount"

    },
    "Dtk::Quick::DQuickControlPalette\0"
    "enabledChanged\0\0normalChanged\0"
    "normalDarkChanged\0hoveredChanged\0"
    "hoveredDarkChanged\0pressedChanged\0"
    "pressedDarkChanged\0disabledChanged\0"
    "disabledDarkChanged\0changed\0enabled\0"
    "normal\0Dtk::Quick::DQuickControlColor\0"
    "normalDark\0hovered\0hoveredDark\0pressed\0"
    "pressedDark\0disabled\0disabledDark\0"
    "ColorFamily\0CommonColor\0CrystalColor\0"
    "ColorFamilyCount"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickControlPalette[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       9,   74, // properties
       1,  110, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x06 /* Public */,
       3,    0,   65,    2, 0x06 /* Public */,
       4,    0,   66,    2, 0x06 /* Public */,
       5,    0,   67,    2, 0x06 /* Public */,
       6,    0,   68,    2, 0x06 /* Public */,
       7,    0,   69,    2, 0x06 /* Public */,
       8,    0,   70,    2, 0x06 /* Public */,
       9,    0,   71,    2, 0x06 /* Public */,
      10,    0,   72,    2, 0x06 /* Public */,
      11,    0,   73,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      12, QMetaType::Bool, 0x00495103,
      13, 0x80000000 | 14, 0x0049510b,
      15, 0x80000000 | 14, 0x0049510b,
      16, 0x80000000 | 14, 0x0049510b,
      17, 0x80000000 | 14, 0x0049510b,
      18, 0x80000000 | 14, 0x0049510b,
      19, 0x80000000 | 14, 0x0049510b,
      20, 0x80000000 | 14, 0x0049510b,
      21, 0x80000000 | 14, 0x0049510b,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       8,

 // enums: name, alias, flags, count, data
      22,   22, 0x0,    3,  115,

 // enum data: key, value
      23, uint(Dtk::Quick::DQuickControlPalette::CommonColor),
      24, uint(Dtk::Quick::DQuickControlPalette::CrystalColor),
      25, uint(Dtk::Quick::DQuickControlPalette::ColorFamilyCount),

       0        // eod
};

void Dtk::Quick::DQuickControlPalette::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DQuickControlPalette *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->normalChanged(); break;
        case 2: _t->normalDarkChanged(); break;
        case 3: _t->hoveredChanged(); break;
        case 4: _t->hoveredDarkChanged(); break;
        case 5: _t->pressedChanged(); break;
        case 6: _t->pressedDarkChanged(); break;
        case 7: _t->disabledChanged(); break;
        case 8: _t->disabledDarkChanged(); break;
        case 9: _t->changed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DQuickControlPalette::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlPalette::enabledChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DQuickControlPalette::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlPalette::normalChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DQuickControlPalette::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlPalette::normalDarkChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DQuickControlPalette::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlPalette::hoveredChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DQuickControlPalette::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlPalette::hoveredDarkChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DQuickControlPalette::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlPalette::pressedChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DQuickControlPalette::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlPalette::pressedDarkChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DQuickControlPalette::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlPalette::disabledChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DQuickControlPalette::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlPalette::disabledDarkChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DQuickControlPalette::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlPalette::changed)) {
                *result = 9;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
        case 7:
        case 6:
        case 5:
        case 4:
        case 3:
        case 2:
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Dtk::Quick::DQuickControlColor >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DQuickControlPalette *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->enabled(); break;
        case 1: *reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v) = _t->normal(); break;
        case 2: *reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v) = _t->normalDark(); break;
        case 3: *reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v) = _t->hovered(); break;
        case 4: *reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v) = _t->hoveredDark(); break;
        case 5: *reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v) = _t->pressed(); break;
        case 6: *reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v) = _t->pressedDark(); break;
        case 7: *reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v) = _t->disabled(); break;
        case 8: *reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v) = _t->disabledDark(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DQuickControlPalette *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setNormal(*reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 2: _t->setNormalDark(*reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 3: _t->setHovered(*reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 4: _t->setHoveredDark(*reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 5: _t->setPressed(*reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 6: _t->setPressedDark(*reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 7: _t->setDisabled(*reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 8: _t->setDisabledDark(*reinterpret_cast< Dtk::Quick::DQuickControlColor*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickControlPalette::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DQuickControlPalette.data,
    qt_meta_data_Dtk__Quick__DQuickControlPalette,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::DQuickControlPalette::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickControlPalette::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DQuickControlPalette.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DQuickControlPalette::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 9;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickControlPalette::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickControlPalette::normalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickControlPalette::normalDarkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickControlPalette::hoveredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickControlPalette::hoveredDarkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickControlPalette::pressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQuickControlPalette::pressedDarkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Quick::DQuickControlPalette::disabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Quick::DQuickControlPalette::disabledDarkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Dtk::Quick::DQuickControlPalette::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
struct qt_meta_stringdata_Dtk__Quick__DQuickControlColorSelector_t {
    QByteArrayData data[35];
    char stringdata0[646];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickControlColorSelector_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickControlColorSelector_t qt_meta_stringdata_Dtk__Quick__DQuickControlColorSelector = {
    {
QT_MOC_LITERAL(0, 0, 38), // "Dtk::Quick::DQuickControlColo..."
QT_MOC_LITERAL(1, 39, 15), // "DefaultProperty"
QT_MOC_LITERAL(2, 55, 8), // "palettes"
QT_MOC_LITERAL(3, 64, 19), // "controlThemeChanged"
QT_MOC_LITERAL(4, 84, 0), // ""
QT_MOC_LITERAL(5, 85, 19), // "controlStateChanged"
QT_MOC_LITERAL(6, 105, 14), // "controlChanged"
QT_MOC_LITERAL(7, 120, 14), // "hoveredChanged"
QT_MOC_LITERAL(8, 135, 14), // "pressedChanged"
QT_MOC_LITERAL(9, 150, 15), // "disabledChanged"
QT_MOC_LITERAL(10, 166, 16), // "inactivedChanged"
QT_MOC_LITERAL(11, 183, 20), // "colorPropertyChanged"
QT_MOC_LITERAL(12, 204, 4), // "name"
QT_MOC_LITERAL(13, 209, 22), // "colorPropertiesChanged"
QT_MOC_LITERAL(14, 232, 13), // "familyChanged"
QT_MOC_LITERAL(15, 246, 18), // "updateControlTheme"
QT_MOC_LITERAL(16, 265, 18), // "updateControlState"
QT_MOC_LITERAL(17, 284, 24), // "updateAllColorProperties"
QT_MOC_LITERAL(18, 309, 23), // "recvPaletteColorChanged"
QT_MOC_LITERAL(19, 333, 18), // "onPaletteDestroyed"
QT_MOC_LITERAL(20, 352, 19), // "updateControlWindow"
QT_MOC_LITERAL(21, 372, 26), // "resolveMetaPropertyChanged"
QT_MOC_LITERAL(22, 399, 26), // "notifyColorPropertyChanged"
QT_MOC_LITERAL(23, 426, 7), // "control"
QT_MOC_LITERAL(24, 434, 11), // "QQuickItem*"
QT_MOC_LITERAL(25, 446, 12), // "controlTheme"
QT_MOC_LITERAL(26, 459, 42), // "Dtk::Gui::DGuiApplicationHelp..."
QT_MOC_LITERAL(27, 502, 12), // "controlState"
QT_MOC_LITERAL(28, 515, 42), // "Dtk::Quick::DQMLGlobalObject:..."
QT_MOC_LITERAL(29, 558, 6), // "family"
QT_MOC_LITERAL(30, 565, 45), // "Dtk::Quick::DQuickControlPale..."
QT_MOC_LITERAL(31, 611, 7), // "hovered"
QT_MOC_LITERAL(32, 619, 7), // "pressed"
QT_MOC_LITERAL(33, 627, 8), // "disabled"
QT_MOC_LITERAL(34, 636, 9) // "inactived"

    },
    "Dtk::Quick::DQuickControlColorSelector\0"
    "DefaultProperty\0palettes\0controlThemeChanged\0"
    "\0controlStateChanged\0controlChanged\0"
    "hoveredChanged\0pressedChanged\0"
    "disabledChanged\0inactivedChanged\0"
    "colorPropertyChanged\0name\0"
    "colorPropertiesChanged\0familyChanged\0"
    "updateControlTheme\0updateControlState\0"
    "updateAllColorProperties\0"
    "recvPaletteColorChanged\0onPaletteDestroyed\0"
    "updateControlWindow\0resolveMetaPropertyChanged\0"
    "notifyColorPropertyChanged\0control\0"
    "QQuickItem*\0controlTheme\0"
    "Dtk::Gui::DGuiApplicationHelper::ColorType\0"
    "controlState\0Dtk::Quick::DQMLGlobalObject::ControlState\0"
    "family\0Dtk::Quick::DQuickControlPalette::ColorFamily\0"
    "hovered\0pressed\0disabled\0inactived"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickControlColorSelector[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
      18,   16, // methods
       8,  126, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,  106,    4, 0x06 /* Public */,
       5,    0,  107,    4, 0x06 /* Public */,
       6,    0,  108,    4, 0x06 /* Public */,
       7,    0,  109,    4, 0x06 /* Public */,
       8,    0,  110,    4, 0x06 /* Public */,
       9,    0,  111,    4, 0x06 /* Public */,
      10,    0,  112,    4, 0x06 /* Public */,
      11,    1,  113,    4, 0x06 /* Public */,
      13,    0,  116,    4, 0x06 /* Public */,
      14,    0,  117,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      15,    0,  118,    4, 0x08 /* Private */,
      16,    0,  119,    4, 0x08 /* Private */,
      17,    0,  120,    4, 0x08 /* Private */,
      18,    0,  121,    4, 0x08 /* Private */,
      19,    0,  122,    4, 0x08 /* Private */,
      20,    0,  123,    4, 0x08 /* Private */,
      21,    0,  124,    4, 0x08 /* Private */,
      22,    0,  125,    4, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QByteArray,   12,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      23, 0x80000000 | 24, 0x00495009,
      25, 0x80000000 | 26, 0x00495009,
      27, 0x80000000 | 28, 0x00495009,
      29, 0x80000000 | 30, 0x0049510f,
      31, QMetaType::Bool, 0x00495107,
      32, QMetaType::Bool, 0x00495107,
      33, QMetaType::Bool, 0x00495107,
      34, QMetaType::Bool, 0x00495107,

 // properties: notify_signal_id
       2,
       0,
       1,
       9,
       3,
       4,
       5,
       6,

       0        // eod
};

void Dtk::Quick::DQuickControlColorSelector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DQuickControlColorSelector *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->controlThemeChanged(); break;
        case 1: _t->controlStateChanged(); break;
        case 2: _t->controlChanged(); break;
        case 3: _t->hoveredChanged(); break;
        case 4: _t->pressedChanged(); break;
        case 5: _t->disabledChanged(); break;
        case 6: _t->inactivedChanged(); break;
        case 7: _t->colorPropertyChanged((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 8: _t->colorPropertiesChanged(); break;
        case 9: _t->familyChanged(); break;
        case 10: _t->updateControlTheme(); break;
        case 11: { bool _r = _t->updateControlState();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->updateAllColorProperties(); break;
        case 13: _t->recvPaletteColorChanged(); break;
        case 14: _t->onPaletteDestroyed(); break;
        case 15: _t->updateControlWindow(); break;
        case 16: _t->resolveMetaPropertyChanged(); break;
        case 17: _t->notifyColorPropertyChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DQuickControlColorSelector::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlColorSelector::controlThemeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DQuickControlColorSelector::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlColorSelector::controlStateChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DQuickControlColorSelector::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlColorSelector::controlChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DQuickControlColorSelector::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlColorSelector::hoveredChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DQuickControlColorSelector::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlColorSelector::pressedChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DQuickControlColorSelector::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlColorSelector::disabledChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DQuickControlColorSelector::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlColorSelector::inactivedChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DQuickControlColorSelector::*)(const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlColorSelector::colorPropertyChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DQuickControlColorSelector::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlColorSelector::colorPropertiesChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DQuickControlColorSelector::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickControlColorSelector::familyChanged)) {
                *result = 9;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DQuickControlColorSelector *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QQuickItem**>(_v) = _t->control(); break;
        case 1: *reinterpret_cast< Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v) = _t->controlTheme(); break;
        case 2: *reinterpret_cast< Dtk::Quick::DQMLGlobalObject::ControlState*>(_v) = _t->controlState(); break;
        case 3: *reinterpret_cast< Dtk::Quick::DQuickControlPalette::ColorFamily*>(_v) = _t->family(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->hovered(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->pressed(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->disabled(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->inactived(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DQuickControlColorSelector *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setFamily(*reinterpret_cast< Dtk::Quick::DQuickControlPalette::ColorFamily*>(_v)); break;
        case 4: _t->setHovered(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setPressed(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setDisabled(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setInactived(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
        DQuickControlColorSelector *_t = static_cast<DQuickControlColorSelector *>(_o);
        (void)_t;
        switch (_id) {
        case 3: _t->resetFamily(); break;
        case 4: _t->resetHovered(); break;
        case 5: _t->resetPressed(); break;
        case 6: _t->resetDisabled(); break;
        case 7: _t->resetInactived(); break;
        default: break;
        }
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_Dtk__Quick__DQuickControlColorSelector[] = {
    QMetaObject::SuperData::link<Dtk::Gui::DGuiApplicationHelper::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Quick::DQMLGlobalObject::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Quick::DQuickControlPalette::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickControlColorSelector::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DQuickControlColorSelector.data,
    qt_meta_data_Dtk__Quick__DQuickControlColorSelector,
    qt_static_metacall,
    qt_meta_extradata_Dtk__Quick__DQuickControlColorSelector,
    nullptr
} };


const QMetaObject *Dtk::Quick::DQuickControlColorSelector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickControlColorSelector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DQuickControlColorSelector.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DQuickControlColorSelector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickControlColorSelector::controlThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickControlColorSelector::controlStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickControlColorSelector::controlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickControlColorSelector::hoveredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickControlColorSelector::pressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickControlColorSelector::disabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQuickControlColorSelector::inactivedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Quick::DQuickControlColorSelector::colorPropertyChanged(const QByteArray & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Dtk::Quick::DQuickControlColorSelector::colorPropertiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Dtk::Quick::DQuickControlColorSelector::familyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
