/****************************************************************************
** Meta object code from reading C++ file 'dsettingscontainer_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/private/dsettingscontainer_p.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dsettingscontainer_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick14SettingsOptionE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::SettingsOption::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick14SettingsOptionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::SettingsOption",
        "DefaultProperty",
        "delegate",
        "QML.Element",
        "SettingsOption",
        "keyChanged",
        "",
        "key",
        "nameChanged",
        "name",
        "valueChanged",
        "QVariant",
        "value",
        "delegateChanged",
        "onConfigValueChanged",
        "onValueChanged",
        "QQmlComponent*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'keyChanged'
        QtMocHelpers::SignalData<void(QString)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(QString)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void(QVariant)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'delegateChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onConfigValueChanged'
        QtMocHelpers::SlotData<void()>(14, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onValueChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(15, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 11, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'key'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'value'
        QtMocHelpers::PropertyData<QVariant>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'delegate'
        QtMocHelpers::PropertyData<QQmlComponent*>(2, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SettingsOption, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::SettingsOption::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick14SettingsOptionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick14SettingsOptionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick14SettingsOptionE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::SettingsOption::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsOption *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->keyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->valueChanged((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 3: _t->delegateChanged(); break;
        case 4: _t->onConfigValueChanged(); break;
        case 5: _t->onValueChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SettingsOption::*)(QString )>(_a, &SettingsOption::keyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsOption::*)(QString )>(_a, &SettingsOption::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsOption::*)(QVariant )>(_a, &SettingsOption::valueChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsOption::*)()>(_a, &SettingsOption::delegateChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->key(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QVariant*>(_v) = _t->value(); break;
        case 3: *reinterpret_cast<QQmlComponent**>(_v) = _t->delegate(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setKey(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setValue(*reinterpret_cast<QVariant*>(_v)); break;
        case 3: _t->setDelegate(*reinterpret_cast<QQmlComponent**>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 2: _t->resetValue(); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::SettingsOption::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::SettingsOption::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick14SettingsOptionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::SettingsOption::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::SettingsOption::keyChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Dtk::Quick::SettingsOption::nameChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Dtk::Quick::SettingsOption::valueChanged(QVariant _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Dtk::Quick::SettingsOption::delegateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace {
struct qt_meta_tag_ZN3Dtk5Quick13SettingsGroupE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::SettingsGroup::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick13SettingsGroupE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::SettingsGroup",
        "DefaultProperty",
        "options",
        "QML.Element",
        "SettingsGroup",
        "QML.Attached",
        "keyChanged",
        "",
        "key",
        "nameChanged",
        "name",
        "visibleChanged",
        "visible",
        "optionsChanged",
        "childrenChanged",
        "backgroundChanged",
        "indexChanged",
        "index",
        "level",
        "QQmlListProperty<Dtk::Quick::SettingsOption>",
        "children",
        "QQmlListProperty<Dtk::Quick::SettingsGroup>",
        "background",
        "QQmlComponent*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'keyChanged'
        QtMocHelpers::SignalData<void(QString)>(6, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(QString)>(9, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'optionsChanged'
        QtMocHelpers::SignalData<void()>(13, 7, QMC::AccessPublic, QMetaType::Void),
        // Signal 'childrenChanged'
        QtMocHelpers::SignalData<void()>(14, 7, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundChanged'
        QtMocHelpers::SignalData<void()>(15, 7, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indexChanged'
        QtMocHelpers::SignalData<void(int)>(16, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'key'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'level'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'index'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags, 6),
        // property 'options'
        QtMocHelpers::PropertyData<QQmlListProperty<Dtk::Quick::SettingsOption>>(2, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'children'
        QtMocHelpers::PropertyData<QQmlListProperty<Dtk::Quick::SettingsGroup>>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'background'
        QtMocHelpers::PropertyData<QQmlComponent*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    4 },
    });
    return QtMocHelpers::metaObjectData<SettingsGroup, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::SettingsGroup::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick13SettingsGroupE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick13SettingsGroupE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick13SettingsGroupE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::SettingsGroup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsGroup *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->keyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->visibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->optionsChanged(); break;
        case 4: _t->childrenChanged(); break;
        case 5: _t->backgroundChanged(); break;
        case 6: _t->indexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SettingsGroup::*)(QString )>(_a, &SettingsGroup::keyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsGroup::*)(QString )>(_a, &SettingsGroup::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsGroup::*)(bool )>(_a, &SettingsGroup::visibleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsGroup::*)()>(_a, &SettingsGroup::optionsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsGroup::*)()>(_a, &SettingsGroup::childrenChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsGroup::*)()>(_a, &SettingsGroup::backgroundChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsGroup::*)(int )>(_a, &SettingsGroup::indexChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->key(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->level(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->visible(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->index(); break;
        case 5: *reinterpret_cast<QQmlListProperty<Dtk::Quick::SettingsOption>*>(_v) = _t->options(); break;
        case 6: *reinterpret_cast<QQmlListProperty<Dtk::Quick::SettingsGroup>*>(_v) = _t->children(); break;
        case 7: *reinterpret_cast<QQmlComponent**>(_v) = _t->background(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setKey(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setVisible(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setBackground(*reinterpret_cast<QQmlComponent**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::SettingsGroup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::SettingsGroup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick13SettingsGroupE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::SettingsGroup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::SettingsGroup::keyChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Dtk::Quick::SettingsGroup::nameChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Dtk::Quick::SettingsGroup::visibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Dtk::Quick::SettingsGroup::optionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::SettingsGroup::childrenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::SettingsGroup::backgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::SettingsGroup::indexChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3Dtk5Quick21SettingsInstanceModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::SettingsInstanceModel::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick21SettingsInstanceModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::SettingsInstanceModel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SettingsInstanceModel, qt_meta_tag_ZN3Dtk5Quick21SettingsInstanceModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::SettingsInstanceModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QQmlInstanceModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick21SettingsInstanceModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick21SettingsInstanceModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick21SettingsInstanceModelE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::SettingsInstanceModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsInstanceModel *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Dtk::Quick::SettingsInstanceModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::SettingsInstanceModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick21SettingsInstanceModelE_t>.strings))
        return static_cast<void*>(this);
    return QQmlInstanceModel::qt_metacast(_clname);
}

int Dtk::Quick::SettingsInstanceModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQmlInstanceModel::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Dtk5Quick20SettingsContentModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::SettingsContentModel::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick20SettingsContentModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::SettingsContentModel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SettingsContentModel, qt_meta_tag_ZN3Dtk5Quick20SettingsContentModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::SettingsContentModel::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingsInstanceModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick20SettingsContentModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick20SettingsContentModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick20SettingsContentModelE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::SettingsContentModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsContentModel *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Dtk::Quick::SettingsContentModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::SettingsContentModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick20SettingsContentModelE_t>.strings))
        return static_cast<void*>(this);
    return SettingsInstanceModel::qt_metacast(_clname);
}

int Dtk::Quick::SettingsContentModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingsInstanceModel::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Dtk5Quick23SettingsNavigationModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::SettingsNavigationModel::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick23SettingsNavigationModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::SettingsNavigationModel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SettingsNavigationModel, qt_meta_tag_ZN3Dtk5Quick23SettingsNavigationModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::SettingsNavigationModel::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingsInstanceModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick23SettingsNavigationModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick23SettingsNavigationModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick23SettingsNavigationModelE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::SettingsNavigationModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsNavigationModel *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Dtk::Quick::SettingsNavigationModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::SettingsNavigationModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick23SettingsNavigationModelE_t>.strings))
        return static_cast<void*>(this);
    return SettingsInstanceModel::qt_metacast(_clname);
}

int Dtk::Quick::SettingsNavigationModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingsInstanceModel::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Dtk5Quick17SettingsContainerE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::SettingsContainer::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick17SettingsContainerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::SettingsContainer",
        "DefaultProperty",
        "groups",
        "QML.Element",
        "SettingsContainer",
        "groupsChanged",
        "",
        "navigationTitleChanged",
        "contentTitleChanged",
        "contentModelChanged",
        "navigationModelChanged",
        "configChanged",
        "contentBackgroundChanged",
        "setGroupVisible",
        "key",
        "visible",
        "groupVisible",
        "resetSettings",
        "onGroupVisibleChanged",
        "config",
        "QQmlListProperty<Dtk::Quick::SettingsGroup>",
        "contentModel",
        "SettingsContentModel*",
        "contentTitle",
        "QQmlComponent*",
        "contentBackground",
        "navigationModel",
        "SettingsNavigationModel*",
        "navigationTitle"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'groupsChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigationTitleChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentTitleChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentModelChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigationModelChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentBackgroundChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setGroupVisible'
        QtMocHelpers::SlotData<void(const QString &, bool)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'groupVisible'
        QtMocHelpers::SlotData<bool(const QString &) const>(16, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'resetSettings'
        QtMocHelpers::SlotData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onGroupVisibleChanged'
        QtMocHelpers::SlotData<void(bool)>(18, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'config'
        QtMocHelpers::PropertyData<QObject*>(19, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'groups'
        QtMocHelpers::PropertyData<QQmlListProperty<Dtk::Quick::SettingsGroup>>(2, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'contentModel'
        QtMocHelpers::PropertyData<SettingsContentModel*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'contentTitle'
        QtMocHelpers::PropertyData<QQmlComponent*>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'contentBackground'
        QtMocHelpers::PropertyData<QQmlComponent*>(25, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'navigationModel'
        QtMocHelpers::PropertyData<SettingsNavigationModel*>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'navigationTitle'
        QtMocHelpers::PropertyData<QQmlComponent*>(28, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SettingsContainer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::SettingsContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick17SettingsContainerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick17SettingsContainerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick17SettingsContainerE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::SettingsContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsContainer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->groupsChanged(); break;
        case 1: _t->navigationTitleChanged(); break;
        case 2: _t->contentTitleChanged(); break;
        case 3: _t->contentModelChanged(); break;
        case 4: _t->navigationModelChanged(); break;
        case 5: _t->configChanged(); break;
        case 6: _t->contentBackgroundChanged(); break;
        case 7: _t->setGroupVisible((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: { bool _r = _t->groupVisible((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->resetSettings(); break;
        case 10: _t->onGroupVisibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SettingsContainer::*)()>(_a, &SettingsContainer::groupsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsContainer::*)()>(_a, &SettingsContainer::navigationTitleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsContainer::*)()>(_a, &SettingsContainer::contentTitleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsContainer::*)()>(_a, &SettingsContainer::contentModelChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsContainer::*)()>(_a, &SettingsContainer::navigationModelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsContainer::*)()>(_a, &SettingsContainer::configChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsContainer::*)()>(_a, &SettingsContainer::contentBackgroundChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
        case 4:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SettingsContentModel* >(); break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SettingsNavigationModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->config(); break;
        case 1: *reinterpret_cast<QQmlListProperty<Dtk::Quick::SettingsGroup>*>(_v) = _t->groups(); break;
        case 2: *reinterpret_cast<SettingsContentModel**>(_v) = _t->contentModel(); break;
        case 3: *reinterpret_cast<QQmlComponent**>(_v) = _t->contentTitle(); break;
        case 4: *reinterpret_cast<QQmlComponent**>(_v) = _t->contentBackground(); break;
        case 5: *reinterpret_cast<SettingsNavigationModel**>(_v) = _t->navigationModel(); break;
        case 6: *reinterpret_cast<QQmlComponent**>(_v) = _t->navigationTitle(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setConfig(*reinterpret_cast<QObject**>(_v)); break;
        case 3: _t->setContentTitle(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 4: _t->setContentBackground(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 6: _t->setNavigationTitle(*reinterpret_cast<QQmlComponent**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::SettingsContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::SettingsContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick17SettingsContainerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::SettingsContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::SettingsContainer::groupsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::SettingsContainer::navigationTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::SettingsContainer::contentTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::SettingsContainer::contentModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::SettingsContainer::navigationModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::SettingsContainer::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::SettingsContainer::contentBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
