/****************************************************************************
** Meta object code from reading C++ file 'dquickiconimage_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/private/dquickiconimage_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickiconimage_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick15DQuickIconImageE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickIconImage::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick15DQuickIconImageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickIconImage",
        "QML.Element",
        "QtIcon",
        "nameChanged",
        "",
        "stateChanged",
        "modeChanged",
        "colorChanged",
        "fallbackSourceChanged",
        "setName",
        "name",
        "setState",
        "State",
        "state",
        "setMode",
        "Mode",
        "mode",
        "setColor",
        "QColor",
        "color",
        "setFallbackSource",
        "QUrl",
        "newSource",
        "setImage",
        "QImage",
        "img",
        "maybeUpdateUrl",
        "fallbackSource",
        "Invalid",
        "Normal",
        "Disabled",
        "Active",
        "Selected",
        "On",
        "Off"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackSourceChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setName'
        QtMocHelpers::SlotData<void(const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'setState'
        QtMocHelpers::SlotData<void(enum State)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setMode'
        QtMocHelpers::SlotData<void(enum Mode)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'setColor'
        QtMocHelpers::SlotData<void(const QColor &)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'setFallbackSource'
        QtMocHelpers::SlotData<void(const QUrl &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'setImage'
        QtMocHelpers::SlotData<void(const QImage &)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'maybeUpdateUrl'
        QtMocHelpers::SlotData<void()>(26, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'mode'
        QtMocHelpers::PropertyData<enum Mode>(16, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(13, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(19, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 3),
        // property 'fallbackSource'
        QtMocHelpers::PropertyData<QUrl>(27, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Mode'
        QtMocHelpers::EnumData<enum Mode>(15, 15, QMC::EnumIsScoped).add({
            {   28, Mode::Invalid },
            {   29, Mode::Normal },
            {   30, Mode::Disabled },
            {   31, Mode::Active },
            {   32, Mode::Selected },
        }),
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(12, 12, QMC::EnumIsScoped).add({
            {   33, State::On },
            {   34, State::Off },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DQuickIconImage, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickIconImage::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickImage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick15DQuickIconImageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick15DQuickIconImageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick15DQuickIconImageE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickIconImage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickIconImage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->stateChanged(); break;
        case 2: _t->modeChanged(); break;
        case 3: _t->colorChanged(); break;
        case 4: _t->fallbackSourceChanged(); break;
        case 5: _t->setName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->setState((*reinterpret_cast<std::add_pointer_t<enum State>>(_a[1]))); break;
        case 7: _t->setMode((*reinterpret_cast<std::add_pointer_t<enum Mode>>(_a[1]))); break;
        case 8: _t->setColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 9: _t->setFallbackSource((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->setImage((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 11: _t->d_func()->maybeUpdateUrl(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQuickIconImage::*)()>(_a, &DQuickIconImage::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickIconImage::*)()>(_a, &DQuickIconImage::stateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickIconImage::*)()>(_a, &DQuickIconImage::modeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickIconImage::*)()>(_a, &DQuickIconImage::colorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickIconImage::*)()>(_a, &DQuickIconImage::fallbackSourceChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<enum Mode*>(_v) = _t->mode(); break;
        case 2: *reinterpret_cast<enum State*>(_v) = _t->state(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 4: *reinterpret_cast<QUrl*>(_v) = _t->fallbackSource(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setMode(*reinterpret_cast<enum Mode*>(_v)); break;
        case 2: _t->setState(*reinterpret_cast<enum State*>(_v)); break;
        case 3: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 4: _t->setFallbackSource(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::DQuickIconImage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickIconImage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick15DQuickIconImageE_t>.strings))
        return static_cast<void*>(this);
    return QQuickImage::qt_metacast(_clname);
}

int Dtk::Quick::DQuickIconImage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickImage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickIconImage::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickIconImage::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickIconImage::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickIconImage::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickIconImage::fallbackSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
