/****************************************************************************
** Meta object code from reading C++ file 'dquickdciiconimage_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/private/dquickdciiconimage_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickdciiconimage_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__DQuickDciIconImage_t {
    QByteArrayData data[28];
    char stringdata0[444];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickDciIconImage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickDciIconImage_t qt_meta_stringdata_Dtk__Quick__DQuickDciIconImage = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Dtk::Quick::DQuickDciIconImage"
QT_MOC_LITERAL(1, 31, 11), // "nameChanged"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 11), // "modeChanged"
QT_MOC_LITERAL(4, 56, 12), // "themeChanged"
QT_MOC_LITERAL(5, 69, 14), // "paletteChanged"
QT_MOC_LITERAL(6, 84, 17), // "sourceSizeChanged"
QT_MOC_LITERAL(7, 102, 13), // "mirrorChanged"
QT_MOC_LITERAL(8, 116, 22), // "fallbackToQIconChanged"
QT_MOC_LITERAL(9, 139, 19), // "asynchronousChanged"
QT_MOC_LITERAL(10, 159, 12), // "cacheChanged"
QT_MOC_LITERAL(11, 172, 15), // "fillModeChanged"
QT_MOC_LITERAL(12, 188, 4), // "play"
QT_MOC_LITERAL(13, 193, 30), // "DQMLGlobalObject::ControlState"
QT_MOC_LITERAL(14, 224, 4), // "mode"
QT_MOC_LITERAL(15, 229, 4), // "name"
QT_MOC_LITERAL(16, 234, 42), // "Dtk::Quick::DQMLGlobalObject:..."
QT_MOC_LITERAL(17, 277, 5), // "theme"
QT_MOC_LITERAL(18, 283, 42), // "Dtk::Gui::DGuiApplicationHelp..."
QT_MOC_LITERAL(19, 326, 7), // "palette"
QT_MOC_LITERAL(20, 334, 25), // "Dtk::Gui::DDciIconPalette"
QT_MOC_LITERAL(21, 360, 10), // "sourceSize"
QT_MOC_LITERAL(22, 371, 6), // "mirror"
QT_MOC_LITERAL(23, 378, 15), // "fallbackToQIcon"
QT_MOC_LITERAL(24, 394, 12), // "asynchronous"
QT_MOC_LITERAL(25, 407, 5), // "cache"
QT_MOC_LITERAL(26, 413, 8), // "fillMode"
QT_MOC_LITERAL(27, 422, 21) // "QQuickImage::FillMode"

    },
    "Dtk::Quick::DQuickDciIconImage\0"
    "nameChanged\0\0modeChanged\0themeChanged\0"
    "paletteChanged\0sourceSizeChanged\0"
    "mirrorChanged\0fallbackToQIconChanged\0"
    "asynchronousChanged\0cacheChanged\0"
    "fillModeChanged\0play\0"
    "DQMLGlobalObject::ControlState\0mode\0"
    "name\0Dtk::Quick::DQMLGlobalObject::ControlState\0"
    "theme\0Dtk::Gui::DGuiApplicationHelper::ColorType\0"
    "palette\0Dtk::Gui::DDciIconPalette\0"
    "sourceSize\0mirror\0fallbackToQIcon\0"
    "asynchronous\0cache\0fillMode\0"
    "QQuickImage::FillMode"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickDciIconImage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
      10,   82, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,
       3,    0,   70,    2, 0x06 /* Public */,
       4,    0,   71,    2, 0x06 /* Public */,
       5,    0,   72,    2, 0x06 /* Public */,
       6,    0,   73,    2, 0x06 /* Public */,
       7,    0,   74,    2, 0x06 /* Public */,
       8,    0,   75,    2, 0x06 /* Public */,
       9,    0,   76,    2, 0x06 /* Public */,
      10,    0,   77,    2, 0x06 /* Public */,
      11,    0,   78,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
      12,    1,   79,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // methods: parameters
    QMetaType::Void, 0x80000000 | 13,   14,

 // properties: name, type, flags
      15, QMetaType::QString, 0x00495903,
      14, 0x80000000 | 16, 0x0049590b,
      17, 0x80000000 | 18, 0x0049590b,
      19, 0x80000000 | 20, 0x0049510b,
      21, QMetaType::QSize, 0x00495103,
      22, QMetaType::Bool, 0x00495103,
      23, QMetaType::Bool, 0x00495103,
      24, QMetaType::Bool, 0x00495103,
      25, QMetaType::Bool, 0x00495903,
      26, 0x80000000 | 27, 0x0049510b,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       8,
       9,

       0        // eod
};

void Dtk::Quick::DQuickDciIconImage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DQuickDciIconImage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->modeChanged(); break;
        case 2: _t->themeChanged(); break;
        case 3: _t->paletteChanged(); break;
        case 4: _t->sourceSizeChanged(); break;
        case 5: _t->mirrorChanged(); break;
        case 6: _t->fallbackToQIconChanged(); break;
        case 7: _t->asynchronousChanged(); break;
        case 8: _t->cacheChanged(); break;
        case 9: _t->fillModeChanged(); break;
        case 10: _t->play((*reinterpret_cast< DQMLGlobalObject::ControlState(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DQuickDciIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickDciIconImage::nameChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DQuickDciIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickDciIconImage::modeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DQuickDciIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickDciIconImage::themeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DQuickDciIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickDciIconImage::paletteChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DQuickDciIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickDciIconImage::sourceSizeChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DQuickDciIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickDciIconImage::mirrorChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DQuickDciIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickDciIconImage::fallbackToQIconChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DQuickDciIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickDciIconImage::asynchronousChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DQuickDciIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickDciIconImage::cacheChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DQuickDciIconImage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickDciIconImage::fillModeChanged)) {
                *result = 9;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DQuickDciIconImage *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast< Dtk::Quick::DQMLGlobalObject::ControlState*>(_v) = _t->mode(); break;
        case 2: *reinterpret_cast< Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v) = _t->theme(); break;
        case 3: *reinterpret_cast< Dtk::Gui::DDciIconPalette*>(_v) = _t->palette(); break;
        case 4: *reinterpret_cast< QSize*>(_v) = _t->sourceSize(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->mirror(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->fallbackToQIcon(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->asynchronous(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->cache(); break;
        case 9: *reinterpret_cast< QQuickImage::FillMode*>(_v) = _t->fillMode(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DQuickDciIconImage *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setMode(*reinterpret_cast< Dtk::Quick::DQMLGlobalObject::ControlState*>(_v)); break;
        case 2: _t->setTheme(*reinterpret_cast< Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v)); break;
        case 3: _t->setPalette(*reinterpret_cast< Dtk::Gui::DDciIconPalette*>(_v)); break;
        case 4: _t->setSourceSize(*reinterpret_cast< QSize*>(_v)); break;
        case 5: _t->setMirror(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setFallbackToQIcon(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setAsynchronous(*reinterpret_cast< bool*>(_v)); break;
        case 8: _t->setCache(*reinterpret_cast< bool*>(_v)); break;
        case 9: _t->setFillMode(*reinterpret_cast< QQuickImage::FillMode*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_Dtk__Quick__DQuickDciIconImage[] = {
    QMetaObject::SuperData::link<Dtk::Quick::DQMLGlobalObject::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Gui::DGuiApplicationHelper::staticMetaObject>(),
    QMetaObject::SuperData::link<QQuickImage::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickDciIconImage::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DQuickDciIconImage.data,
    qt_meta_data_Dtk__Quick__DQuickDciIconImage,
    qt_static_metacall,
    qt_meta_extradata_Dtk__Quick__DQuickDciIconImage,
    nullptr
} };


const QMetaObject *Dtk::Quick::DQuickDciIconImage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickDciIconImage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DQuickDciIconImage.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Core::DObject"))
        return static_cast< Core::DObject*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Dtk::Quick::DQuickDciIconImage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 10;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickDciIconImage::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickDciIconImage::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickDciIconImage::themeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickDciIconImage::paletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickDciIconImage::sourceSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickDciIconImage::mirrorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQuickDciIconImage::fallbackToQIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Quick::DQuickDciIconImage::asynchronousChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Quick::DQuickDciIconImage::cacheChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Dtk::Quick::DQuickDciIconImage::fillModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
struct qt_meta_stringdata_Dtk__Quick__DQuickIconAttached_t {
    QByteArrayData data[13];
    char stringdata0[242];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickIconAttached_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickIconAttached_t qt_meta_stringdata_Dtk__Quick__DQuickIconAttached = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Dtk::Quick::DQuickIconAttached"
QT_MOC_LITERAL(1, 31, 11), // "modeChanged"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 12), // "themeChanged"
QT_MOC_LITERAL(4, 57, 14), // "paletteChanged"
QT_MOC_LITERAL(5, 72, 22), // "fallbackToQIconChanged"
QT_MOC_LITERAL(6, 95, 4), // "mode"
QT_MOC_LITERAL(7, 100, 42), // "Dtk::Quick::DQMLGlobalObject:..."
QT_MOC_LITERAL(8, 143, 5), // "theme"
QT_MOC_LITERAL(9, 149, 42), // "Dtk::Gui::DGuiApplicationHelp..."
QT_MOC_LITERAL(10, 192, 7), // "palette"
QT_MOC_LITERAL(11, 200, 25), // "Dtk::Gui::DDciIconPalette"
QT_MOC_LITERAL(12, 226, 15) // "fallbackToQIcon"

    },
    "Dtk::Quick::DQuickIconAttached\0"
    "modeChanged\0\0themeChanged\0paletteChanged\0"
    "fallbackToQIconChanged\0mode\0"
    "Dtk::Quick::DQMLGlobalObject::ControlState\0"
    "theme\0Dtk::Gui::DGuiApplicationHelper::ColorType\0"
    "palette\0Dtk::Gui::DDciIconPalette\0"
    "fallbackToQIcon"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickIconAttached[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       4,   38, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x06 /* Public */,
       3,    0,   35,    2, 0x06 /* Public */,
       4,    0,   36,    2, 0x06 /* Public */,
       5,    0,   37,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       6, 0x80000000 | 7, 0x0049510b,
       8, 0x80000000 | 9, 0x0049510b,
      10, 0x80000000 | 11, 0x0049510b,
      12, QMetaType::Bool, 0x00495103,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,

       0        // eod
};

void Dtk::Quick::DQuickIconAttached::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DQuickIconAttached *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->modeChanged(); break;
        case 1: _t->themeChanged(); break;
        case 2: _t->paletteChanged(); break;
        case 3: _t->fallbackToQIconChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DQuickIconAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickIconAttached::modeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DQuickIconAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickIconAttached::themeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DQuickIconAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickIconAttached::paletteChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DQuickIconAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickIconAttached::fallbackToQIconChanged)) {
                *result = 3;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DQuickIconAttached *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< Dtk::Quick::DQMLGlobalObject::ControlState*>(_v) = _t->mode(); break;
        case 1: *reinterpret_cast< Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v) = _t->theme(); break;
        case 2: *reinterpret_cast< Dtk::Gui::DDciIconPalette*>(_v) = _t->palette(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->fallbackToQIcon(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DQuickIconAttached *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMode(*reinterpret_cast< Dtk::Quick::DQMLGlobalObject::ControlState*>(_v)); break;
        case 1: _t->setTheme(*reinterpret_cast< Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v)); break;
        case 2: _t->setPalette(*reinterpret_cast< Dtk::Gui::DDciIconPalette*>(_v)); break;
        case 3: _t->setFallbackToQIcon(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

static const QMetaObject::SuperData qt_meta_extradata_Dtk__Quick__DQuickIconAttached[] = {
    QMetaObject::SuperData::link<Dtk::Quick::DQMLGlobalObject::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Gui::DGuiApplicationHelper::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickIconAttached::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DQuickIconAttached.data,
    qt_meta_data_Dtk__Quick__DQuickIconAttached,
    qt_static_metacall,
    qt_meta_extradata_Dtk__Quick__DQuickIconAttached,
    nullptr
} };


const QMetaObject *Dtk::Quick::DQuickIconAttached::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickIconAttached::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DQuickIconAttached.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Core::DObject"))
        return static_cast< Core::DObject*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DQuickIconAttached::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickIconAttached::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickIconAttached::themeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickIconAttached::paletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickIconAttached::fallbackToQIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
