/****************************************************************************
** Meta object code from reading C++ file 'dquickarrowboxpath_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/private/dquickarrowboxpath_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickarrowboxpath_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__DQuickArrowBoxPath_t {
    QByteArrayData data[25];
    char stringdata0[296];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickArrowBoxPath_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickArrowBoxPath_t qt_meta_stringdata_Dtk__Quick__DQuickArrowBoxPath = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Dtk::Quick::DQuickArrowBoxPath"
QT_MOC_LITERAL(1, 31, 12), // "widthChanged"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 13), // "heightChanged"
QT_MOC_LITERAL(4, 59, 21), // "arrowDirectionChanged"
QT_MOC_LITERAL(5, 81, 13), // "arrowXChanged"
QT_MOC_LITERAL(6, 95, 13), // "arrowYChanged"
QT_MOC_LITERAL(7, 109, 17), // "arrowWidthChanged"
QT_MOC_LITERAL(8, 127, 18), // "arrowHeightChanged"
QT_MOC_LITERAL(9, 146, 20), // "roundedRadiusChanged"
QT_MOC_LITERAL(10, 167, 13), // "spreadChanged"
QT_MOC_LITERAL(11, 181, 14), // "arrowDirection"
QT_MOC_LITERAL(12, 196, 9), // "Direction"
QT_MOC_LITERAL(13, 206, 5), // "width"
QT_MOC_LITERAL(14, 212, 6), // "height"
QT_MOC_LITERAL(15, 219, 6), // "arrowX"
QT_MOC_LITERAL(16, 226, 6), // "arrowY"
QT_MOC_LITERAL(17, 233, 10), // "arrowWidth"
QT_MOC_LITERAL(18, 244, 11), // "arrowHeight"
QT_MOC_LITERAL(19, 256, 13), // "roundedRadius"
QT_MOC_LITERAL(20, 270, 6), // "spread"
QT_MOC_LITERAL(21, 277, 2), // "Up"
QT_MOC_LITERAL(22, 280, 4), // "Down"
QT_MOC_LITERAL(23, 285, 4), // "Left"
QT_MOC_LITERAL(24, 290, 5) // "Right"

    },
    "Dtk::Quick::DQuickArrowBoxPath\0"
    "widthChanged\0\0heightChanged\0"
    "arrowDirectionChanged\0arrowXChanged\0"
    "arrowYChanged\0arrowWidthChanged\0"
    "arrowHeightChanged\0roundedRadiusChanged\0"
    "spreadChanged\0arrowDirection\0Direction\0"
    "width\0height\0arrowX\0arrowY\0arrowWidth\0"
    "arrowHeight\0roundedRadius\0spread\0Up\0"
    "Down\0Left\0Right"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickArrowBoxPath[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       9,   68, // properties
       1,  104, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    0,   60,    2, 0x06 /* Public */,
       4,    0,   61,    2, 0x06 /* Public */,
       5,    0,   62,    2, 0x06 /* Public */,
       6,    0,   63,    2, 0x06 /* Public */,
       7,    0,   64,    2, 0x06 /* Public */,
       8,    0,   65,    2, 0x06 /* Public */,
       9,    0,   66,    2, 0x06 /* Public */,
      10,    0,   67,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      11, 0x80000000 | 12, 0x0049510b,
      13, QMetaType::QReal, 0x00495103,
      14, QMetaType::QReal, 0x00495103,
      15, QMetaType::QReal, 0x00495103,
      16, QMetaType::QReal, 0x00495103,
      17, QMetaType::QReal, 0x00495103,
      18, QMetaType::QReal, 0x00495103,
      19, QMetaType::QReal, 0x00495103,
      20, QMetaType::QReal, 0x00495103,

 // properties: notify_signal_id
       2,
       0,
       1,
       3,
       4,
       5,
       6,
       7,
       8,

 // enums: name, alias, flags, count, data
      12,   12, 0x0,    4,  109,

 // enum data: key, value
      21, uint(Dtk::Quick::DQuickArrowBoxPath::Up),
      22, uint(Dtk::Quick::DQuickArrowBoxPath::Down),
      23, uint(Dtk::Quick::DQuickArrowBoxPath::Left),
      24, uint(Dtk::Quick::DQuickArrowBoxPath::Right),

       0        // eod
};

void Dtk::Quick::DQuickArrowBoxPath::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DQuickArrowBoxPath *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->widthChanged(); break;
        case 1: _t->heightChanged(); break;
        case 2: _t->arrowDirectionChanged(); break;
        case 3: _t->arrowXChanged(); break;
        case 4: _t->arrowYChanged(); break;
        case 5: _t->arrowWidthChanged(); break;
        case 6: _t->arrowHeightChanged(); break;
        case 7: _t->roundedRadiusChanged(); break;
        case 8: _t->spreadChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DQuickArrowBoxPath::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickArrowBoxPath::widthChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DQuickArrowBoxPath::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickArrowBoxPath::heightChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DQuickArrowBoxPath::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickArrowBoxPath::arrowDirectionChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DQuickArrowBoxPath::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickArrowBoxPath::arrowXChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DQuickArrowBoxPath::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickArrowBoxPath::arrowYChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DQuickArrowBoxPath::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickArrowBoxPath::arrowWidthChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DQuickArrowBoxPath::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickArrowBoxPath::arrowHeightChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DQuickArrowBoxPath::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickArrowBoxPath::roundedRadiusChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DQuickArrowBoxPath::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickArrowBoxPath::spreadChanged)) {
                *result = 8;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DQuickArrowBoxPath *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< Direction*>(_v) = _t->arrowDirection(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->width(); break;
        case 2: *reinterpret_cast< qreal*>(_v) = _t->height(); break;
        case 3: *reinterpret_cast< qreal*>(_v) = _t->arrowX(); break;
        case 4: *reinterpret_cast< qreal*>(_v) = _t->arrowY(); break;
        case 5: *reinterpret_cast< qreal*>(_v) = _t->arrowWidth(); break;
        case 6: *reinterpret_cast< qreal*>(_v) = _t->arrowHeight(); break;
        case 7: *reinterpret_cast< qreal*>(_v) = _t->roundedRadius(); break;
        case 8: *reinterpret_cast< qreal*>(_v) = _t->spread(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DQuickArrowBoxPath *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setArrowDirection(*reinterpret_cast< Direction*>(_v)); break;
        case 1: _t->setWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 2: _t->setHeight(*reinterpret_cast< qreal*>(_v)); break;
        case 3: _t->setArrowX(*reinterpret_cast< qreal*>(_v)); break;
        case 4: _t->setArrowY(*reinterpret_cast< qreal*>(_v)); break;
        case 5: _t->setArrowWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 6: _t->setArrowHeight(*reinterpret_cast< qreal*>(_v)); break;
        case 7: _t->setRoundedRadius(*reinterpret_cast< qreal*>(_v)); break;
        case 8: _t->setSpread(*reinterpret_cast< qreal*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickArrowBoxPath::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickCurve::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DQuickArrowBoxPath.data,
    qt_meta_data_Dtk__Quick__DQuickArrowBoxPath,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::DQuickArrowBoxPath::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickArrowBoxPath::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DQuickArrowBoxPath.stringdata0))
        return static_cast<void*>(this);
    return QQuickCurve::qt_metacast(_clname);
}

int Dtk::Quick::DQuickArrowBoxPath::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickCurve::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 9;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickArrowBoxPath::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickArrowBoxPath::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickArrowBoxPath::arrowDirectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickArrowBoxPath::arrowXChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickArrowBoxPath::arrowYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickArrowBoxPath::arrowWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQuickArrowBoxPath::arrowHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Quick::DQuickArrowBoxPath::roundedRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Quick::DQuickArrowBoxPath::spreadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
