/****************************************************************************
** Meta object code from reading C++ file 'dplatformthemeproxy.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/dplatformthemeproxy.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dplatformthemeproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__DPlatformThemeProxy_t {
    QByteArrayData data[141];
    char stringdata0[2036];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DPlatformThemeProxy_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DPlatformThemeProxy_t qt_meta_stringdata_Dtk__Quick__DPlatformThemeProxy = {
    {
QT_MOC_LITERAL(0, 0, 31), // "Dtk::Quick::DPlatformThemeProxy"
QT_MOC_LITERAL(1, 32, 22), // "cursorBlinkTimeChanged"
QT_MOC_LITERAL(2, 55, 0), // ""
QT_MOC_LITERAL(3, 56, 15), // "cursorBlinkTime"
QT_MOC_LITERAL(4, 72, 25), // "cursorBlinkTimeoutChanged"
QT_MOC_LITERAL(5, 98, 18), // "cursorBlinkTimeout"
QT_MOC_LITERAL(6, 117, 18), // "cursorBlinkChanged"
QT_MOC_LITERAL(7, 136, 11), // "cursorBlink"
QT_MOC_LITERAL(8, 148, 26), // "doubleClickDistanceChanged"
QT_MOC_LITERAL(9, 175, 19), // "doubleClickDistance"
QT_MOC_LITERAL(10, 195, 22), // "doubleClickTimeChanged"
QT_MOC_LITERAL(11, 218, 15), // "doubleClickTime"
QT_MOC_LITERAL(12, 234, 23), // "dndDragThresholdChanged"
QT_MOC_LITERAL(13, 258, 16), // "dndDragThreshold"
QT_MOC_LITERAL(14, 275, 16), // "themeNameChanged"
QT_MOC_LITERAL(15, 292, 9), // "themeName"
QT_MOC_LITERAL(16, 302, 20), // "iconThemeNameChanged"
QT_MOC_LITERAL(17, 323, 13), // "iconThemeName"
QT_MOC_LITERAL(18, 337, 21), // "soundThemeNameChanged"
QT_MOC_LITERAL(19, 359, 14), // "soundThemeName"
QT_MOC_LITERAL(20, 374, 15), // "fontNameChanged"
QT_MOC_LITERAL(21, 390, 8), // "fontName"
QT_MOC_LITERAL(22, 399, 19), // "monoFontNameChanged"
QT_MOC_LITERAL(23, 419, 12), // "monoFontName"
QT_MOC_LITERAL(24, 432, 20), // "fontPointSizeChanged"
QT_MOC_LITERAL(25, 453, 13), // "fontPointSize"
QT_MOC_LITERAL(26, 467, 18), // "gtkFontNameChanged"
QT_MOC_LITERAL(27, 486, 18), // "activeColorChanged"
QT_MOC_LITERAL(28, 505, 11), // "activeColor"
QT_MOC_LITERAL(29, 517, 14), // "paletteChanged"
QT_MOC_LITERAL(30, 532, 18), // "Dtk::Gui::DPalette"
QT_MOC_LITERAL(31, 551, 7), // "palette"
QT_MOC_LITERAL(32, 559, 13), // "windowChanged"
QT_MOC_LITERAL(33, 573, 6), // "window"
QT_MOC_LITERAL(34, 580, 17), // "windowTextChanged"
QT_MOC_LITERAL(35, 598, 10), // "windowText"
QT_MOC_LITERAL(36, 609, 11), // "baseChanged"
QT_MOC_LITERAL(37, 621, 4), // "base"
QT_MOC_LITERAL(38, 626, 20), // "alternateBaseChanged"
QT_MOC_LITERAL(39, 647, 13), // "alternateBase"
QT_MOC_LITERAL(40, 661, 18), // "toolTipBaseChanged"
QT_MOC_LITERAL(41, 680, 11), // "toolTipBase"
QT_MOC_LITERAL(42, 692, 18), // "toolTipTextChanged"
QT_MOC_LITERAL(43, 711, 11), // "toolTipText"
QT_MOC_LITERAL(44, 723, 11), // "textChanged"
QT_MOC_LITERAL(45, 735, 4), // "text"
QT_MOC_LITERAL(46, 740, 13), // "buttonChanged"
QT_MOC_LITERAL(47, 754, 6), // "button"
QT_MOC_LITERAL(48, 761, 17), // "buttonTextChanged"
QT_MOC_LITERAL(49, 779, 10), // "buttonText"
QT_MOC_LITERAL(50, 790, 17), // "brightTextChanged"
QT_MOC_LITERAL(51, 808, 10), // "brightText"
QT_MOC_LITERAL(52, 819, 12), // "lightChanged"
QT_MOC_LITERAL(53, 832, 5), // "light"
QT_MOC_LITERAL(54, 838, 15), // "midlightChanged"
QT_MOC_LITERAL(55, 854, 8), // "midlight"
QT_MOC_LITERAL(56, 863, 11), // "darkChanged"
QT_MOC_LITERAL(57, 875, 4), // "dark"
QT_MOC_LITERAL(58, 880, 10), // "midChanged"
QT_MOC_LITERAL(59, 891, 3), // "mid"
QT_MOC_LITERAL(60, 895, 13), // "shadowChanged"
QT_MOC_LITERAL(61, 909, 6), // "shadow"
QT_MOC_LITERAL(62, 916, 16), // "highlightChanged"
QT_MOC_LITERAL(63, 933, 9), // "highlight"
QT_MOC_LITERAL(64, 943, 22), // "highlightedTextChanged"
QT_MOC_LITERAL(65, 966, 15), // "highlightedText"
QT_MOC_LITERAL(66, 982, 11), // "linkChanged"
QT_MOC_LITERAL(67, 994, 4), // "link"
QT_MOC_LITERAL(68, 999, 18), // "linkVisitedChanged"
QT_MOC_LITERAL(69, 1018, 11), // "linkVisited"
QT_MOC_LITERAL(70, 1030, 21), // "itemBackgroundChanged"
QT_MOC_LITERAL(71, 1052, 14), // "itemBackground"
QT_MOC_LITERAL(72, 1067, 16), // "textTitleChanged"
QT_MOC_LITERAL(73, 1084, 9), // "textTitle"
QT_MOC_LITERAL(74, 1094, 15), // "textTipsChanged"
QT_MOC_LITERAL(75, 1110, 8), // "textTips"
QT_MOC_LITERAL(76, 1119, 18), // "textWarningChanged"
QT_MOC_LITERAL(77, 1138, 11), // "textWarning"
QT_MOC_LITERAL(78, 1150, 17), // "textLivelyChanged"
QT_MOC_LITERAL(79, 1168, 10), // "textLively"
QT_MOC_LITERAL(80, 1179, 18), // "lightLivelyChanged"
QT_MOC_LITERAL(81, 1198, 11), // "lightLively"
QT_MOC_LITERAL(82, 1210, 17), // "darkLivelyChanged"
QT_MOC_LITERAL(83, 1228, 10), // "darkLively"
QT_MOC_LITERAL(84, 1239, 18), // "frameBorderChanged"
QT_MOC_LITERAL(85, 1258, 11), // "frameBorder"
QT_MOC_LITERAL(86, 1270, 18), // "dotsPerInchChanged"
QT_MOC_LITERAL(87, 1289, 6), // "screen"
QT_MOC_LITERAL(88, 1296, 3), // "dpi"
QT_MOC_LITERAL(89, 1300, 19), // "windowRadiusChanged"
QT_MOC_LITERAL(90, 1320, 1), // "r"
QT_MOC_LITERAL(91, 1322, 22), // "scrollBarPolicyChanged"
QT_MOC_LITERAL(92, 1345, 18), // "setCursorBlinkTime"
QT_MOC_LITERAL(93, 1364, 21), // "setCursorBlinkTimeout"
QT_MOC_LITERAL(94, 1386, 14), // "setCursorBlink"
QT_MOC_LITERAL(95, 1401, 22), // "setDoubleClickDistance"
QT_MOC_LITERAL(96, 1424, 18), // "setDoubleClickTime"
QT_MOC_LITERAL(97, 1443, 19), // "setDndDragThreshold"
QT_MOC_LITERAL(98, 1463, 12), // "setThemeName"
QT_MOC_LITERAL(99, 1476, 16), // "setIconThemeName"
QT_MOC_LITERAL(100, 1493, 17), // "setSoundThemeName"
QT_MOC_LITERAL(101, 1511, 11), // "setFontName"
QT_MOC_LITERAL(102, 1523, 15), // "setMonoFontName"
QT_MOC_LITERAL(103, 1539, 16), // "setFontPointSize"
QT_MOC_LITERAL(104, 1556, 14), // "setGtkFontName"
QT_MOC_LITERAL(105, 1571, 14), // "setActiveColor"
QT_MOC_LITERAL(106, 1586, 9), // "setWindow"
QT_MOC_LITERAL(107, 1596, 13), // "setWindowText"
QT_MOC_LITERAL(108, 1610, 7), // "setBase"
QT_MOC_LITERAL(109, 1618, 16), // "setAlternateBase"
QT_MOC_LITERAL(110, 1635, 14), // "setToolTipBase"
QT_MOC_LITERAL(111, 1650, 14), // "setToolTipText"
QT_MOC_LITERAL(112, 1665, 7), // "setText"
QT_MOC_LITERAL(113, 1673, 9), // "setButton"
QT_MOC_LITERAL(114, 1683, 13), // "setButtonText"
QT_MOC_LITERAL(115, 1697, 13), // "setBrightText"
QT_MOC_LITERAL(116, 1711, 8), // "setLight"
QT_MOC_LITERAL(117, 1720, 11), // "setMidlight"
QT_MOC_LITERAL(118, 1732, 7), // "setDark"
QT_MOC_LITERAL(119, 1740, 6), // "setMid"
QT_MOC_LITERAL(120, 1747, 9), // "setShadow"
QT_MOC_LITERAL(121, 1757, 12), // "setHighlight"
QT_MOC_LITERAL(122, 1770, 18), // "setHighlightedText"
QT_MOC_LITERAL(123, 1789, 7), // "setLink"
QT_MOC_LITERAL(124, 1797, 14), // "setLinkVisited"
QT_MOC_LITERAL(125, 1812, 17), // "setItemBackground"
QT_MOC_LITERAL(126, 1830, 12), // "setTextTitle"
QT_MOC_LITERAL(127, 1843, 11), // "setTextTips"
QT_MOC_LITERAL(128, 1855, 14), // "setTextWarning"
QT_MOC_LITERAL(129, 1870, 13), // "setTextLively"
QT_MOC_LITERAL(130, 1884, 14), // "setLightLively"
QT_MOC_LITERAL(131, 1899, 13), // "setDarkLively"
QT_MOC_LITERAL(132, 1913, 14), // "setFrameBorder"
QT_MOC_LITERAL(133, 1928, 14), // "setDotsPerInch"
QT_MOC_LITERAL(134, 1943, 10), // "screenName"
QT_MOC_LITERAL(135, 1954, 15), // "setWindowRadius"
QT_MOC_LITERAL(136, 1970, 12), // "windowRadius"
QT_MOC_LITERAL(137, 1983, 12), // "defaultValue"
QT_MOC_LITERAL(138, 1996, 11), // "dotsPerInch"
QT_MOC_LITERAL(139, 2008, 11), // "gtkFontName"
QT_MOC_LITERAL(140, 2020, 15) // "scrollBarPolicy"

    },
    "Dtk::Quick::DPlatformThemeProxy\0"
    "cursorBlinkTimeChanged\0\0cursorBlinkTime\0"
    "cursorBlinkTimeoutChanged\0cursorBlinkTimeout\0"
    "cursorBlinkChanged\0cursorBlink\0"
    "doubleClickDistanceChanged\0"
    "doubleClickDistance\0doubleClickTimeChanged\0"
    "doubleClickTime\0dndDragThresholdChanged\0"
    "dndDragThreshold\0themeNameChanged\0"
    "themeName\0iconThemeNameChanged\0"
    "iconThemeName\0soundThemeNameChanged\0"
    "soundThemeName\0fontNameChanged\0fontName\0"
    "monoFontNameChanged\0monoFontName\0"
    "fontPointSizeChanged\0fontPointSize\0"
    "gtkFontNameChanged\0activeColorChanged\0"
    "activeColor\0paletteChanged\0"
    "Dtk::Gui::DPalette\0palette\0windowChanged\0"
    "window\0windowTextChanged\0windowText\0"
    "baseChanged\0base\0alternateBaseChanged\0"
    "alternateBase\0toolTipBaseChanged\0"
    "toolTipBase\0toolTipTextChanged\0"
    "toolTipText\0textChanged\0text\0buttonChanged\0"
    "button\0buttonTextChanged\0buttonText\0"
    "brightTextChanged\0brightText\0lightChanged\0"
    "light\0midlightChanged\0midlight\0"
    "darkChanged\0dark\0midChanged\0mid\0"
    "shadowChanged\0shadow\0highlightChanged\0"
    "highlight\0highlightedTextChanged\0"
    "highlightedText\0linkChanged\0link\0"
    "linkVisitedChanged\0linkVisited\0"
    "itemBackgroundChanged\0itemBackground\0"
    "textTitleChanged\0textTitle\0textTipsChanged\0"
    "textTips\0textWarningChanged\0textWarning\0"
    "textLivelyChanged\0textLively\0"
    "lightLivelyChanged\0lightLively\0"
    "darkLivelyChanged\0darkLively\0"
    "frameBorderChanged\0frameBorder\0"
    "dotsPerInchChanged\0screen\0dpi\0"
    "windowRadiusChanged\0r\0scrollBarPolicyChanged\0"
    "setCursorBlinkTime\0setCursorBlinkTimeout\0"
    "setCursorBlink\0setDoubleClickDistance\0"
    "setDoubleClickTime\0setDndDragThreshold\0"
    "setThemeName\0setIconThemeName\0"
    "setSoundThemeName\0setFontName\0"
    "setMonoFontName\0setFontPointSize\0"
    "setGtkFontName\0setActiveColor\0setWindow\0"
    "setWindowText\0setBase\0setAlternateBase\0"
    "setToolTipBase\0setToolTipText\0setText\0"
    "setButton\0setButtonText\0setBrightText\0"
    "setLight\0setMidlight\0setDark\0setMid\0"
    "setShadow\0setHighlight\0setHighlightedText\0"
    "setLink\0setLinkVisited\0setItemBackground\0"
    "setTextTitle\0setTextTips\0setTextWarning\0"
    "setTextLively\0setLightLively\0setDarkLively\0"
    "setFrameBorder\0setDotsPerInch\0screenName\0"
    "setWindowRadius\0windowRadius\0defaultValue\0"
    "dotsPerInch\0gtkFontName\0scrollBarPolicy"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DPlatformThemeProxy[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      91,   14, // methods
      43,  742, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      45,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  469,    2, 0x06 /* Public */,
       4,    1,  472,    2, 0x06 /* Public */,
       6,    1,  475,    2, 0x06 /* Public */,
       8,    1,  478,    2, 0x06 /* Public */,
      10,    1,  481,    2, 0x06 /* Public */,
      12,    1,  484,    2, 0x06 /* Public */,
      14,    1,  487,    2, 0x06 /* Public */,
      16,    1,  490,    2, 0x06 /* Public */,
      18,    1,  493,    2, 0x06 /* Public */,
      20,    1,  496,    2, 0x06 /* Public */,
      22,    1,  499,    2, 0x06 /* Public */,
      24,    1,  502,    2, 0x06 /* Public */,
      26,    1,  505,    2, 0x06 /* Public */,
      27,    1,  508,    2, 0x06 /* Public */,
      29,    1,  511,    2, 0x06 /* Public */,
      32,    1,  514,    2, 0x06 /* Public */,
      34,    1,  517,    2, 0x06 /* Public */,
      36,    1,  520,    2, 0x06 /* Public */,
      38,    1,  523,    2, 0x06 /* Public */,
      40,    1,  526,    2, 0x06 /* Public */,
      42,    1,  529,    2, 0x06 /* Public */,
      44,    1,  532,    2, 0x06 /* Public */,
      46,    1,  535,    2, 0x06 /* Public */,
      48,    1,  538,    2, 0x06 /* Public */,
      50,    1,  541,    2, 0x06 /* Public */,
      52,    1,  544,    2, 0x06 /* Public */,
      54,    1,  547,    2, 0x06 /* Public */,
      56,    1,  550,    2, 0x06 /* Public */,
      58,    1,  553,    2, 0x06 /* Public */,
      60,    1,  556,    2, 0x06 /* Public */,
      62,    1,  559,    2, 0x06 /* Public */,
      64,    1,  562,    2, 0x06 /* Public */,
      66,    1,  565,    2, 0x06 /* Public */,
      68,    1,  568,    2, 0x06 /* Public */,
      70,    1,  571,    2, 0x06 /* Public */,
      72,    1,  574,    2, 0x06 /* Public */,
      74,    1,  577,    2, 0x06 /* Public */,
      76,    1,  580,    2, 0x06 /* Public */,
      78,    1,  583,    2, 0x06 /* Public */,
      80,    1,  586,    2, 0x06 /* Public */,
      82,    1,  589,    2, 0x06 /* Public */,
      84,    1,  592,    2, 0x06 /* Public */,
      86,    2,  595,    2, 0x06 /* Public */,
      89,    1,  600,    2, 0x06 /* Public */,
      91,    0,  603,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      92,    1,  604,    2, 0x0a /* Public */,
      93,    1,  607,    2, 0x0a /* Public */,
      94,    1,  610,    2, 0x0a /* Public */,
      95,    1,  613,    2, 0x0a /* Public */,
      96,    1,  616,    2, 0x0a /* Public */,
      97,    1,  619,    2, 0x0a /* Public */,
      98,    1,  622,    2, 0x0a /* Public */,
      99,    1,  625,    2, 0x0a /* Public */,
     100,    1,  628,    2, 0x0a /* Public */,
     101,    1,  631,    2, 0x0a /* Public */,
     102,    1,  634,    2, 0x0a /* Public */,
     103,    1,  637,    2, 0x0a /* Public */,
     104,    1,  640,    2, 0x0a /* Public */,
     105,    1,  643,    2, 0x0a /* Public */,
     106,    1,  646,    2, 0x0a /* Public */,
     107,    1,  649,    2, 0x0a /* Public */,
     108,    1,  652,    2, 0x0a /* Public */,
     109,    1,  655,    2, 0x0a /* Public */,
     110,    1,  658,    2, 0x0a /* Public */,
     111,    1,  661,    2, 0x0a /* Public */,
     112,    1,  664,    2, 0x0a /* Public */,
     113,    1,  667,    2, 0x0a /* Public */,
     114,    1,  670,    2, 0x0a /* Public */,
     115,    1,  673,    2, 0x0a /* Public */,
     116,    1,  676,    2, 0x0a /* Public */,
     117,    1,  679,    2, 0x0a /* Public */,
     118,    1,  682,    2, 0x0a /* Public */,
     119,    1,  685,    2, 0x0a /* Public */,
     120,    1,  688,    2, 0x0a /* Public */,
     121,    1,  691,    2, 0x0a /* Public */,
     122,    1,  694,    2, 0x0a /* Public */,
     123,    1,  697,    2, 0x0a /* Public */,
     124,    1,  700,    2, 0x0a /* Public */,
     125,    1,  703,    2, 0x0a /* Public */,
     126,    1,  706,    2, 0x0a /* Public */,
     127,    1,  709,    2, 0x0a /* Public */,
     128,    1,  712,    2, 0x0a /* Public */,
     129,    1,  715,    2, 0x0a /* Public */,
     130,    1,  718,    2, 0x0a /* Public */,
     131,    1,  721,    2, 0x0a /* Public */,
     132,    1,  724,    2, 0x0a /* Public */,
     133,    2,  727,    2, 0x0a /* Public */,
     135,    1,  732,    2, 0x0a /* Public */,

 // methods: name, argc, parameters, tag, flags
     136,    1,  735,    2, 0x02 /* Public */,
     138,    1,  738,    2, 0x02 /* Public */,
     138,    0,  741,    2, 0x22 /* Public | MethodCloned */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::QByteArray,   15,
    QMetaType::Void, QMetaType::QByteArray,   17,
    QMetaType::Void, QMetaType::QByteArray,   19,
    QMetaType::Void, QMetaType::QByteArray,   21,
    QMetaType::Void, QMetaType::QByteArray,   23,
    QMetaType::Void, QMetaType::QReal,   25,
    QMetaType::Void, QMetaType::QByteArray,   21,
    QMetaType::Void, QMetaType::QColor,   28,
    QMetaType::Void, 0x80000000 | 30,   31,
    QMetaType::Void, QMetaType::QColor,   33,
    QMetaType::Void, QMetaType::QColor,   35,
    QMetaType::Void, QMetaType::QColor,   37,
    QMetaType::Void, QMetaType::QColor,   39,
    QMetaType::Void, QMetaType::QColor,   41,
    QMetaType::Void, QMetaType::QColor,   43,
    QMetaType::Void, QMetaType::QColor,   45,
    QMetaType::Void, QMetaType::QColor,   47,
    QMetaType::Void, QMetaType::QColor,   49,
    QMetaType::Void, QMetaType::QColor,   51,
    QMetaType::Void, QMetaType::QColor,   53,
    QMetaType::Void, QMetaType::QColor,   55,
    QMetaType::Void, QMetaType::QColor,   57,
    QMetaType::Void, QMetaType::QColor,   59,
    QMetaType::Void, QMetaType::QColor,   61,
    QMetaType::Void, QMetaType::QColor,   63,
    QMetaType::Void, QMetaType::QColor,   65,
    QMetaType::Void, QMetaType::QColor,   67,
    QMetaType::Void, QMetaType::QColor,   69,
    QMetaType::Void, QMetaType::QColor,   71,
    QMetaType::Void, QMetaType::QColor,   73,
    QMetaType::Void, QMetaType::QColor,   75,
    QMetaType::Void, QMetaType::QColor,   77,
    QMetaType::Void, QMetaType::QColor,   79,
    QMetaType::Void, QMetaType::QColor,   81,
    QMetaType::Void, QMetaType::QColor,   83,
    QMetaType::Void, QMetaType::QColor,   85,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,   87,   88,
    QMetaType::Void, QMetaType::Int,   90,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::QByteArray,   15,
    QMetaType::Void, QMetaType::QByteArray,   17,
    QMetaType::Void, QMetaType::QByteArray,   19,
    QMetaType::Void, QMetaType::QByteArray,   21,
    QMetaType::Void, QMetaType::QByteArray,   23,
    QMetaType::Void, QMetaType::QReal,   25,
    QMetaType::Void, QMetaType::QByteArray,   21,
    QMetaType::Void, QMetaType::QColor,   28,
    QMetaType::Void, QMetaType::QColor,   33,
    QMetaType::Void, QMetaType::QColor,   35,
    QMetaType::Void, QMetaType::QColor,   37,
    QMetaType::Void, QMetaType::QColor,   39,
    QMetaType::Void, QMetaType::QColor,   41,
    QMetaType::Void, QMetaType::QColor,   43,
    QMetaType::Void, QMetaType::QColor,   45,
    QMetaType::Void, QMetaType::QColor,   47,
    QMetaType::Void, QMetaType::QColor,   49,
    QMetaType::Void, QMetaType::QColor,   51,
    QMetaType::Void, QMetaType::QColor,   53,
    QMetaType::Void, QMetaType::QColor,   55,
    QMetaType::Void, QMetaType::QColor,   57,
    QMetaType::Void, QMetaType::QColor,   59,
    QMetaType::Void, QMetaType::QColor,   61,
    QMetaType::Void, QMetaType::QColor,   63,
    QMetaType::Void, QMetaType::QColor,   65,
    QMetaType::Void, QMetaType::QColor,   67,
    QMetaType::Void, QMetaType::QColor,   69,
    QMetaType::Void, QMetaType::QColor,   71,
    QMetaType::Void, QMetaType::QColor,   73,
    QMetaType::Void, QMetaType::QColor,   75,
    QMetaType::Void, QMetaType::QColor,   77,
    QMetaType::Void, QMetaType::QColor,   79,
    QMetaType::Void, QMetaType::QColor,   81,
    QMetaType::Void, QMetaType::QColor,   83,
    QMetaType::Void, QMetaType::QColor,   85,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,  134,   88,
    QMetaType::Void, QMetaType::Int,  136,

 // methods: parameters
    QMetaType::Int, QMetaType::Int,  137,
    QMetaType::Int, QMetaType::QString,  134,
    QMetaType::Int,

 // properties: name, type, flags
       3, QMetaType::Int, 0x00495103,
       5, QMetaType::Int, 0x00495103,
       7, QMetaType::Bool, 0x00495103,
       9, QMetaType::Int, 0x00495103,
      11, QMetaType::Int, 0x00495103,
      13, QMetaType::Int, 0x00495103,
     136, QMetaType::Int, 0x00495103,
      15, QMetaType::QByteArray, 0x00495103,
      17, QMetaType::QByteArray, 0x00495103,
      19, QMetaType::QByteArray, 0x00495103,
      21, QMetaType::QByteArray, 0x00495103,
      23, QMetaType::QByteArray, 0x00495103,
      25, QMetaType::QReal, 0x00495103,
     139, QMetaType::QByteArray, 0x00495103,
      28, QMetaType::QColor, 0x00495103,
      33, QMetaType::QColor, 0x00495103,
      35, QMetaType::QColor, 0x00495103,
      37, QMetaType::QColor, 0x00495103,
      39, QMetaType::QColor, 0x00495103,
      41, QMetaType::QColor, 0x00495103,
      43, QMetaType::QColor, 0x00495103,
      45, QMetaType::QColor, 0x00495103,
      47, QMetaType::QColor, 0x00495103,
      49, QMetaType::QColor, 0x00495103,
      51, QMetaType::QColor, 0x00495103,
      53, QMetaType::QColor, 0x00495103,
      55, QMetaType::QColor, 0x00495103,
      57, QMetaType::QColor, 0x00495103,
      59, QMetaType::QColor, 0x00495103,
      61, QMetaType::QColor, 0x00495103,
      63, QMetaType::QColor, 0x00495103,
      65, QMetaType::QColor, 0x00495103,
      67, QMetaType::QColor, 0x00495103,
      69, QMetaType::QColor, 0x00495103,
      71, QMetaType::QColor, 0x00495103,
      73, QMetaType::QColor, 0x00495103,
      75, QMetaType::QColor, 0x00495103,
      77, QMetaType::QColor, 0x00495103,
      79, QMetaType::QColor, 0x00495103,
      81, QMetaType::QColor, 0x00495103,
      83, QMetaType::QColor, 0x00495103,
      85, QMetaType::QColor, 0x00495103,
     140, QMetaType::Int, 0x00495001,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
      43,
       6,
       7,
       8,
       9,
      10,
      11,
      12,
      13,
      15,
      16,
      17,
      18,
      19,
      20,
      21,
      22,
      23,
      24,
      25,
      26,
      27,
      28,
      29,
      30,
      31,
      32,
      33,
      34,
      35,
      36,
      37,
      38,
      39,
      40,
      41,
      44,

       0        // eod
};

void Dtk::Quick::DPlatformThemeProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DPlatformThemeProxy *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->cursorBlinkTimeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->cursorBlinkTimeoutChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->cursorBlinkChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->doubleClickDistanceChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->doubleClickTimeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->dndDragThresholdChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->themeNameChanged((*reinterpret_cast< QByteArray(*)>(_a[1]))); break;
        case 7: _t->iconThemeNameChanged((*reinterpret_cast< QByteArray(*)>(_a[1]))); break;
        case 8: _t->soundThemeNameChanged((*reinterpret_cast< QByteArray(*)>(_a[1]))); break;
        case 9: _t->fontNameChanged((*reinterpret_cast< QByteArray(*)>(_a[1]))); break;
        case 10: _t->monoFontNameChanged((*reinterpret_cast< QByteArray(*)>(_a[1]))); break;
        case 11: _t->fontPointSizeChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 12: _t->gtkFontNameChanged((*reinterpret_cast< QByteArray(*)>(_a[1]))); break;
        case 13: _t->activeColorChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 14: _t->paletteChanged((*reinterpret_cast< Dtk::Gui::DPalette(*)>(_a[1]))); break;
        case 15: _t->windowChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 16: _t->windowTextChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 17: _t->baseChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 18: _t->alternateBaseChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 19: _t->toolTipBaseChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 20: _t->toolTipTextChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 21: _t->textChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 22: _t->buttonChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 23: _t->buttonTextChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 24: _t->brightTextChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 25: _t->lightChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 26: _t->midlightChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 27: _t->darkChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 28: _t->midChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 29: _t->shadowChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 30: _t->highlightChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 31: _t->highlightedTextChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 32: _t->linkChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 33: _t->linkVisitedChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 34: _t->itemBackgroundChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 35: _t->textTitleChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 36: _t->textTipsChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 37: _t->textWarningChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 38: _t->textLivelyChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 39: _t->lightLivelyChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 40: _t->darkLivelyChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 41: _t->frameBorderChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 42: _t->dotsPerInchChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 43: _t->windowRadiusChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 44: _t->scrollBarPolicyChanged(); break;
        case 45: _t->setCursorBlinkTime((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 46: _t->setCursorBlinkTimeout((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 47: _t->setCursorBlink((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 48: _t->setDoubleClickDistance((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 49: _t->setDoubleClickTime((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 50: _t->setDndDragThreshold((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 51: _t->setThemeName((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 52: _t->setIconThemeName((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 53: _t->setSoundThemeName((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 54: _t->setFontName((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 55: _t->setMonoFontName((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 56: _t->setFontPointSize((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 57: _t->setGtkFontName((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 58: _t->setActiveColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 59: _t->setWindow((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 60: _t->setWindowText((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 61: _t->setBase((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 62: _t->setAlternateBase((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 63: _t->setToolTipBase((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 64: _t->setToolTipText((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 65: _t->setText((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 66: _t->setButton((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 67: _t->setButtonText((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 68: _t->setBrightText((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 69: _t->setLight((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 70: _t->setMidlight((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 71: _t->setDark((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 72: _t->setMid((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 73: _t->setShadow((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 74: _t->setHighlight((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 75: _t->setHighlightedText((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 76: _t->setLink((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 77: _t->setLinkVisited((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 78: _t->setItemBackground((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 79: _t->setTextTitle((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 80: _t->setTextTips((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 81: _t->setTextWarning((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 82: _t->setTextLively((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 83: _t->setLightLively((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 84: _t->setDarkLively((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 85: _t->setFrameBorder((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 86: _t->setDotsPerInch((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 87: _t->setWindowRadius((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 88: { int _r = _t->windowRadius((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 89: { int _r = _t->dotsPerInch((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 90: { int _r = _t->dotsPerInch();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DPlatformThemeProxy::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::cursorBlinkTimeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::cursorBlinkTimeoutChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::cursorBlinkChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::doubleClickDistanceChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::doubleClickTimeChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::dndDragThresholdChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QByteArray );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::themeNameChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QByteArray );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::iconThemeNameChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QByteArray );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::soundThemeNameChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QByteArray );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::fontNameChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QByteArray );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::monoFontNameChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::fontPointSizeChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QByteArray );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::gtkFontNameChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::activeColorChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(Dtk::Gui::DPalette );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::paletteChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::windowChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::windowTextChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::baseChanged)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::alternateBaseChanged)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::toolTipBaseChanged)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::toolTipTextChanged)) {
                *result = 20;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::textChanged)) {
                *result = 21;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::buttonChanged)) {
                *result = 22;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::buttonTextChanged)) {
                *result = 23;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::brightTextChanged)) {
                *result = 24;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::lightChanged)) {
                *result = 25;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::midlightChanged)) {
                *result = 26;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::darkChanged)) {
                *result = 27;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::midChanged)) {
                *result = 28;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::shadowChanged)) {
                *result = 29;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::highlightChanged)) {
                *result = 30;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::highlightedTextChanged)) {
                *result = 31;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::linkChanged)) {
                *result = 32;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::linkVisitedChanged)) {
                *result = 33;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::itemBackgroundChanged)) {
                *result = 34;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::textTitleChanged)) {
                *result = 35;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::textTipsChanged)) {
                *result = 36;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::textWarningChanged)) {
                *result = 37;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::textLivelyChanged)) {
                *result = 38;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::lightLivelyChanged)) {
                *result = 39;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::darkLivelyChanged)) {
                *result = 40;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::frameBorderChanged)) {
                *result = 41;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(const QString & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::dotsPerInchChanged)) {
                *result = 42;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::windowRadiusChanged)) {
                *result = 43;
                return;
            }
        }
        {
            using _t = void (DPlatformThemeProxy::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPlatformThemeProxy::scrollBarPolicyChanged)) {
                *result = 44;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DPlatformThemeProxy *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->cursorBlinkTime(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->cursorBlinkTimeout(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->cursorBlink(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->doubleClickDistance(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->doubleClickTime(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->dndDragThreshold(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->windowRadius(); break;
        case 7: *reinterpret_cast< QByteArray*>(_v) = _t->themeName(); break;
        case 8: *reinterpret_cast< QByteArray*>(_v) = _t->iconThemeName(); break;
        case 9: *reinterpret_cast< QByteArray*>(_v) = _t->soundThemeName(); break;
        case 10: *reinterpret_cast< QByteArray*>(_v) = _t->fontName(); break;
        case 11: *reinterpret_cast< QByteArray*>(_v) = _t->monoFontName(); break;
        case 12: *reinterpret_cast< qreal*>(_v) = _t->fontPointSize(); break;
        case 13: *reinterpret_cast< QByteArray*>(_v) = _t->gtkFontName(); break;
        case 14: *reinterpret_cast< QColor*>(_v) = _t->activeColor(); break;
        case 15: *reinterpret_cast< QColor*>(_v) = _t->window(); break;
        case 16: *reinterpret_cast< QColor*>(_v) = _t->windowText(); break;
        case 17: *reinterpret_cast< QColor*>(_v) = _t->base(); break;
        case 18: *reinterpret_cast< QColor*>(_v) = _t->alternateBase(); break;
        case 19: *reinterpret_cast< QColor*>(_v) = _t->toolTipBase(); break;
        case 20: *reinterpret_cast< QColor*>(_v) = _t->toolTipText(); break;
        case 21: *reinterpret_cast< QColor*>(_v) = _t->text(); break;
        case 22: *reinterpret_cast< QColor*>(_v) = _t->button(); break;
        case 23: *reinterpret_cast< QColor*>(_v) = _t->buttonText(); break;
        case 24: *reinterpret_cast< QColor*>(_v) = _t->brightText(); break;
        case 25: *reinterpret_cast< QColor*>(_v) = _t->light(); break;
        case 26: *reinterpret_cast< QColor*>(_v) = _t->midlight(); break;
        case 27: *reinterpret_cast< QColor*>(_v) = _t->dark(); break;
        case 28: *reinterpret_cast< QColor*>(_v) = _t->mid(); break;
        case 29: *reinterpret_cast< QColor*>(_v) = _t->shadow(); break;
        case 30: *reinterpret_cast< QColor*>(_v) = _t->highlight(); break;
        case 31: *reinterpret_cast< QColor*>(_v) = _t->highlightedText(); break;
        case 32: *reinterpret_cast< QColor*>(_v) = _t->link(); break;
        case 33: *reinterpret_cast< QColor*>(_v) = _t->linkVisited(); break;
        case 34: *reinterpret_cast< QColor*>(_v) = _t->itemBackground(); break;
        case 35: *reinterpret_cast< QColor*>(_v) = _t->textTitle(); break;
        case 36: *reinterpret_cast< QColor*>(_v) = _t->textTips(); break;
        case 37: *reinterpret_cast< QColor*>(_v) = _t->textWarning(); break;
        case 38: *reinterpret_cast< QColor*>(_v) = _t->textLively(); break;
        case 39: *reinterpret_cast< QColor*>(_v) = _t->lightLively(); break;
        case 40: *reinterpret_cast< QColor*>(_v) = _t->darkLively(); break;
        case 41: *reinterpret_cast< QColor*>(_v) = _t->frameBorder(); break;
        case 42: *reinterpret_cast< int*>(_v) = _t->scrollBarPolicy(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DPlatformThemeProxy *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCursorBlinkTime(*reinterpret_cast< int*>(_v)); break;
        case 1: _t->setCursorBlinkTimeout(*reinterpret_cast< int*>(_v)); break;
        case 2: _t->setCursorBlink(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setDoubleClickDistance(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setDoubleClickTime(*reinterpret_cast< int*>(_v)); break;
        case 5: _t->setDndDragThreshold(*reinterpret_cast< int*>(_v)); break;
        case 6: _t->setWindowRadius(*reinterpret_cast< int*>(_v)); break;
        case 7: _t->setThemeName(*reinterpret_cast< QByteArray*>(_v)); break;
        case 8: _t->setIconThemeName(*reinterpret_cast< QByteArray*>(_v)); break;
        case 9: _t->setSoundThemeName(*reinterpret_cast< QByteArray*>(_v)); break;
        case 10: _t->setFontName(*reinterpret_cast< QByteArray*>(_v)); break;
        case 11: _t->setMonoFontName(*reinterpret_cast< QByteArray*>(_v)); break;
        case 12: _t->setFontPointSize(*reinterpret_cast< qreal*>(_v)); break;
        case 13: _t->setGtkFontName(*reinterpret_cast< QByteArray*>(_v)); break;
        case 14: _t->setActiveColor(*reinterpret_cast< QColor*>(_v)); break;
        case 15: _t->setWindow(*reinterpret_cast< QColor*>(_v)); break;
        case 16: _t->setWindowText(*reinterpret_cast< QColor*>(_v)); break;
        case 17: _t->setBase(*reinterpret_cast< QColor*>(_v)); break;
        case 18: _t->setAlternateBase(*reinterpret_cast< QColor*>(_v)); break;
        case 19: _t->setToolTipBase(*reinterpret_cast< QColor*>(_v)); break;
        case 20: _t->setToolTipText(*reinterpret_cast< QColor*>(_v)); break;
        case 21: _t->setText(*reinterpret_cast< QColor*>(_v)); break;
        case 22: _t->setButton(*reinterpret_cast< QColor*>(_v)); break;
        case 23: _t->setButtonText(*reinterpret_cast< QColor*>(_v)); break;
        case 24: _t->setBrightText(*reinterpret_cast< QColor*>(_v)); break;
        case 25: _t->setLight(*reinterpret_cast< QColor*>(_v)); break;
        case 26: _t->setMidlight(*reinterpret_cast< QColor*>(_v)); break;
        case 27: _t->setDark(*reinterpret_cast< QColor*>(_v)); break;
        case 28: _t->setMid(*reinterpret_cast< QColor*>(_v)); break;
        case 29: _t->setShadow(*reinterpret_cast< QColor*>(_v)); break;
        case 30: _t->setHighlight(*reinterpret_cast< QColor*>(_v)); break;
        case 31: _t->setHighlightedText(*reinterpret_cast< QColor*>(_v)); break;
        case 32: _t->setLink(*reinterpret_cast< QColor*>(_v)); break;
        case 33: _t->setLinkVisited(*reinterpret_cast< QColor*>(_v)); break;
        case 34: _t->setItemBackground(*reinterpret_cast< QColor*>(_v)); break;
        case 35: _t->setTextTitle(*reinterpret_cast< QColor*>(_v)); break;
        case 36: _t->setTextTips(*reinterpret_cast< QColor*>(_v)); break;
        case 37: _t->setTextWarning(*reinterpret_cast< QColor*>(_v)); break;
        case 38: _t->setTextLively(*reinterpret_cast< QColor*>(_v)); break;
        case 39: _t->setLightLively(*reinterpret_cast< QColor*>(_v)); break;
        case 40: _t->setDarkLively(*reinterpret_cast< QColor*>(_v)); break;
        case 41: _t->setFrameBorder(*reinterpret_cast< QColor*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DPlatformThemeProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DPlatformThemeProxy.data,
    qt_meta_data_Dtk__Quick__DPlatformThemeProxy,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::DPlatformThemeProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DPlatformThemeProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DPlatformThemeProxy.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DPlatformThemeProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 91)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 91;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 91)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 91;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 43;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 43;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 43;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 43;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 43;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DPlatformThemeProxy::cursorBlinkTimeChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dtk::Quick::DPlatformThemeProxy::cursorBlinkTimeoutChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Dtk::Quick::DPlatformThemeProxy::cursorBlinkChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dtk::Quick::DPlatformThemeProxy::doubleClickDistanceChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Dtk::Quick::DPlatformThemeProxy::doubleClickTimeChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Dtk::Quick::DPlatformThemeProxy::dndDragThresholdChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Dtk::Quick::DPlatformThemeProxy::themeNameChanged(QByteArray _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Dtk::Quick::DPlatformThemeProxy::iconThemeNameChanged(QByteArray _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Dtk::Quick::DPlatformThemeProxy::soundThemeNameChanged(QByteArray _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Dtk::Quick::DPlatformThemeProxy::fontNameChanged(QByteArray _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Dtk::Quick::DPlatformThemeProxy::monoFontNameChanged(QByteArray _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Dtk::Quick::DPlatformThemeProxy::fontPointSizeChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void Dtk::Quick::DPlatformThemeProxy::gtkFontNameChanged(QByteArray _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void Dtk::Quick::DPlatformThemeProxy::activeColorChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void Dtk::Quick::DPlatformThemeProxy::paletteChanged(Dtk::Gui::DPalette _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void Dtk::Quick::DPlatformThemeProxy::windowChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void Dtk::Quick::DPlatformThemeProxy::windowTextChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void Dtk::Quick::DPlatformThemeProxy::baseChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void Dtk::Quick::DPlatformThemeProxy::alternateBaseChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void Dtk::Quick::DPlatformThemeProxy::toolTipBaseChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void Dtk::Quick::DPlatformThemeProxy::toolTipTextChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void Dtk::Quick::DPlatformThemeProxy::textChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 21, _a);
}

// SIGNAL 22
void Dtk::Quick::DPlatformThemeProxy::buttonChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 22, _a);
}

// SIGNAL 23
void Dtk::Quick::DPlatformThemeProxy::buttonTextChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 23, _a);
}

// SIGNAL 24
void Dtk::Quick::DPlatformThemeProxy::brightTextChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 24, _a);
}

// SIGNAL 25
void Dtk::Quick::DPlatformThemeProxy::lightChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 25, _a);
}

// SIGNAL 26
void Dtk::Quick::DPlatformThemeProxy::midlightChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 26, _a);
}

// SIGNAL 27
void Dtk::Quick::DPlatformThemeProxy::darkChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 27, _a);
}

// SIGNAL 28
void Dtk::Quick::DPlatformThemeProxy::midChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 28, _a);
}

// SIGNAL 29
void Dtk::Quick::DPlatformThemeProxy::shadowChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 29, _a);
}

// SIGNAL 30
void Dtk::Quick::DPlatformThemeProxy::highlightChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 30, _a);
}

// SIGNAL 31
void Dtk::Quick::DPlatformThemeProxy::highlightedTextChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 31, _a);
}

// SIGNAL 32
void Dtk::Quick::DPlatformThemeProxy::linkChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 32, _a);
}

// SIGNAL 33
void Dtk::Quick::DPlatformThemeProxy::linkVisitedChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 33, _a);
}

// SIGNAL 34
void Dtk::Quick::DPlatformThemeProxy::itemBackgroundChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 34, _a);
}

// SIGNAL 35
void Dtk::Quick::DPlatformThemeProxy::textTitleChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 35, _a);
}

// SIGNAL 36
void Dtk::Quick::DPlatformThemeProxy::textTipsChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 36, _a);
}

// SIGNAL 37
void Dtk::Quick::DPlatformThemeProxy::textWarningChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 37, _a);
}

// SIGNAL 38
void Dtk::Quick::DPlatformThemeProxy::textLivelyChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 38, _a);
}

// SIGNAL 39
void Dtk::Quick::DPlatformThemeProxy::lightLivelyChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 39, _a);
}

// SIGNAL 40
void Dtk::Quick::DPlatformThemeProxy::darkLivelyChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 40, _a);
}

// SIGNAL 41
void Dtk::Quick::DPlatformThemeProxy::frameBorderChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 41, _a);
}

// SIGNAL 42
void Dtk::Quick::DPlatformThemeProxy::dotsPerInchChanged(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 42, _a);
}

// SIGNAL 43
void Dtk::Quick::DPlatformThemeProxy::windowRadiusChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 43, _a);
}

// SIGNAL 44
void Dtk::Quick::DPlatformThemeProxy::scrollBarPolicyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
