/****************************************************************************
** Meta object code from reading C++ file 'dmessagemanager_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/private/dmessagemanager_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dmessagemanager_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__FloatingMessageContainer_t {
    QByteArrayData data[11];
    char stringdata0[146];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__FloatingMessageContainer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__FloatingMessageContainer_t qt_meta_stringdata_Dtk__Quick__FloatingMessageContainer = {
    {
QT_MOC_LITERAL(0, 0, 36), // "Dtk::Quick::FloatingMessageCo..."
QT_MOC_LITERAL(1, 37, 15), // "DefaultProperty"
QT_MOC_LITERAL(2, 53, 5), // "panel"
QT_MOC_LITERAL(3, 59, 14), // "messageChanged"
QT_MOC_LITERAL(4, 74, 0), // ""
QT_MOC_LITERAL(5, 75, 15), // "durationChanged"
QT_MOC_LITERAL(6, 91, 10), // "delayClose"
QT_MOC_LITERAL(7, 102, 11), // "QQuickItem*"
QT_MOC_LITERAL(8, 114, 7), // "message"
QT_MOC_LITERAL(9, 122, 8), // "duration"
QT_MOC_LITERAL(10, 131, 14) // "immediateClose"

    },
    "Dtk::Quick::FloatingMessageContainer\0"
    "DefaultProperty\0panel\0messageChanged\0"
    "\0durationChanged\0delayClose\0QQuickItem*\0"
    "message\0duration\0immediateClose"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__FloatingMessageContainer[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
       3,   16, // methods
       4,   34, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,   31,    4, 0x06 /* Public */,
       5,    0,   32,    4, 0x06 /* Public */,
       6,    0,   33,    4, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       2, 0x80000000 | 7, 0x0009510b,
       8, QMetaType::QVariant, 0x00495103,
       9, QMetaType::Int, 0x00495103,
      10, QMetaType::Bool, 0x00095103,

 // properties: notify_signal_id
       0,
       0,
       1,
       0,

       0        // eod
};

void Dtk::Quick::FloatingMessageContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FloatingMessageContainer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->messageChanged(); break;
        case 1: _t->durationChanged(); break;
        case 2: _t->delayClose(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (FloatingMessageContainer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FloatingMessageContainer::messageChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (FloatingMessageContainer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FloatingMessageContainer::durationChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (FloatingMessageContainer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FloatingMessageContainer::delayClose)) {
                *result = 2;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<FloatingMessageContainer *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QQuickItem**>(_v) = _t->panel(); break;
        case 1: *reinterpret_cast< QVariant*>(_v) = _t->message(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->duration(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->immediateClose(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<FloatingMessageContainer *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPanel(*reinterpret_cast< QQuickItem**>(_v)); break;
        case 1: _t->setMessage(*reinterpret_cast< QVariant*>(_v)); break;
        case 2: _t->setDuration(*reinterpret_cast< int*>(_v)); break;
        case 3: _t->setImmediateClose(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::FloatingMessageContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__FloatingMessageContainer.data,
    qt_meta_data_Dtk__Quick__FloatingMessageContainer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::FloatingMessageContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::FloatingMessageContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__FloatingMessageContainer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::FloatingMessageContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::FloatingMessageContainer::messageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::FloatingMessageContainer::durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::FloatingMessageContainer::delayClose()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
struct qt_meta_stringdata_Dtk__Quick__MessageManager_t {
    QByteArrayData data[17];
    char stringdata0[195];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__MessageManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__MessageManager_t qt_meta_stringdata_Dtk__Quick__MessageManager = {
    {
QT_MOC_LITERAL(0, 0, 26), // "Dtk::Quick::MessageManager"
QT_MOC_LITERAL(1, 27, 12), // "countChanged"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 11), // "sendMessage"
QT_MOC_LITERAL(4, 53, 7), // "content"
QT_MOC_LITERAL(5, 61, 8), // "iconName"
QT_MOC_LITERAL(6, 70, 8), // "duration"
QT_MOC_LITERAL(7, 79, 5), // "msgId"
QT_MOC_LITERAL(8, 85, 14), // "QQmlComponent*"
QT_MOC_LITERAL(9, 100, 8), // "delegate"
QT_MOC_LITERAL(10, 109, 7), // "message"
QT_MOC_LITERAL(11, 117, 5), // "close"
QT_MOC_LITERAL(12, 123, 37), // "Dtk::Quick::FloatingMessageCo..."
QT_MOC_LITERAL(13, 161, 6), // "layout"
QT_MOC_LITERAL(14, 168, 11), // "QQuickItem*"
QT_MOC_LITERAL(15, 180, 8), // "capacity"
QT_MOC_LITERAL(16, 189, 5) // "count"

    },
    "Dtk::Quick::MessageManager\0countChanged\0"
    "\0sendMessage\0content\0iconName\0duration\0"
    "msgId\0QQmlComponent*\0delegate\0message\0"
    "close\0Dtk::Quick::FloatingMessageContainer*\0"
    "layout\0QQuickItem*\0capacity\0count"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__MessageManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       4,  116, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    4,   65,    2, 0x0a /* Public */,
       3,    3,   74,    2, 0x2a /* Public | MethodCloned */,
       3,    2,   81,    2, 0x2a /* Public | MethodCloned */,
       3,    1,   86,    2, 0x2a /* Public | MethodCloned */,
       3,    4,   89,    2, 0x0a /* Public */,
       3,    3,   98,    2, 0x2a /* Public | MethodCloned */,
       3,    2,  105,    2, 0x2a /* Public | MethodCloned */,
      11,    1,  110,    2, 0x0a /* Public */,
      11,    1,  113,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Bool, QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::QString,    4,    5,    6,    7,
    QMetaType::Bool, QMetaType::QString, QMetaType::QString, QMetaType::Int,    4,    5,    6,
    QMetaType::Bool, QMetaType::QString, QMetaType::QString,    4,    5,
    QMetaType::Bool, QMetaType::QString,    4,
    QMetaType::Bool, 0x80000000 | 8, QMetaType::QVariant, QMetaType::Int, QMetaType::QString,    9,   10,    6,    7,
    QMetaType::Bool, 0x80000000 | 8, QMetaType::QVariant, QMetaType::Int,    9,   10,    6,
    QMetaType::Bool, 0x80000000 | 8, QMetaType::QVariant,    9,   10,
    QMetaType::Void, 0x80000000 | 12,   10,
    QMetaType::Void, QMetaType::QString,    7,

 // properties: name, type, flags
       9, 0x80000000 | 8, 0x0009510b,
      13, 0x80000000 | 14, 0x0009510b,
      15, QMetaType::Int, 0x00095103,
      16, QMetaType::Int, 0x00495001,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,

       0        // eod
};

void Dtk::Quick::MessageManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MessageManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->countChanged(); break;
        case 1: { bool _r = _t->sendMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->sendMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->sendMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->sendMessage((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->sendMessage((*reinterpret_cast< QQmlComponent*(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->sendMessage((*reinterpret_cast< QQmlComponent*(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->sendMessage((*reinterpret_cast< QQmlComponent*(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->close((*reinterpret_cast< Dtk::Quick::FloatingMessageContainer*(*)>(_a[1]))); break;
        case 9: _t->close((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Dtk::Quick::FloatingMessageContainer* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MessageManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MessageManager::countChanged)) {
                *result = 0;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<MessageManager *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QQmlComponent**>(_v) = _t->delegate(); break;
        case 1: *reinterpret_cast< QQuickItem**>(_v) = _t->layout(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->capacity(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->count(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<MessageManager *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDelegate(*reinterpret_cast< QQmlComponent**>(_v)); break;
        case 1: _t->setLayout(*reinterpret_cast< QQuickItem**>(_v)); break;
        case 2: _t->setCapacity(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::MessageManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__MessageManager.data,
    qt_meta_data_Dtk__Quick__MessageManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::MessageManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::MessageManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__MessageManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::MessageManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::MessageManager::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
