/****************************************************************************
** Meta object code from reading C++ file 'dquickdciicon_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/private/dquickdciicon_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickdciicon_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick13DQuickDciIconE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickDciIcon::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick13DQuickDciIconE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickDciIcon",
        "QML.Element",
        "anonymous",
        "name",
        "width",
        "height",
        "mode",
        "Dtk::Quick::DQMLGlobalObject::ControlState",
        "theme",
        "Dtk::Gui::DGuiApplicationHelper::ColorType",
        "palette",
        "Dtk::Gui::DDciIconPalette",
        "source",
        "QUrl",
        "fallbackToQIcon"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final),
        // property 'width'
        QtMocHelpers::PropertyData<int>(4, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final),
        // property 'height'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final),
        // property 'mode'
        QtMocHelpers::PropertyData<Dtk::Quick::DQMLGlobalObject::ControlState>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
        // property 'theme'
        QtMocHelpers::PropertyData<Dtk::Gui::DGuiApplicationHelper::ColorType>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
        // property 'palette'
        QtMocHelpers::PropertyData<Dtk::Gui::DDciIconPalette>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
        // property 'fallbackToQIcon'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DQuickDciIcon, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3Dtk5Quick13DQuickDciIconE[] = {
    QMetaObject::SuperData::link<Dtk::Quick::DQMLGlobalObject::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Gui::DGuiApplicationHelper::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickDciIcon::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick13DQuickDciIconE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick13DQuickDciIconE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3Dtk5Quick13DQuickDciIconE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick13DQuickDciIconE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickDciIcon::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<DQuickDciIcon *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->width(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->height(); break;
        case 3: *reinterpret_cast<Dtk::Quick::DQMLGlobalObject::ControlState*>(_v) = _t->mode(); break;
        case 4: *reinterpret_cast<Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v) = _t->theme(); break;
        case 5: *reinterpret_cast<Dtk::Gui::DDciIconPalette*>(_v) = _t->palette(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->fallbackToQIcon(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setWidth(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setHeight(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setMode(*reinterpret_cast<Dtk::Quick::DQMLGlobalObject::ControlState*>(_v)); break;
        case 4: _t->setTheme(*reinterpret_cast<Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v)); break;
        case 5: _t->setPalette(*reinterpret_cast<Dtk::Gui::DDciIconPalette*>(_v)); break;
        case 6: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        case 7: _t->setFallbackToQIcon(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 0: _t->resetName(); break;
        case 1: _t->resetWidth(); break;
        case 2: _t->resetHeight(); break;
        case 3: _t->resetMode(); break;
        case 4: _t->resetTheme(); break;
        case 5: _t->resetTheme(); break;
        case 6: _t->resetSource(); break;
        case 7: _t->resetFallbackToQIcon(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
