#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _org_deepin_dtk_SearchEdit_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_LineEdit_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ControlBackground_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_PasswordEdit_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ButtonBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_FloatingButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_IconButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_RecommandButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ToolButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_WarningButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_FocusBoxBorder_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_CicleSpreadAnimation_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_TitleBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_DialogTitleBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_WindowButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_WindowButtonGroup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_DialogWindow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_AboutDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_HelpAction_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_AboutAction_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_QuitAction_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ThemeMenu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_RectangularShadow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_AlertToolTip_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_FlowStyle_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Button_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Control_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_PlusMinusSpinBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_EditPanel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_TextArea_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_TextField_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_SpinBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_SpinBoxIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ApplicationWindow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_BoxShadow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_FloatingPanel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_FloatingMessage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Menu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_MenuItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_MenuSeparator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_HighlightPanel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ArrowListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ScrollIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_StyledBehindWindowBlur_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Popup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_PopupWindow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Switch_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Slider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_SliderHandle_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ScrollBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ComboBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ActionButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ItemDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_CheckDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_TipsSlider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_SliderTipItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_BoxInsetShadow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_CheckBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_IpV4LineEdit_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_OutsideBoxBorder_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_InsideBoxBorder_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_SortFilterModel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ArrowShapePopupWindow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_StyledArrowShapeWindow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ArrowShapePopup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Action_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ActionGroup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Label_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Container_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ButtonGroup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ScrollView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_MenuBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_AbstractButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_TabBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_SwipeDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_SwipeView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Drawer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Dial_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Dialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_DelayButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_RoundButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_RadioButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ToolTip_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_DialogButtonBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Frame_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_GroupBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_PageIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_StackView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_BusyIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ProgressBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_BoxPanel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_Pane_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_KeySequenceEdit_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ButtonIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_EmbeddedProgressBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_WaterProgressBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_PlaceholderText_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ControlGroup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_ControlGroupItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_DragItemsImage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_deepin_dtk_LicenseDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/SearchEdit.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_SearchEdit_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/LineEdit.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_LineEdit_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ControlBackground.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ControlBackground_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/PasswordEdit.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_PasswordEdit_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ButtonBox.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ButtonBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/FloatingButton.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_FloatingButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/IconButton.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_IconButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/RecommandButton.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_RecommandButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ToolButton.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ToolButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/WarningButton.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_WarningButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/FocusBoxBorder.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_FocusBoxBorder_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/CicleSpreadAnimation.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_CicleSpreadAnimation_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/TitleBar.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_TitleBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/DialogTitleBar.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_DialogTitleBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/WindowButton.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_WindowButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/WindowButtonGroup.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_WindowButtonGroup_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/DialogWindow.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_DialogWindow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/AboutDialog.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_AboutDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/HelpAction.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_HelpAction_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/AboutAction.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_AboutAction_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/QuitAction.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_QuitAction_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ThemeMenu.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ThemeMenu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/RectangularShadow.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_RectangularShadow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/AlertToolTip.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_AlertToolTip_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/FlowStyle.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_FlowStyle_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Button.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Button_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Control.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Control_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/PlusMinusSpinBox.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_PlusMinusSpinBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/EditPanel.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_EditPanel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/TextArea.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_TextArea_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/TextField.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_TextField_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/SpinBox.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_SpinBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/SpinBoxIndicator.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_SpinBoxIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ApplicationWindow.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ApplicationWindow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/BoxShadow.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_BoxShadow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/FloatingPanel.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_FloatingPanel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/FloatingMessage.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_FloatingMessage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Menu.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Menu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/MenuItem.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_MenuItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/MenuSeparator.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_MenuSeparator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/HighlightPanel.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_HighlightPanel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ArrowListView.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ArrowListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ScrollIndicator.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ScrollIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/StyledBehindWindowBlur.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_StyledBehindWindowBlur_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Popup.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Popup_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/PopupWindow.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_PopupWindow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Switch.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Switch_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Slider.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Slider_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/SliderHandle.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_SliderHandle_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ScrollBar.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ScrollBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ComboBox.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ComboBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ActionButton.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ActionButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ItemDelegate.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ItemDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ListView.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/CheckDelegate.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_CheckDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/TipsSlider.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_TipsSlider_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/SliderTipItem.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_SliderTipItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/BoxInsetShadow.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_BoxInsetShadow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/CheckBox.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_CheckBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/IpV4LineEdit.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_IpV4LineEdit_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/OutsideBoxBorder.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_OutsideBoxBorder_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/InsideBoxBorder.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_InsideBoxBorder_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/SortFilterModel.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_SortFilterModel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ArrowShapePopupWindow.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ArrowShapePopupWindow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/StyledArrowShapeWindow.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_StyledArrowShapeWindow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ArrowShapePopup.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ArrowShapePopup_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Action.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Action_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ActionGroup.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ActionGroup_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Label.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Label_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Container.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Container_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ButtonGroup.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ButtonGroup_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ScrollView.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ScrollView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/MenuBar.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_MenuBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/AbstractButton.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_AbstractButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/TabBar.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_TabBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/SwipeDelegate.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_SwipeDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/SwipeView.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_SwipeView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Drawer.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Drawer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Dial.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Dial_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Dialog.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Dialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/DelayButton.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_DelayButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/RoundButton.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_RoundButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/RadioButton.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_RadioButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ToolTip.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ToolTip_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/DialogButtonBox.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_DialogButtonBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Frame.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Frame_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/GroupBox.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_GroupBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/PageIndicator.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_PageIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/StackView.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_StackView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/BusyIndicator.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_BusyIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ProgressBar.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ProgressBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/BoxPanel.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_BoxPanel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/Pane.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_Pane_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/KeySequenceEdit.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_KeySequenceEdit_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ButtonIndicator.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ButtonIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/EmbeddedProgressBar.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_EmbeddedProgressBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/WaterProgressBar.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_WaterProgressBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/PlaceholderText.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_PlaceholderText_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ControlGroup.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ControlGroup_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/ControlGroupItem.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_ControlGroupItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/DragItemsImage.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_DragItemsImage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/deepin/dtk/LicenseDialog.qml"), &QmlCacheGeneratedCode::_org_deepin_dtk_LicenseDialog_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_dtk6declarative)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_dtk6declarative))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_dtk6declarative)() {
    return 1;
}
