/****************************************************************************
** Meta object code from reading C++ file 'dquickitemviewport.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/dquickitemviewport.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickitemviewport.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick18DQuickItemViewportE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickItemViewport::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick18DQuickItemViewportE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickItemViewport",
        "QML.Element",
        "ItemViewport",
        "sourceItemChanged",
        "",
        "sourceRectChanged",
        "radiusChanged",
        "fixedChanged",
        "hideSourceChanged",
        "compositionModeChanged",
        "invalidateSceneGraph",
        "sourceItem",
        "QQuickItem*",
        "sourceRect",
        "QRectF",
        "radius",
        "fixed",
        "hideSource",
        "compositionMode",
        "QPainter::CompositionMode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceItemChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceRectChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'radiusChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fixedChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hideSourceChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'compositionModeChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'invalidateSceneGraph'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sourceItem'
        QtMocHelpers::PropertyData<QQuickItem*>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'sourceRect'
        QtMocHelpers::PropertyData<QRectF>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'radius'
        QtMocHelpers::PropertyData<float>(15, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'fixed'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'hideSource'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'compositionMode'
        QtMocHelpers::PropertyData<QPainter::CompositionMode>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DQuickItemViewport, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3Dtk5Quick18DQuickItemViewportE[] = {
    QMetaObject::SuperData::link<QPainter::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickItemViewport::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickItemViewportE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickItemViewportE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3Dtk5Quick18DQuickItemViewportE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick18DQuickItemViewportE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickItemViewport::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickItemViewport *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceItemChanged(); break;
        case 1: _t->sourceRectChanged(); break;
        case 2: _t->radiusChanged(); break;
        case 3: _t->fixedChanged(); break;
        case 4: _t->hideSourceChanged(); break;
        case 5: _t->compositionModeChanged(); break;
        case 6: _t->invalidateSceneGraph(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQuickItemViewport::*)()>(_a, &DQuickItemViewport::sourceItemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickItemViewport::*)()>(_a, &DQuickItemViewport::sourceRectChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickItemViewport::*)()>(_a, &DQuickItemViewport::radiusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickItemViewport::*)()>(_a, &DQuickItemViewport::fixedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickItemViewport::*)()>(_a, &DQuickItemViewport::hideSourceChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickItemViewport::*)()>(_a, &DQuickItemViewport::compositionModeChanged, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->sourceItem(); break;
        case 1: *reinterpret_cast<QRectF*>(_v) = _t->sourceRect(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->radius(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->fixed(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hideSource(); break;
        case 5: *reinterpret_cast<QPainter::CompositionMode*>(_v) = _t->compositionMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSourceItem(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 1: _t->setSourceRect(*reinterpret_cast<QRectF*>(_v)); break;
        case 2: _t->setRadius(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setFixed(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setHideSource(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setCompositionMode(*reinterpret_cast<QPainter::CompositionMode*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 5: _t->resetCompositionMode(); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::DQuickItemViewport::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickItemViewport::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickItemViewportE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Core::DObject"))
        return static_cast< Core::DObject*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Dtk::Quick::DQuickItemViewport::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickItemViewport::sourceItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickItemViewport::sourceRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickItemViewport::radiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickItemViewport::fixedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickItemViewport::hideSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickItemViewport::compositionModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
