/****************************************************************************
** Meta object code from reading C++ file 'dquickwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/dquickwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__DQuickWindow_t {
    QByteArrayData data[1];
    char stringdata0[25];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickWindow_t qt_meta_stringdata_Dtk__Quick__DQuickWindow = {
    {
QT_MOC_LITERAL(0, 0, 24) // "Dtk::Quick::DQuickWindow"

    },
    "Dtk::Quick::DQuickWindow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Dtk::Quick::DQuickWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickWindow::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DQuickWindow.data,
    qt_meta_data_Dtk__Quick__DQuickWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::DQuickWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DQuickWindow.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QQuickWindow::qt_metacast(_clname);
}

int Dtk::Quick::DQuickWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickWindow::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Dtk__Quick__DQuickWindowAttached_t {
    QByteArrayData data[99];
    char stringdata0[1857];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickWindowAttached_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickWindowAttached_t qt_meta_stringdata_Dtk__Quick__DQuickWindowAttached = {
    {
QT_MOC_LITERAL(0, 0, 32), // "Dtk::Quick::DQuickWindowAttached"
QT_MOC_LITERAL(1, 33, 14), // "enabledChanged"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 19), // "windowRadiusChanged"
QT_MOC_LITERAL(4, 69, 18), // "borderWidthChanged"
QT_MOC_LITERAL(5, 88, 18), // "borderColorChanged"
QT_MOC_LITERAL(6, 107, 19), // "shadowRadiusChanged"
QT_MOC_LITERAL(7, 127, 19), // "shadowOffsetChanged"
QT_MOC_LITERAL(8, 147, 18), // "shadowColorChanged"
QT_MOC_LITERAL(9, 166, 28), // "translucentBackgroundChanged"
QT_MOC_LITERAL(10, 195, 25), // "enableSystemResizeChanged"
QT_MOC_LITERAL(11, 221, 23), // "enableSystemMoveChanged"
QT_MOC_LITERAL(12, 245, 23), // "enableBlurWindowChanged"
QT_MOC_LITERAL(13, 269, 20), // "wmWindowTypesChanged"
QT_MOC_LITERAL(14, 290, 21), // "motifFunctionsChanged"
QT_MOC_LITERAL(15, 312, 23), // "motifDecorationsChanged"
QT_MOC_LITERAL(16, 336, 22), // "alphaBufferSizeChanged"
QT_MOC_LITERAL(17, 359, 15), // "clipPathChanged"
QT_MOC_LITERAL(18, 375, 20), // "overlayExitedChanged"
QT_MOC_LITERAL(19, 396, 21), // "loadingOverlayChanged"
QT_MOC_LITERAL(20, 418, 16), // "appLoaderChanged"
QT_MOC_LITERAL(21, 435, 19), // "windowEffectChanged"
QT_MOC_LITERAL(22, 455, 26), // "windowStartUpEffectChanged"
QT_MOC_LITERAL(23, 482, 10), // "setEnabled"
QT_MOC_LITERAL(24, 493, 1), // "e"
QT_MOC_LITERAL(25, 495, 15), // "setWindowRadius"
QT_MOC_LITERAL(26, 511, 12), // "windowRadius"
QT_MOC_LITERAL(27, 524, 14), // "setBorderWidth"
QT_MOC_LITERAL(28, 539, 11), // "borderWidth"
QT_MOC_LITERAL(29, 551, 14), // "setBorderColor"
QT_MOC_LITERAL(30, 566, 11), // "borderColor"
QT_MOC_LITERAL(31, 578, 15), // "setShadowRadius"
QT_MOC_LITERAL(32, 594, 12), // "shadowRadius"
QT_MOC_LITERAL(33, 607, 15), // "setShadowOffset"
QT_MOC_LITERAL(34, 623, 12), // "shadowOffset"
QT_MOC_LITERAL(35, 636, 14), // "setShadowColor"
QT_MOC_LITERAL(36, 651, 11), // "shadowColor"
QT_MOC_LITERAL(37, 663, 24), // "setTranslucentBackground"
QT_MOC_LITERAL(38, 688, 21), // "translucentBackground"
QT_MOC_LITERAL(39, 710, 21), // "setEnableSystemResize"
QT_MOC_LITERAL(40, 732, 18), // "enableSystemResize"
QT_MOC_LITERAL(41, 751, 19), // "setEnableSystemMove"
QT_MOC_LITERAL(42, 771, 16), // "enableSystemMove"
QT_MOC_LITERAL(43, 788, 19), // "setEnableBlurWindow"
QT_MOC_LITERAL(44, 808, 16), // "enableBlurWindow"
QT_MOC_LITERAL(45, 825, 18), // "setAlphaBufferSize"
QT_MOC_LITERAL(46, 844, 4), // "size"
QT_MOC_LITERAL(47, 849, 16), // "setWmWindowTypes"
QT_MOC_LITERAL(48, 866, 45), // "Dtk::Gui::DWindowManagerHelpe..."
QT_MOC_LITERAL(49, 912, 13), // "wmWindowTypes"
QT_MOC_LITERAL(50, 926, 17), // "setMotifFunctions"
QT_MOC_LITERAL(51, 944, 46), // "Dtk::Gui::DWindowManagerHelpe..."
QT_MOC_LITERAL(52, 991, 14), // "motifFunctions"
QT_MOC_LITERAL(53, 1006, 19), // "setMotifDecorations"
QT_MOC_LITERAL(54, 1026, 48), // "Dtk::Gui::DWindowManagerHelpe..."
QT_MOC_LITERAL(55, 1075, 16), // "motifDecorations"
QT_MOC_LITERAL(56, 1092, 21), // "popupSystemWindowMenu"
QT_MOC_LITERAL(57, 1114, 21), // "setWindowBlurAreaByWM"
QT_MOC_LITERAL(58, 1136, 36), // "QVector<DPlatformHandle::WMBl..."
QT_MOC_LITERAL(59, 1173, 4), // "area"
QT_MOC_LITERAL(60, 1178, 19), // "QList<QPainterPath>"
QT_MOC_LITERAL(61, 1198, 15), // "setClipPathByWM"
QT_MOC_LITERAL(62, 1214, 12), // "QPainterPath"
QT_MOC_LITERAL(63, 1227, 8), // "clipPath"
QT_MOC_LITERAL(64, 1236, 11), // "setClipPath"
QT_MOC_LITERAL(65, 1248, 11), // "QQuickPath*"
QT_MOC_LITERAL(66, 1260, 4), // "path"
QT_MOC_LITERAL(67, 1265, 16), // "setOverlayExited"
QT_MOC_LITERAL(68, 1282, 17), // "QQuickTransition*"
QT_MOC_LITERAL(69, 1300, 4), // "exit"
QT_MOC_LITERAL(70, 1305, 17), // "setLoadingOverlay"
QT_MOC_LITERAL(71, 1323, 14), // "QQmlComponent*"
QT_MOC_LITERAL(72, 1338, 9), // "component"
QT_MOC_LITERAL(73, 1348, 15), // "setWindowEffect"
QT_MOC_LITERAL(74, 1364, 39), // "Dtk::Gui::DPlatformHandle::Ef..."
QT_MOC_LITERAL(75, 1404, 6), // "effect"
QT_MOC_LITERAL(76, 1411, 22), // "setWindowStartUpEffect"
QT_MOC_LITERAL(77, 1434, 38), // "Dtk::Gui::DPlatformHandle::Ef..."
QT_MOC_LITERAL(78, 1473, 4), // "type"
QT_MOC_LITERAL(79, 1478, 13), // "showMinimized"
QT_MOC_LITERAL(80, 1492, 13), // "showMaximized"
QT_MOC_LITERAL(81, 1506, 14), // "showFullScreen"
QT_MOC_LITERAL(82, 1521, 10), // "showNormal"
QT_MOC_LITERAL(83, 1532, 28), // "_q_onWindowMotifHintsChanged"
QT_MOC_LITERAL(84, 1561, 26), // "_q_updateBlurAreaForWindow"
QT_MOC_LITERAL(85, 1588, 17), // "_q_updateClipPath"
QT_MOC_LITERAL(86, 1606, 23), // "_q_ensurePlatformHandle"
QT_MOC_LITERAL(87, 1630, 6), // "window"
QT_MOC_LITERAL(88, 1637, 13), // "QQuickWindow*"
QT_MOC_LITERAL(89, 1651, 7), // "enabled"
QT_MOC_LITERAL(90, 1659, 15), // "alphaBufferSize"
QT_MOC_LITERAL(91, 1675, 13), // "overlayExited"
QT_MOC_LITERAL(92, 1689, 14), // "loadingOverlay"
QT_MOC_LITERAL(93, 1704, 9), // "appLoader"
QT_MOC_LITERAL(94, 1714, 32), // "Dtk::Quick::DQuickAppLoaderItem*"
QT_MOC_LITERAL(95, 1747, 12), // "windowEffect"
QT_MOC_LITERAL(96, 1760, 38), // "Dtk::Gui::DPlatformHandle::Ef..."
QT_MOC_LITERAL(97, 1799, 19), // "windowStartUpEffect"
QT_MOC_LITERAL(98, 1819, 37) // "Dtk::Gui::DPlatformHandle::Ef..."

    },
    "Dtk::Quick::DQuickWindowAttached\0"
    "enabledChanged\0\0windowRadiusChanged\0"
    "borderWidthChanged\0borderColorChanged\0"
    "shadowRadiusChanged\0shadowOffsetChanged\0"
    "shadowColorChanged\0translucentBackgroundChanged\0"
    "enableSystemResizeChanged\0"
    "enableSystemMoveChanged\0enableBlurWindowChanged\0"
    "wmWindowTypesChanged\0motifFunctionsChanged\0"
    "motifDecorationsChanged\0alphaBufferSizeChanged\0"
    "clipPathChanged\0overlayExitedChanged\0"
    "loadingOverlayChanged\0appLoaderChanged\0"
    "windowEffectChanged\0windowStartUpEffectChanged\0"
    "setEnabled\0e\0setWindowRadius\0windowRadius\0"
    "setBorderWidth\0borderWidth\0setBorderColor\0"
    "borderColor\0setShadowRadius\0shadowRadius\0"
    "setShadowOffset\0shadowOffset\0"
    "setShadowColor\0shadowColor\0"
    "setTranslucentBackground\0translucentBackground\0"
    "setEnableSystemResize\0enableSystemResize\0"
    "setEnableSystemMove\0enableSystemMove\0"
    "setEnableBlurWindow\0enableBlurWindow\0"
    "setAlphaBufferSize\0size\0setWmWindowTypes\0"
    "Dtk::Gui::DWindowManagerHelper::WmWindowTypes\0"
    "wmWindowTypes\0setMotifFunctions\0"
    "Dtk::Gui::DWindowManagerHelper::MotifFunctions\0"
    "motifFunctions\0setMotifDecorations\0"
    "Dtk::Gui::DWindowManagerHelper::MotifDecorations\0"
    "motifDecorations\0popupSystemWindowMenu\0"
    "setWindowBlurAreaByWM\0"
    "QVector<DPlatformHandle::WMBlurArea>\0"
    "area\0QList<QPainterPath>\0setClipPathByWM\0"
    "QPainterPath\0clipPath\0setClipPath\0"
    "QQuickPath*\0path\0setOverlayExited\0"
    "QQuickTransition*\0exit\0setLoadingOverlay\0"
    "QQmlComponent*\0component\0setWindowEffect\0"
    "Dtk::Gui::DPlatformHandle::EffectScenes\0"
    "effect\0setWindowStartUpEffect\0"
    "Dtk::Gui::DPlatformHandle::EffectTypes\0"
    "type\0showMinimized\0showMaximized\0"
    "showFullScreen\0showNormal\0"
    "_q_onWindowMotifHintsChanged\0"
    "_q_updateBlurAreaForWindow\0_q_updateClipPath\0"
    "_q_ensurePlatformHandle\0window\0"
    "QQuickWindow*\0enabled\0alphaBufferSize\0"
    "overlayExited\0loadingOverlay\0appLoader\0"
    "Dtk::Quick::DQuickAppLoaderItem*\0"
    "windowEffect\0Dtk::Gui::DPlatformHandle::EffectScene\0"
    "windowStartUpEffect\0"
    "Dtk::Gui::DPlatformHandle::EffectType"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickWindowAttached[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      53,   14, // methods
      22,  380, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      21,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  279,    2, 0x06 /* Public */,
       3,    0,  280,    2, 0x06 /* Public */,
       4,    0,  281,    2, 0x06 /* Public */,
       5,    0,  282,    2, 0x06 /* Public */,
       6,    0,  283,    2, 0x06 /* Public */,
       7,    0,  284,    2, 0x06 /* Public */,
       8,    0,  285,    2, 0x06 /* Public */,
       9,    0,  286,    2, 0x06 /* Public */,
      10,    0,  287,    2, 0x06 /* Public */,
      11,    0,  288,    2, 0x06 /* Public */,
      12,    0,  289,    2, 0x06 /* Public */,
      13,    0,  290,    2, 0x06 /* Public */,
      14,    0,  291,    2, 0x06 /* Public */,
      15,    0,  292,    2, 0x06 /* Public */,
      16,    0,  293,    2, 0x06 /* Public */,
      17,    0,  294,    2, 0x06 /* Public */,
      18,    0,  295,    2, 0x06 /* Public */,
      19,    0,  296,    2, 0x06 /* Public */,
      20,    0,  297,    2, 0x06 /* Public */,
      21,    0,  298,    2, 0x06 /* Public */,
      22,    0,  299,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      23,    1,  300,    2, 0x0a /* Public */,
      25,    1,  303,    2, 0x0a /* Public */,
      27,    1,  306,    2, 0x0a /* Public */,
      29,    1,  309,    2, 0x0a /* Public */,
      31,    1,  312,    2, 0x0a /* Public */,
      33,    1,  315,    2, 0x0a /* Public */,
      35,    1,  318,    2, 0x0a /* Public */,
      37,    1,  321,    2, 0x0a /* Public */,
      39,    1,  324,    2, 0x0a /* Public */,
      41,    1,  327,    2, 0x0a /* Public */,
      43,    1,  330,    2, 0x0a /* Public */,
      45,    1,  333,    2, 0x0a /* Public */,
      47,    1,  336,    2, 0x0a /* Public */,
      50,    1,  339,    2, 0x0a /* Public */,
      53,    1,  342,    2, 0x0a /* Public */,
      56,    0,  345,    2, 0x0a /* Public */,
      57,    1,  346,    2, 0x0a /* Public */,
      57,    1,  349,    2, 0x0a /* Public */,
      61,    1,  352,    2, 0x0a /* Public */,
      64,    1,  355,    2, 0x0a /* Public */,
      67,    1,  358,    2, 0x0a /* Public */,
      70,    1,  361,    2, 0x0a /* Public */,
      73,    1,  364,    2, 0x0a /* Public */,
      76,    1,  367,    2, 0x0a /* Public */,
      79,    0,  370,    2, 0x0a /* Public */,
      80,    0,  371,    2, 0x0a /* Public */,
      81,    0,  372,    2, 0x0a /* Public */,
      82,    0,  373,    2, 0x0a /* Public */,
      83,    1,  374,    2, 0x08 /* Private */,
      84,    0,  377,    2, 0x08 /* Private */,
      85,    0,  378,    2, 0x08 /* Private */,
      86,    0,  379,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   24,
    QMetaType::Void, QMetaType::Int,   26,
    QMetaType::Void, QMetaType::Int,   28,
    QMetaType::Void, QMetaType::QColor,   30,
    QMetaType::Void, QMetaType::Int,   32,
    QMetaType::Void, QMetaType::QPoint,   34,
    QMetaType::Void, QMetaType::QColor,   36,
    QMetaType::Void, QMetaType::Bool,   38,
    QMetaType::Void, QMetaType::Bool,   40,
    QMetaType::Void, QMetaType::Bool,   42,
    QMetaType::Void, QMetaType::Bool,   44,
    QMetaType::Void, QMetaType::Int,   46,
    QMetaType::Void, 0x80000000 | 48,   49,
    QMetaType::Void, 0x80000000 | 51,   52,
    QMetaType::Void, 0x80000000 | 54,   55,
    QMetaType::Void,
    QMetaType::Bool, 0x80000000 | 58,   59,
    QMetaType::Bool, 0x80000000 | 60,   59,
    QMetaType::Void, 0x80000000 | 62,   63,
    QMetaType::Void, 0x80000000 | 65,   66,
    QMetaType::Void, 0x80000000 | 68,   69,
    QMetaType::Void, 0x80000000 | 71,   72,
    QMetaType::Void, 0x80000000 | 74,   75,
    QMetaType::Void, 0x80000000 | 77,   78,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      87, 0x80000000 | 88, 0x00095409,
      89, QMetaType::Bool, 0x00495103,
      26, QMetaType::Int, 0x00495103,
      28, QMetaType::Int, 0x00495103,
      30, QMetaType::QColor, 0x00495103,
      32, QMetaType::Int, 0x00495103,
      34, QMetaType::QPoint, 0x00495103,
      36, QMetaType::QColor, 0x00495103,
      38, QMetaType::Bool, 0x00495103,
      40, QMetaType::Bool, 0x00495103,
      42, QMetaType::Bool, 0x00495103,
      44, QMetaType::Bool, 0x00495103,
      90, QMetaType::Int, 0x00495103,
      63, 0x80000000 | 65, 0x0049510b,
      49, 0x80000000 | 48, 0x0049510b,
      52, 0x80000000 | 51, 0x0049510b,
      55, 0x80000000 | 54, 0x0049510b,
      91, 0x80000000 | 68, 0x0049590b,
      92, 0x80000000 | 71, 0x0049590b,
      93, 0x80000000 | 94, 0x00495009,
      95, 0x80000000 | 96, 0x0049510b,
      97, 0x80000000 | 98, 0x0049510b,

 // properties: notify_signal_id
       0,
       0,
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       8,
       9,
      10,
      14,
      15,
      11,
      12,
      13,
      16,
      17,
      18,
      19,
      20,

       0        // eod
};

void Dtk::Quick::DQuickWindowAttached::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DQuickWindowAttached *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->windowRadiusChanged(); break;
        case 2: _t->borderWidthChanged(); break;
        case 3: _t->borderColorChanged(); break;
        case 4: _t->shadowRadiusChanged(); break;
        case 5: _t->shadowOffsetChanged(); break;
        case 6: _t->shadowColorChanged(); break;
        case 7: _t->translucentBackgroundChanged(); break;
        case 8: _t->enableSystemResizeChanged(); break;
        case 9: _t->enableSystemMoveChanged(); break;
        case 10: _t->enableBlurWindowChanged(); break;
        case 11: _t->wmWindowTypesChanged(); break;
        case 12: _t->motifFunctionsChanged(); break;
        case 13: _t->motifDecorationsChanged(); break;
        case 14: _t->alphaBufferSizeChanged(); break;
        case 15: _t->clipPathChanged(); break;
        case 16: _t->overlayExitedChanged(); break;
        case 17: _t->loadingOverlayChanged(); break;
        case 18: _t->appLoaderChanged(); break;
        case 19: _t->windowEffectChanged(); break;
        case 20: _t->windowStartUpEffectChanged(); break;
        case 21: _t->setEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: _t->setWindowRadius((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->setBorderWidth((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: _t->setBorderColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 25: _t->setShadowRadius((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 26: _t->setShadowOffset((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 27: _t->setShadowColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 28: _t->setTranslucentBackground((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 29: _t->setEnableSystemResize((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 30: _t->setEnableSystemMove((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 31: _t->setEnableBlurWindow((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 32: _t->setAlphaBufferSize((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 33: _t->setWmWindowTypes((*reinterpret_cast< Dtk::Gui::DWindowManagerHelper::WmWindowTypes(*)>(_a[1]))); break;
        case 34: _t->setMotifFunctions((*reinterpret_cast< Dtk::Gui::DWindowManagerHelper::MotifFunctions(*)>(_a[1]))); break;
        case 35: _t->setMotifDecorations((*reinterpret_cast< Dtk::Gui::DWindowManagerHelper::MotifDecorations(*)>(_a[1]))); break;
        case 36: _t->popupSystemWindowMenu(); break;
        case 37: { bool _r = _t->setWindowBlurAreaByWM((*reinterpret_cast< const QVector<DPlatformHandle::WMBlurArea>(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->setWindowBlurAreaByWM((*reinterpret_cast< const QList<QPainterPath>(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 39: _t->setClipPathByWM((*reinterpret_cast< const QPainterPath(*)>(_a[1]))); break;
        case 40: _t->setClipPath((*reinterpret_cast< QQuickPath*(*)>(_a[1]))); break;
        case 41: _t->setOverlayExited((*reinterpret_cast< QQuickTransition*(*)>(_a[1]))); break;
        case 42: _t->setLoadingOverlay((*reinterpret_cast< QQmlComponent*(*)>(_a[1]))); break;
        case 43: _t->setWindowEffect((*reinterpret_cast< Dtk::Gui::DPlatformHandle::EffectScenes(*)>(_a[1]))); break;
        case 44: _t->setWindowStartUpEffect((*reinterpret_cast< Dtk::Gui::DPlatformHandle::EffectTypes(*)>(_a[1]))); break;
        case 45: _t->showMinimized(); break;
        case 46: _t->showMaximized(); break;
        case 47: _t->showFullScreen(); break;
        case 48: _t->showNormal(); break;
        case 49: _t->d_func()->_q_onWindowMotifHintsChanged((*reinterpret_cast< quint32(*)>(_a[1]))); break;
        case 50: _t->d_func()->_q_updateBlurAreaForWindow(); break;
        case 51: _t->d_func()->_q_updateClipPath(); break;
        case 52: _t->d_func()->_q_ensurePlatformHandle(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QPainterPath> >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QPainterPath >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::enabledChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::windowRadiusChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::borderWidthChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::borderColorChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::shadowRadiusChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::shadowOffsetChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::shadowColorChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::translucentBackgroundChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::enableSystemResizeChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::enableSystemMoveChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::enableBlurWindowChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::wmWindowTypesChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::motifFunctionsChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::motifDecorationsChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::alphaBufferSizeChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::clipPathChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::overlayExitedChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::loadingOverlayChanged)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::appLoaderChanged)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::windowEffectChanged)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (DQuickWindowAttached::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickWindowAttached::windowStartUpEffectChanged)) {
                *result = 20;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickWindow* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DQuickWindowAttached *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QQuickWindow**>(_v) = _t->window(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isEnabled(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->windowRadius(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->borderWidth(); break;
        case 4: *reinterpret_cast< QColor*>(_v) = _t->borderColor(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->shadowRadius(); break;
        case 6: *reinterpret_cast< QPoint*>(_v) = _t->shadowOffset(); break;
        case 7: *reinterpret_cast< QColor*>(_v) = _t->shadowColor(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->translucentBackground(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->enableSystemResize(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->enableSystemMove(); break;
        case 11: *reinterpret_cast< bool*>(_v) = _t->enableBlurWindow(); break;
        case 12: *reinterpret_cast< int*>(_v) = _t->alphaBufferSize(); break;
        case 13: *reinterpret_cast< QQuickPath**>(_v) = _t->clipPath(); break;
        case 14: *reinterpret_cast< Dtk::Gui::DWindowManagerHelper::WmWindowTypes*>(_v) = _t->wmWindowTypes(); break;
        case 15: *reinterpret_cast< Dtk::Gui::DWindowManagerHelper::MotifFunctions*>(_v) = _t->motifFunctions(); break;
        case 16: *reinterpret_cast< Dtk::Gui::DWindowManagerHelper::MotifDecorations*>(_v) = _t->motifDecorations(); break;
        case 17: *reinterpret_cast< QQuickTransition**>(_v) = _t->overlayExited(); break;
        case 18: *reinterpret_cast< QQmlComponent**>(_v) = _t->loadingOverlay(); break;
        case 19: *reinterpret_cast< Dtk::Quick::DQuickAppLoaderItem**>(_v) = _t->appLoader(); break;
        case 20: *reinterpret_cast< Dtk::Gui::DPlatformHandle::EffectScene*>(_v) = _t->windowEffect(); break;
        case 21: *reinterpret_cast< Dtk::Gui::DPlatformHandle::EffectType*>(_v) = _t->windowStartUpEffect(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DQuickWindowAttached *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setWindowRadius(*reinterpret_cast< int*>(_v)); break;
        case 3: _t->setBorderWidth(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setBorderColor(*reinterpret_cast< QColor*>(_v)); break;
        case 5: _t->setShadowRadius(*reinterpret_cast< int*>(_v)); break;
        case 6: _t->setShadowOffset(*reinterpret_cast< QPoint*>(_v)); break;
        case 7: _t->setShadowColor(*reinterpret_cast< QColor*>(_v)); break;
        case 8: _t->setTranslucentBackground(*reinterpret_cast< bool*>(_v)); break;
        case 9: _t->setEnableSystemResize(*reinterpret_cast< bool*>(_v)); break;
        case 10: _t->setEnableSystemMove(*reinterpret_cast< bool*>(_v)); break;
        case 11: _t->setEnableBlurWindow(*reinterpret_cast< bool*>(_v)); break;
        case 12: _t->setAlphaBufferSize(*reinterpret_cast< int*>(_v)); break;
        case 13: _t->setClipPath(*reinterpret_cast< QQuickPath**>(_v)); break;
        case 14: _t->setWmWindowTypes(*reinterpret_cast< Dtk::Gui::DWindowManagerHelper::WmWindowTypes*>(_v)); break;
        case 15: _t->setMotifFunctions(*reinterpret_cast< Dtk::Gui::DWindowManagerHelper::MotifFunctions*>(_v)); break;
        case 16: _t->setMotifDecorations(*reinterpret_cast< Dtk::Gui::DWindowManagerHelper::MotifDecorations*>(_v)); break;
        case 17: _t->setOverlayExited(*reinterpret_cast< QQuickTransition**>(_v)); break;
        case 18: _t->setLoadingOverlay(*reinterpret_cast< QQmlComponent**>(_v)); break;
        case 20: _t->setWindowEffect(*reinterpret_cast< Dtk::Gui::DPlatformHandle::EffectScene*>(_v)); break;
        case 21: _t->setWindowStartUpEffect(*reinterpret_cast< Dtk::Gui::DPlatformHandle::EffectType*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_Dtk__Quick__DQuickWindowAttached[] = {
    QMetaObject::SuperData::link<Dtk::Gui::DWindowManagerHelper::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Gui::DPlatformHandle::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickWindowAttached::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DQuickWindowAttached.data,
    qt_meta_data_Dtk__Quick__DQuickWindowAttached,
    qt_static_metacall,
    qt_meta_extradata_Dtk__Quick__DQuickWindowAttached,
    nullptr
} };


const QMetaObject *Dtk::Quick::DQuickWindowAttached::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickWindowAttached::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DQuickWindowAttached.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DQuickWindowAttached::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 53)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 53;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 53)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 53;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 22;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 22;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 22;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 22;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 22;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickWindowAttached::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickWindowAttached::windowRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickWindowAttached::borderWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickWindowAttached::borderColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickWindowAttached::shadowRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickWindowAttached::shadowOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQuickWindowAttached::shadowColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Quick::DQuickWindowAttached::translucentBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Quick::DQuickWindowAttached::enableSystemResizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Dtk::Quick::DQuickWindowAttached::enableSystemMoveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Dtk::Quick::DQuickWindowAttached::enableBlurWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Dtk::Quick::DQuickWindowAttached::wmWindowTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Dtk::Quick::DQuickWindowAttached::motifFunctionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Dtk::Quick::DQuickWindowAttached::motifDecorationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Dtk::Quick::DQuickWindowAttached::alphaBufferSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Dtk::Quick::DQuickWindowAttached::clipPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Dtk::Quick::DQuickWindowAttached::overlayExitedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Dtk::Quick::DQuickWindowAttached::loadingOverlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Dtk::Quick::DQuickWindowAttached::appLoaderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Dtk::Quick::DQuickWindowAttached::windowEffectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Dtk::Quick::DQuickWindowAttached::windowStartUpEffectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
