/****************************************************************************
** Meta object code from reading C++ file 'dquickcontrolpalette_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/private/dquickcontrolpalette_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickcontrolpalette_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick18DQuickControlColorE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickControlColor::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick18DQuickControlColorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickControlColor",
        "QML.Element",
        "anonymous",
        "common",
        "Dtk::Quick::DColor",
        "crystal"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'common'
        QtMocHelpers::PropertyData<Dtk::Quick::DColor>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
        // property 'crystal'
        QtMocHelpers::PropertyData<Dtk::Quick::DColor>(5, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DQuickControlColor, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickControlColor::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickControlColorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickControlColorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick18DQuickControlColorE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickControlColor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<DQuickControlColor *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Dtk::Quick::DColor >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Dtk::Quick::DColor*>(_v) = _t->common(); break;
        case 1: *reinterpret_cast<Dtk::Quick::DColor*>(_v) = _t->crystal(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCommon(*reinterpret_cast<Dtk::Quick::DColor*>(_v)); break;
        case 1: _t->setCrystal(*reinterpret_cast<Dtk::Quick::DColor*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN3Dtk5Quick20DQuickControlPaletteE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickControlPalette::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick20DQuickControlPaletteE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickControlPalette",
        "QML.Element",
        "Palette",
        "enabledChanged",
        "",
        "normalChanged",
        "normalDarkChanged",
        "hoveredChanged",
        "hoveredDarkChanged",
        "pressedChanged",
        "pressedDarkChanged",
        "disabledChanged",
        "disabledDarkChanged",
        "changed",
        "enabled",
        "normal",
        "Dtk::Quick::DQuickControlColor",
        "normalDark",
        "hovered",
        "hoveredDark",
        "pressed",
        "pressedDark",
        "disabled",
        "disabledDark",
        "ColorFamily",
        "CommonColor",
        "CrystalColor",
        "ColorFamilyCount"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'normalChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'normalDarkChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoveredChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoveredDarkChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressedChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressedDarkChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disabledChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disabledDarkChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'normal'
        QtMocHelpers::PropertyData<Dtk::Quick::DQuickControlColor>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'normalDark'
        QtMocHelpers::PropertyData<Dtk::Quick::DQuickControlColor>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'hovered'
        QtMocHelpers::PropertyData<Dtk::Quick::DQuickControlColor>(18, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'hoveredDark'
        QtMocHelpers::PropertyData<Dtk::Quick::DQuickControlColor>(19, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'pressed'
        QtMocHelpers::PropertyData<Dtk::Quick::DQuickControlColor>(20, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'pressedDark'
        QtMocHelpers::PropertyData<Dtk::Quick::DQuickControlColor>(21, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'disabled'
        QtMocHelpers::PropertyData<Dtk::Quick::DQuickControlColor>(22, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'disabledDark'
        QtMocHelpers::PropertyData<Dtk::Quick::DQuickControlColor>(23, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ColorFamily'
        QtMocHelpers::EnumData<enum ColorFamily>(24, 24, QMC::EnumFlags{}).add({
            {   25, ColorFamily::CommonColor },
            {   26, ColorFamily::CrystalColor },
            {   27, ColorFamily::ColorFamilyCount },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DQuickControlPalette, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickControlPalette::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick20DQuickControlPaletteE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick20DQuickControlPaletteE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick20DQuickControlPaletteE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickControlPalette::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickControlPalette *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->normalChanged(); break;
        case 2: _t->normalDarkChanged(); break;
        case 3: _t->hoveredChanged(); break;
        case 4: _t->hoveredDarkChanged(); break;
        case 5: _t->pressedChanged(); break;
        case 6: _t->pressedDarkChanged(); break;
        case 7: _t->disabledChanged(); break;
        case 8: _t->disabledDarkChanged(); break;
        case 9: _t->changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQuickControlPalette::*)()>(_a, &DQuickControlPalette::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlPalette::*)()>(_a, &DQuickControlPalette::normalChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlPalette::*)()>(_a, &DQuickControlPalette::normalDarkChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlPalette::*)()>(_a, &DQuickControlPalette::hoveredChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlPalette::*)()>(_a, &DQuickControlPalette::hoveredDarkChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlPalette::*)()>(_a, &DQuickControlPalette::pressedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlPalette::*)()>(_a, &DQuickControlPalette::pressedDarkChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlPalette::*)()>(_a, &DQuickControlPalette::disabledChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlPalette::*)()>(_a, &DQuickControlPalette::disabledDarkChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlPalette::*)()>(_a, &DQuickControlPalette::changed, 9))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
        case 7:
        case 6:
        case 5:
        case 4:
        case 3:
        case 2:
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Dtk::Quick::DQuickControlColor >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 1: *reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v) = _t->normal(); break;
        case 2: *reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v) = _t->normalDark(); break;
        case 3: *reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v) = _t->hovered(); break;
        case 4: *reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v) = _t->hoveredDark(); break;
        case 5: *reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v) = _t->pressed(); break;
        case 6: *reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v) = _t->pressedDark(); break;
        case 7: *reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v) = _t->disabled(); break;
        case 8: *reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v) = _t->disabledDark(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setNormal(*reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 2: _t->setNormalDark(*reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 3: _t->setHovered(*reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 4: _t->setHoveredDark(*reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 5: _t->setPressed(*reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 6: _t->setPressedDark(*reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 7: _t->setDisabled(*reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v)); break;
        case 8: _t->setDisabledDark(*reinterpret_cast<Dtk::Quick::DQuickControlColor*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::DQuickControlPalette::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickControlPalette::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick20DQuickControlPaletteE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DQuickControlPalette::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickControlPalette::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickControlPalette::normalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickControlPalette::normalDarkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickControlPalette::hoveredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickControlPalette::hoveredDarkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickControlPalette::pressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQuickControlPalette::pressedDarkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Quick::DQuickControlPalette::disabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Quick::DQuickControlPalette::disabledDarkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Dtk::Quick::DQuickControlPalette::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
namespace {
struct qt_meta_tag_ZN3Dtk5Quick26DQuickControlColorSelectorE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickControlColorSelector::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick26DQuickControlColorSelectorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickControlColorSelector",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "ColorSelector is only available as an attached property.",
        "QML.Element",
        "ColorSelector",
        "QML.Attached",
        "DQuickControlColorSelector",
        "DefaultProperty",
        "palettes",
        "controlThemeChanged",
        "",
        "controlStateChanged",
        "controlChanged",
        "hoveredChanged",
        "pressedChanged",
        "disabledChanged",
        "inactivedChanged",
        "colorPropertyChanged",
        "name",
        "colorPropertiesChanged",
        "familyChanged",
        "updateControlTheme",
        "updateControlState",
        "updateAllColorProperties",
        "recvPaletteColorChanged",
        "onPaletteDestroyed",
        "updateControlWindow",
        "resolveMetaPropertyChanged",
        "notifyColorPropertyChanged",
        "control",
        "QQuickItem*",
        "controlTheme",
        "Dtk::Gui::DGuiApplicationHelper::ColorType",
        "controlState",
        "Dtk::Quick::DQMLGlobalObject::ControlState",
        "family",
        "Dtk::Quick::DQuickControlPalette::ColorFamily",
        "hovered",
        "pressed",
        "disabled",
        "inactived"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'controlThemeChanged'
        QtMocHelpers::SignalData<void()>(11, 12, QMC::AccessPublic, QMetaType::Void),
        // Signal 'controlStateChanged'
        QtMocHelpers::SignalData<void()>(13, 12, QMC::AccessPublic, QMetaType::Void),
        // Signal 'controlChanged'
        QtMocHelpers::SignalData<void()>(14, 12, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoveredChanged'
        QtMocHelpers::SignalData<void()>(15, 12, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressedChanged'
        QtMocHelpers::SignalData<void()>(16, 12, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disabledChanged'
        QtMocHelpers::SignalData<void()>(17, 12, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inactivedChanged'
        QtMocHelpers::SignalData<void()>(18, 12, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorPropertyChanged'
        QtMocHelpers::SignalData<void(const QByteArray &)>(19, 12, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 20 },
        }}),
        // Signal 'colorPropertiesChanged'
        QtMocHelpers::SignalData<void()>(21, 12, QMC::AccessPublic, QMetaType::Void),
        // Signal 'familyChanged'
        QtMocHelpers::SignalData<void()>(22, 12, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateControlTheme'
        QtMocHelpers::SlotData<void()>(23, 12, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateControlState'
        QtMocHelpers::SlotData<bool()>(24, 12, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'updateAllColorProperties'
        QtMocHelpers::SlotData<void()>(25, 12, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'recvPaletteColorChanged'
        QtMocHelpers::SlotData<void()>(26, 12, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPaletteDestroyed'
        QtMocHelpers::SlotData<void()>(27, 12, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateControlWindow'
        QtMocHelpers::SlotData<void()>(28, 12, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resolveMetaPropertyChanged'
        QtMocHelpers::SlotData<void()>(29, 12, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'notifyColorPropertyChanged'
        QtMocHelpers::SlotData<void()>(30, 12, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'control'
        QtMocHelpers::PropertyData<QQuickItem*>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'controlTheme'
        QtMocHelpers::PropertyData<Dtk::Gui::DGuiApplicationHelper::ColorType>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'controlState'
        QtMocHelpers::PropertyData<Dtk::Quick::DQMLGlobalObject::ControlState>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'family'
        QtMocHelpers::PropertyData<Dtk::Quick::DQuickControlPalette::ColorFamily>(37, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'hovered'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 3),
        // property 'pressed'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 4),
        // property 'disabled'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 5),
        // property 'inactived'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
    });
    return QtMocHelpers::metaObjectData<DQuickControlColorSelector, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3Dtk5Quick26DQuickControlColorSelectorE[] = {
    QMetaObject::SuperData::link<Dtk::Gui::DGuiApplicationHelper::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Quick::DQMLGlobalObject::staticMetaObject>(),
    QMetaObject::SuperData::link<Dtk::Quick::DQuickControlPalette::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickControlColorSelector::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick26DQuickControlColorSelectorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick26DQuickControlColorSelectorE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3Dtk5Quick26DQuickControlColorSelectorE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick26DQuickControlColorSelectorE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickControlColorSelector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickControlColorSelector *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->controlThemeChanged(); break;
        case 1: _t->controlStateChanged(); break;
        case 2: _t->controlChanged(); break;
        case 3: _t->hoveredChanged(); break;
        case 4: _t->pressedChanged(); break;
        case 5: _t->disabledChanged(); break;
        case 6: _t->inactivedChanged(); break;
        case 7: _t->colorPropertyChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 8: _t->colorPropertiesChanged(); break;
        case 9: _t->familyChanged(); break;
        case 10: _t->updateControlTheme(); break;
        case 11: { bool _r = _t->updateControlState();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->updateAllColorProperties(); break;
        case 13: _t->recvPaletteColorChanged(); break;
        case 14: _t->onPaletteDestroyed(); break;
        case 15: _t->updateControlWindow(); break;
        case 16: _t->resolveMetaPropertyChanged(); break;
        case 17: _t->notifyColorPropertyChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQuickControlColorSelector::*)()>(_a, &DQuickControlColorSelector::controlThemeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlColorSelector::*)()>(_a, &DQuickControlColorSelector::controlStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlColorSelector::*)()>(_a, &DQuickControlColorSelector::controlChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlColorSelector::*)()>(_a, &DQuickControlColorSelector::hoveredChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlColorSelector::*)()>(_a, &DQuickControlColorSelector::pressedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlColorSelector::*)()>(_a, &DQuickControlColorSelector::disabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlColorSelector::*)()>(_a, &DQuickControlColorSelector::inactivedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlColorSelector::*)(const QByteArray & )>(_a, &DQuickControlColorSelector::colorPropertyChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlColorSelector::*)()>(_a, &DQuickControlColorSelector::colorPropertiesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickControlColorSelector::*)()>(_a, &DQuickControlColorSelector::familyChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->control(); break;
        case 1: *reinterpret_cast<Dtk::Gui::DGuiApplicationHelper::ColorType*>(_v) = _t->controlTheme(); break;
        case 2: *reinterpret_cast<Dtk::Quick::DQMLGlobalObject::ControlState*>(_v) = _t->controlState(); break;
        case 3: *reinterpret_cast<Dtk::Quick::DQuickControlPalette::ColorFamily*>(_v) = _t->family(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hovered(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->pressed(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->disabled(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->inactived(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setFamily(*reinterpret_cast<Dtk::Quick::DQuickControlPalette::ColorFamily*>(_v)); break;
        case 4: _t->setHovered(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setPressed(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setDisabled(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setInactived(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 3: _t->resetFamily(); break;
        case 4: _t->resetHovered(); break;
        case 5: _t->resetPressed(); break;
        case 6: _t->resetDisabled(); break;
        case 7: _t->resetInactived(); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::DQuickControlColorSelector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickControlColorSelector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick26DQuickControlColorSelectorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::DQuickControlColorSelector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickControlColorSelector::controlThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickControlColorSelector::controlStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickControlColorSelector::controlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickControlColorSelector::hoveredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickControlColorSelector::pressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickControlColorSelector::disabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQuickControlColorSelector::inactivedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Quick::DQuickControlColorSelector::colorPropertyChanged(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Dtk::Quick::DQuickControlColorSelector::colorPropertiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Dtk::Quick::DQuickControlColorSelector::familyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
