#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>

namespace QmlCacheGeneratedCode {
namespace _dtk_declarative_qml_IpV4LineEdit_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_private_KeySequenceLabel_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_KeySequenceEdit_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_settings_LineEdit_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_DialogButtonBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_SearchEdit_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Slider_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_SpinBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_EditPanel_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_GroupBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_SliderTipItem_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_RoundButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_settings_NavigationTitle_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ActionGroup_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_private_ColorOverlay_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_StyledBehindWindowBlur_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_CicleSpreadAnimation_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ComboBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ApplicationWindow_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_PasswordEdit_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_FloatingPanel_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_IconButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ButtonPanel_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_AbstractButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_PlusMinusSpinBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ThemeMenu_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Button_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_CheckDelegate_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ScrollView_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_StyledArrowShapeWindow_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_DelayButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_settings_SettingsDialog_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Menu_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_MenuItem_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_private_ProgressBarPanel_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ControlBackground_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_WindowButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_PopupWindow_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_settings_CheckBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_settings_ContentTitle_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_RecommandButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_LineEdit_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_AboutAction_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ButtonBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ButtonGroup_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_settings_OptionDelegate_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ScrollBar_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_AboutDialog_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_private_ArrowListViewButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_WindowButtonGroup_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Switch_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_PageIndicator_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_AlertToolTip_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_MenuSeparator_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_private_SoftwareOpacityMask_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_RadioButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_WarningButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ToolTip_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_BusyIndicator_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_TitleBar_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_TabBar_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_DialogWindow_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_QuitAction_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_FocusBoxBorder_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_SwipeView_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_OutsideBoxBorder_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_BoxInsetShadow_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_settings_ContentBackground_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_CheckBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_private_OpacityMask_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ItemDelegate_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_EmbeddedProgressBar_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_DialogTitleBar_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_HelpAction_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Action_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_MenuBar_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_PlaceholderText_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_HighlightPanel_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ScrollIndicator_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ArrowShapePopupWindow_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_BoxPanel_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_TipsSlider_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Dialog_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ArrowListView_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Drawer_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_BoxShadow_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_TextArea_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_FloatingButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Control_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_StackView_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_InsideBoxBorder_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Container_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Frame_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_SliderHandle_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_SwipeDelegate_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ButtonIndicator_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ArrowShapePopup_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_WaterProgressBar_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ActionButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_FlowStyle_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_FloatingMessage_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_SpinBoxIndicator_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_TextField_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_RectangularShadow_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Label_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_settings_ComboBox_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Pane_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_private_ProgressBarImpl_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_private_SoftwareColorOverlay_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Popup_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ProgressBar_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_SortFilterModel_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_Dial_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_style_Style_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}
namespace _dtk_declarative_qml_ToolButton_qml { 
    extern const unsigned char qmlData[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), nullptr, nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/IpV4LineEdit.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_IpV4LineEdit_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/private/KeySequenceLabel.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_private_KeySequenceLabel_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/KeySequenceEdit.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_KeySequenceEdit_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/settings/LineEdit.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_settings_LineEdit_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/DialogButtonBox.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_DialogButtonBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/SearchEdit.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_SearchEdit_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Slider.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Slider_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/SpinBox.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_SpinBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/EditPanel.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_EditPanel_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/GroupBox.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_GroupBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/SliderTipItem.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_SliderTipItem_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/RoundButton.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_RoundButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/settings/NavigationTitle.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_settings_NavigationTitle_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ActionGroup.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ActionGroup_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/private/ColorOverlay.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_private_ColorOverlay_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/StyledBehindWindowBlur.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_StyledBehindWindowBlur_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/CicleSpreadAnimation.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_CicleSpreadAnimation_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ComboBox.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ComboBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ApplicationWindow.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ApplicationWindow_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/PasswordEdit.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_PasswordEdit_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/FloatingPanel.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_FloatingPanel_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/IconButton.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_IconButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ButtonPanel.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ButtonPanel_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/AbstractButton.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_AbstractButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/PlusMinusSpinBox.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_PlusMinusSpinBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ThemeMenu.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ThemeMenu_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Button.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Button_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/CheckDelegate.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_CheckDelegate_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ScrollView.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ScrollView_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/StyledArrowShapeWindow.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_StyledArrowShapeWindow_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/DelayButton.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_DelayButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/settings/SettingsDialog.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_settings_SettingsDialog_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Menu.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Menu_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/MenuItem.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_MenuItem_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/private/ProgressBarPanel.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_private_ProgressBarPanel_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ControlBackground.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ControlBackground_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/WindowButton.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_WindowButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/PopupWindow.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_PopupWindow_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/settings/CheckBox.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_settings_CheckBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/settings/ContentTitle.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_settings_ContentTitle_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/RecommandButton.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_RecommandButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/LineEdit.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_LineEdit_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/AboutAction.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_AboutAction_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ButtonBox.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ButtonBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ButtonGroup.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ButtonGroup_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/settings/OptionDelegate.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_settings_OptionDelegate_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ScrollBar.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ScrollBar_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/AboutDialog.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_AboutDialog_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/private/ArrowListViewButton.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_private_ArrowListViewButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/WindowButtonGroup.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_WindowButtonGroup_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Switch.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Switch_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/PageIndicator.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_PageIndicator_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/AlertToolTip.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_AlertToolTip_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/MenuSeparator.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_MenuSeparator_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/private/SoftwareOpacityMask.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_private_SoftwareOpacityMask_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/RadioButton.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_RadioButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/WarningButton.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_WarningButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ToolTip.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ToolTip_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/BusyIndicator.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_BusyIndicator_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/TitleBar.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_TitleBar_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/TabBar.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_TabBar_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/DialogWindow.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_DialogWindow_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/QuitAction.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_QuitAction_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/FocusBoxBorder.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_FocusBoxBorder_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/SwipeView.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_SwipeView_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/OutsideBoxBorder.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_OutsideBoxBorder_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/BoxInsetShadow.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_BoxInsetShadow_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/settings/ContentBackground.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_settings_ContentBackground_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/CheckBox.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_CheckBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/private/OpacityMask.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_private_OpacityMask_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ItemDelegate.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ItemDelegate_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/EmbeddedProgressBar.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_EmbeddedProgressBar_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/DialogTitleBar.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_DialogTitleBar_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/HelpAction.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_HelpAction_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Action.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Action_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/MenuBar.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_MenuBar_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/PlaceholderText.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_PlaceholderText_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/HighlightPanel.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_HighlightPanel_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ScrollIndicator.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ScrollIndicator_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ArrowShapePopupWindow.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ArrowShapePopupWindow_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/BoxPanel.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_BoxPanel_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/TipsSlider.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_TipsSlider_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Dialog.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Dialog_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ArrowListView.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ArrowListView_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Drawer.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Drawer_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/BoxShadow.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_BoxShadow_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/TextArea.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_TextArea_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/FloatingButton.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_FloatingButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Control.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Control_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/StackView.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_StackView_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/InsideBoxBorder.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_InsideBoxBorder_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Container.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Container_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Frame.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Frame_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/SliderHandle.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_SliderHandle_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/SwipeDelegate.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_SwipeDelegate_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ButtonIndicator.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ButtonIndicator_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ArrowShapePopup.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ArrowShapePopup_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/WaterProgressBar.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_WaterProgressBar_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ActionButton.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ActionButton_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/FlowStyle.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_FlowStyle_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/FloatingMessage.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_FloatingMessage_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/SpinBoxIndicator.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_SpinBoxIndicator_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/TextField.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_TextField_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/RectangularShadow.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_RectangularShadow_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Label.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Label_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/settings/ComboBox.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_settings_ComboBox_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Pane.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Pane_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/private/ProgressBarImpl.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_private_ProgressBarImpl_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/private/SoftwareColorOverlay.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_private_SoftwareColorOverlay_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Popup.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Popup_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ProgressBar.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ProgressBar_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/SortFilterModel.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_SortFilterModel_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/Dial.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_Dial_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/style/Style.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_style_Style_qml::unit);
        resourcePathToCachedUnit.insert(QStringLiteral("/dtk/declarative/qml/ToolButton.qml"), &QmlCacheGeneratedCode::_dtk_declarative_qml_ToolButton_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.version = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_dtkdeclarative_qml)() {
    ::unitRegistry();
    Q_INIT_RESOURCE(dtkdeclarative_qml_qmlcache);
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_dtkdeclarative_qml))
int QT_MANGLE_NAMESPACE(qCleanupResources_dtkdeclarative_qml)() {
    Q_CLEANUP_RESOURCE(dtkdeclarative_qml_qmlcache);
    return 1;
}
