/****************************************************************************
** Meta object code from reading C++ file 'dsettingscontainer_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/private/dsettingscontainer_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dsettingscontainer_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__SettingsOption_t {
    QByteArrayData data[14];
    char stringdata0[171];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__SettingsOption_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__SettingsOption_t qt_meta_stringdata_Dtk__Quick__SettingsOption = {
    {
QT_MOC_LITERAL(0, 0, 26), // "Dtk::Quick::SettingsOption"
QT_MOC_LITERAL(1, 27, 15), // "DefaultProperty"
QT_MOC_LITERAL(2, 43, 8), // "delegate"
QT_MOC_LITERAL(3, 52, 10), // "keyChanged"
QT_MOC_LITERAL(4, 63, 0), // ""
QT_MOC_LITERAL(5, 64, 3), // "key"
QT_MOC_LITERAL(6, 68, 11), // "nameChanged"
QT_MOC_LITERAL(7, 80, 4), // "name"
QT_MOC_LITERAL(8, 85, 12), // "valueChanged"
QT_MOC_LITERAL(9, 98, 5), // "value"
QT_MOC_LITERAL(10, 104, 15), // "delegateChanged"
QT_MOC_LITERAL(11, 120, 20), // "onConfigValueChanged"
QT_MOC_LITERAL(12, 141, 14), // "onValueChanged"
QT_MOC_LITERAL(13, 156, 14) // "QQmlComponent*"

    },
    "Dtk::Quick::SettingsOption\0DefaultProperty\0"
    "delegate\0keyChanged\0\0key\0nameChanged\0"
    "name\0valueChanged\0value\0delegateChanged\0"
    "onConfigValueChanged\0onValueChanged\0"
    "QQmlComponent*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__SettingsOption[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
       6,   16, // methods
       4,   62, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    1,   46,    4, 0x06 /* Public */,
       6,    1,   49,    4, 0x06 /* Public */,
       8,    1,   52,    4, 0x06 /* Public */,
      10,    0,   55,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,   56,    4, 0x08 /* Private */,
      12,    2,   57,    4, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QVariant,    9,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,    5,    9,

 // properties: name, type, flags
       5, QMetaType::QString, 0x00495103,
       7, QMetaType::QString, 0x00495103,
       9, QMetaType::QVariant, 0x00495107,
       2, 0x80000000 | 13, 0x0049510b,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,

       0        // eod
};

void Dtk::Quick::SettingsOption::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SettingsOption *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->keyChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 1: _t->nameChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: _t->valueChanged((*reinterpret_cast< QVariant(*)>(_a[1]))); break;
        case 3: _t->delegateChanged(); break;
        case 4: _t->onConfigValueChanged(); break;
        case 5: _t->onValueChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SettingsOption::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsOption::keyChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (SettingsOption::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsOption::nameChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (SettingsOption::*)(QVariant );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsOption::valueChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (SettingsOption::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsOption::delegateChanged)) {
                *result = 3;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<SettingsOption *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->key(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast< QVariant*>(_v) = _t->value(); break;
        case 3: *reinterpret_cast< QQmlComponent**>(_v) = _t->delegate(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<SettingsOption *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setKey(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setName(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setValue(*reinterpret_cast< QVariant*>(_v)); break;
        case 3: _t->setDelegate(*reinterpret_cast< QQmlComponent**>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
        SettingsOption *_t = static_cast<SettingsOption *>(_o);
        (void)_t;
        switch (_id) {
        case 2: _t->resetValue(); break;
        default: break;
        }
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::SettingsOption::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__SettingsOption.data,
    qt_meta_data_Dtk__Quick__SettingsOption,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::SettingsOption::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::SettingsOption::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__SettingsOption.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::SettingsOption::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::SettingsOption::keyChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dtk::Quick::SettingsOption::nameChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Dtk::Quick::SettingsOption::valueChanged(QVariant _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dtk::Quick::SettingsOption::delegateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
struct qt_meta_stringdata_Dtk__Quick__SettingsGroup_t {
    QByteArrayData data[21];
    char stringdata0[304];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__SettingsGroup_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__SettingsGroup_t qt_meta_stringdata_Dtk__Quick__SettingsGroup = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Dtk::Quick::SettingsGroup"
QT_MOC_LITERAL(1, 26, 15), // "DefaultProperty"
QT_MOC_LITERAL(2, 42, 7), // "options"
QT_MOC_LITERAL(3, 50, 10), // "keyChanged"
QT_MOC_LITERAL(4, 61, 0), // ""
QT_MOC_LITERAL(5, 62, 3), // "key"
QT_MOC_LITERAL(6, 66, 11), // "nameChanged"
QT_MOC_LITERAL(7, 78, 4), // "name"
QT_MOC_LITERAL(8, 83, 14), // "visibleChanged"
QT_MOC_LITERAL(9, 98, 7), // "visible"
QT_MOC_LITERAL(10, 106, 14), // "optionsChanged"
QT_MOC_LITERAL(11, 121, 15), // "childrenChanged"
QT_MOC_LITERAL(12, 137, 17), // "backgroundChanged"
QT_MOC_LITERAL(13, 155, 12), // "indexChanged"
QT_MOC_LITERAL(14, 168, 5), // "index"
QT_MOC_LITERAL(15, 174, 5), // "level"
QT_MOC_LITERAL(16, 180, 44), // "QQmlListProperty<Dtk::Quick::..."
QT_MOC_LITERAL(17, 225, 8), // "children"
QT_MOC_LITERAL(18, 234, 43), // "QQmlListProperty<Dtk::Quick::..."
QT_MOC_LITERAL(19, 278, 10), // "background"
QT_MOC_LITERAL(20, 289, 14) // "QQmlComponent*"

    },
    "Dtk::Quick::SettingsGroup\0DefaultProperty\0"
    "options\0keyChanged\0\0key\0nameChanged\0"
    "name\0visibleChanged\0visible\0optionsChanged\0"
    "childrenChanged\0backgroundChanged\0"
    "indexChanged\0index\0level\0"
    "QQmlListProperty<Dtk::Quick::SettingsOption>\0"
    "children\0QQmlListProperty<Dtk::Quick::SettingsGroup>\0"
    "background\0QQmlComponent*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__SettingsGroup[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
       7,   16, // methods
       8,   66, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    1,   51,    4, 0x06 /* Public */,
       6,    1,   54,    4, 0x06 /* Public */,
       8,    1,   57,    4, 0x06 /* Public */,
      10,    0,   60,    4, 0x06 /* Public */,
      11,    0,   61,    4, 0x06 /* Public */,
      12,    0,   62,    4, 0x06 /* Public */,
      13,    1,   63,    4, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   14,

 // properties: name, type, flags
       5, QMetaType::QString, 0x00495103,
       7, QMetaType::QString, 0x00495103,
      15, QMetaType::Int, 0x00095401,
       9, QMetaType::Bool, 0x00495103,
      14, QMetaType::Int, 0x00495001,
       2, 0x80000000 | 16, 0x00495009,
      17, 0x80000000 | 18, 0x00495009,
      19, 0x80000000 | 20, 0x0049510b,

 // properties: notify_signal_id
       0,
       1,
       0,
       2,
       6,
       3,
       4,
       5,

       0        // eod
};

void Dtk::Quick::SettingsGroup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SettingsGroup *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->keyChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 1: _t->nameChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: _t->visibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->optionsChanged(); break;
        case 4: _t->childrenChanged(); break;
        case 5: _t->backgroundChanged(); break;
        case 6: _t->indexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SettingsGroup::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsGroup::keyChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (SettingsGroup::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsGroup::nameChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (SettingsGroup::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsGroup::visibleChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (SettingsGroup::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsGroup::optionsChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (SettingsGroup::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsGroup::childrenChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (SettingsGroup::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsGroup::backgroundChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (SettingsGroup::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsGroup::indexChanged)) {
                *result = 6;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<SettingsGroup *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->key(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->level(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->visible(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->index(); break;
        case 5: *reinterpret_cast< QQmlListProperty<Dtk::Quick::SettingsOption>*>(_v) = _t->options(); break;
        case 6: *reinterpret_cast< QQmlListProperty<Dtk::Quick::SettingsGroup>*>(_v) = _t->children(); break;
        case 7: *reinterpret_cast< QQmlComponent**>(_v) = _t->background(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<SettingsGroup *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setKey(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setName(*reinterpret_cast< QString*>(_v)); break;
        case 3: _t->setVisible(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setBackground(*reinterpret_cast< QQmlComponent**>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::SettingsGroup::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__SettingsGroup.data,
    qt_meta_data_Dtk__Quick__SettingsGroup,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::SettingsGroup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::SettingsGroup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__SettingsGroup.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::SettingsGroup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::SettingsGroup::keyChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dtk::Quick::SettingsGroup::nameChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Dtk::Quick::SettingsGroup::visibleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dtk::Quick::SettingsGroup::optionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::SettingsGroup::childrenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::SettingsGroup::backgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::SettingsGroup::indexChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
struct qt_meta_stringdata_Dtk__Quick__SettingsInstanceModel_t {
    QByteArrayData data[1];
    char stringdata0[34];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__SettingsInstanceModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__SettingsInstanceModel_t qt_meta_stringdata_Dtk__Quick__SettingsInstanceModel = {
    {
QT_MOC_LITERAL(0, 0, 33) // "Dtk::Quick::SettingsInstanceM..."

    },
    "Dtk::Quick::SettingsInstanceModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__SettingsInstanceModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Dtk::Quick::SettingsInstanceModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::SettingsInstanceModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QQmlInstanceModel::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__SettingsInstanceModel.data,
    qt_meta_data_Dtk__Quick__SettingsInstanceModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::SettingsInstanceModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::SettingsInstanceModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__SettingsInstanceModel.stringdata0))
        return static_cast<void*>(this);
    return QQmlInstanceModel::qt_metacast(_clname);
}

int Dtk::Quick::SettingsInstanceModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQmlInstanceModel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Dtk__Quick__SettingsContentModel_t {
    QByteArrayData data[1];
    char stringdata0[33];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__SettingsContentModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__SettingsContentModel_t qt_meta_stringdata_Dtk__Quick__SettingsContentModel = {
    {
QT_MOC_LITERAL(0, 0, 32) // "Dtk::Quick::SettingsContentModel"

    },
    "Dtk::Quick::SettingsContentModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__SettingsContentModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Dtk::Quick::SettingsContentModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::SettingsContentModel::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingsInstanceModel::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__SettingsContentModel.data,
    qt_meta_data_Dtk__Quick__SettingsContentModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::SettingsContentModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::SettingsContentModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__SettingsContentModel.stringdata0))
        return static_cast<void*>(this);
    return SettingsInstanceModel::qt_metacast(_clname);
}

int Dtk::Quick::SettingsContentModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingsInstanceModel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Dtk__Quick__SettingsNavigationModel_t {
    QByteArrayData data[1];
    char stringdata0[36];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__SettingsNavigationModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__SettingsNavigationModel_t qt_meta_stringdata_Dtk__Quick__SettingsNavigationModel = {
    {
QT_MOC_LITERAL(0, 0, 35) // "Dtk::Quick::SettingsNavigatio..."

    },
    "Dtk::Quick::SettingsNavigationModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__SettingsNavigationModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Dtk::Quick::SettingsNavigationModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::SettingsNavigationModel::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingsInstanceModel::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__SettingsNavigationModel.data,
    qt_meta_data_Dtk__Quick__SettingsNavigationModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::SettingsNavigationModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::SettingsNavigationModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__SettingsNavigationModel.stringdata0))
        return static_cast<void*>(this);
    return SettingsInstanceModel::qt_metacast(_clname);
}

int Dtk::Quick::SettingsNavigationModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingsInstanceModel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Dtk__Quick__SettingsContainer_t {
    QByteArrayData data[27];
    char stringdata0[459];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__SettingsContainer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__SettingsContainer_t qt_meta_stringdata_Dtk__Quick__SettingsContainer = {
    {
QT_MOC_LITERAL(0, 0, 29), // "Dtk::Quick::SettingsContainer"
QT_MOC_LITERAL(1, 30, 15), // "DefaultProperty"
QT_MOC_LITERAL(2, 46, 6), // "groups"
QT_MOC_LITERAL(3, 53, 13), // "groupsChanged"
QT_MOC_LITERAL(4, 67, 0), // ""
QT_MOC_LITERAL(5, 68, 22), // "navigationTitleChanged"
QT_MOC_LITERAL(6, 91, 19), // "contentTitleChanged"
QT_MOC_LITERAL(7, 111, 19), // "contentModelChanged"
QT_MOC_LITERAL(8, 131, 22), // "navigationModelChanged"
QT_MOC_LITERAL(9, 154, 13), // "configChanged"
QT_MOC_LITERAL(10, 168, 24), // "contentBackgroundChanged"
QT_MOC_LITERAL(11, 193, 15), // "setGroupVisible"
QT_MOC_LITERAL(12, 209, 3), // "key"
QT_MOC_LITERAL(13, 213, 7), // "visible"
QT_MOC_LITERAL(14, 221, 12), // "groupVisible"
QT_MOC_LITERAL(15, 234, 13), // "resetSettings"
QT_MOC_LITERAL(16, 248, 21), // "onGroupVisibleChanged"
QT_MOC_LITERAL(17, 270, 6), // "config"
QT_MOC_LITERAL(18, 277, 43), // "QQmlListProperty<Dtk::Quick::..."
QT_MOC_LITERAL(19, 321, 12), // "contentModel"
QT_MOC_LITERAL(20, 334, 21), // "SettingsContentModel*"
QT_MOC_LITERAL(21, 356, 12), // "contentTitle"
QT_MOC_LITERAL(22, 369, 14), // "QQmlComponent*"
QT_MOC_LITERAL(23, 384, 17), // "contentBackground"
QT_MOC_LITERAL(24, 402, 15), // "navigationModel"
QT_MOC_LITERAL(25, 418, 24), // "SettingsNavigationModel*"
QT_MOC_LITERAL(26, 443, 15) // "navigationTitle"

    },
    "Dtk::Quick::SettingsContainer\0"
    "DefaultProperty\0groups\0groupsChanged\0"
    "\0navigationTitleChanged\0contentTitleChanged\0"
    "contentModelChanged\0navigationModelChanged\0"
    "configChanged\0contentBackgroundChanged\0"
    "setGroupVisible\0key\0visible\0groupVisible\0"
    "resetSettings\0onGroupVisibleChanged\0"
    "config\0QQmlListProperty<Dtk::Quick::SettingsGroup>\0"
    "contentModel\0SettingsContentModel*\0"
    "contentTitle\0QQmlComponent*\0"
    "contentBackground\0navigationModel\0"
    "SettingsNavigationModel*\0navigationTitle"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__SettingsContainer[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
      11,   16, // methods
       7,   90, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,   71,    4, 0x06 /* Public */,
       5,    0,   72,    4, 0x06 /* Public */,
       6,    0,   73,    4, 0x06 /* Public */,
       7,    0,   74,    4, 0x06 /* Public */,
       8,    0,   75,    4, 0x06 /* Public */,
       9,    0,   76,    4, 0x06 /* Public */,
      10,    0,   77,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    2,   78,    4, 0x0a /* Public */,
      14,    1,   83,    4, 0x0a /* Public */,
      15,    0,   86,    4, 0x0a /* Public */,
      16,    1,   87,    4, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   12,   13,
    QMetaType::Bool, QMetaType::QString,   12,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   13,

 // properties: name, type, flags
      17, QMetaType::QObjectStar, 0x00495103,
       2, 0x80000000 | 18, 0x00495009,
      19, 0x80000000 | 20, 0x00495009,
      21, 0x80000000 | 22, 0x0049510b,
      23, 0x80000000 | 22, 0x0049510b,
      24, 0x80000000 | 25, 0x00495009,
      26, 0x80000000 | 22, 0x0049510b,

 // properties: notify_signal_id
       5,
       0,
       3,
       2,
       6,
       4,
       1,

       0        // eod
};

void Dtk::Quick::SettingsContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SettingsContainer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->groupsChanged(); break;
        case 1: _t->navigationTitleChanged(); break;
        case 2: _t->contentTitleChanged(); break;
        case 3: _t->contentModelChanged(); break;
        case 4: _t->navigationModelChanged(); break;
        case 5: _t->configChanged(); break;
        case 6: _t->contentBackgroundChanged(); break;
        case 7: _t->setGroupVisible((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 8: { bool _r = _t->groupVisible((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->resetSettings(); break;
        case 10: _t->onGroupVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SettingsContainer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsContainer::groupsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (SettingsContainer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsContainer::navigationTitleChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (SettingsContainer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsContainer::contentTitleChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (SettingsContainer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsContainer::contentModelChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (SettingsContainer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsContainer::navigationModelChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (SettingsContainer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsContainer::configChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (SettingsContainer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SettingsContainer::contentBackgroundChanged)) {
                *result = 6;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
        case 4:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SettingsContentModel* >(); break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SettingsNavigationModel* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<SettingsContainer *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QObject**>(_v) = _t->config(); break;
        case 1: *reinterpret_cast< QQmlListProperty<Dtk::Quick::SettingsGroup>*>(_v) = _t->groups(); break;
        case 2: *reinterpret_cast< SettingsContentModel**>(_v) = _t->contentModel(); break;
        case 3: *reinterpret_cast< QQmlComponent**>(_v) = _t->contentTitle(); break;
        case 4: *reinterpret_cast< QQmlComponent**>(_v) = _t->contentBackground(); break;
        case 5: *reinterpret_cast< SettingsNavigationModel**>(_v) = _t->navigationModel(); break;
        case 6: *reinterpret_cast< QQmlComponent**>(_v) = _t->navigationTitle(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<SettingsContainer *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setConfig(*reinterpret_cast< QObject**>(_v)); break;
        case 3: _t->setContentTitle(*reinterpret_cast< QQmlComponent**>(_v)); break;
        case 4: _t->setContentBackground(*reinterpret_cast< QQmlComponent**>(_v)); break;
        case 6: _t->setNavigationTitle(*reinterpret_cast< QQmlComponent**>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::SettingsContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__SettingsContainer.data,
    qt_meta_data_Dtk__Quick__SettingsContainer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::SettingsContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::SettingsContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__SettingsContainer.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Quick::SettingsContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::SettingsContainer::groupsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::SettingsContainer::navigationTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::SettingsContainer::contentTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::SettingsContainer::contentModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::SettingsContainer::navigationModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::SettingsContainer::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::SettingsContainer::contentBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
