#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _0x5f_Chameleon_ApplicationWindow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_BusyIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_Button_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_CheckBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_CheckDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_ComboBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_Control_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_DelayButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_DialogButtonBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_Dial_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_Frame_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_GroupBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_ItemDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_ListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_MenuItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_Menu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_MenuSeparator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_PageIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_Pane_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_Popup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_ProgressBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_RadioButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_RoundButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_ScrollBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_ScrollView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_ScrollIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_Slider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_SpinBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_StackView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_Switch_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_TextArea_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_TextField_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Chameleon_ToolTip_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/ApplicationWindow.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_ApplicationWindow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/BusyIndicator.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_BusyIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/Button.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_Button_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/CheckBox.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_CheckBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/CheckDelegate.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_CheckDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/ComboBox.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_ComboBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/Control.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_Control_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/DelayButton.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_DelayButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/DialogButtonBox.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_DialogButtonBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/Dial.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_Dial_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/Frame.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_Frame_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/GroupBox.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_GroupBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/ItemDelegate.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_ItemDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/ListView.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_ListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/MenuItem.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_MenuItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/Menu.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_Menu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/MenuSeparator.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_MenuSeparator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/PageIndicator.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_PageIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/Pane.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_Pane_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/Popup.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_Popup_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/ProgressBar.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_ProgressBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/RadioButton.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_RadioButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/RoundButton.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_RoundButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/ScrollBar.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_ScrollBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/ScrollView.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_ScrollView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/ScrollIndicator.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_ScrollIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/Slider.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_Slider_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/SpinBox.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_SpinBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/StackView.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_StackView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/Switch.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_Switch_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/TextArea.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_TextArea_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/TextField.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_TextField_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Chameleon/ToolTip.qml"), &QmlCacheGeneratedCode::_0x5f_Chameleon_ToolTip_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_qtquickcontrolschameleonstyleplugin)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_qtquickcontrolschameleonstyleplugin))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_qtquickcontrolschameleonstyleplugin)() {
    return 1;
}
