/****************************************************************************
** Meta object code from reading C++ file 'dquickextendregister_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qt6/src/dquickextendregister_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickextendregister_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick26WindowManagerHelperForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::WindowManagerHelperForeign::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick26WindowManagerHelperForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::WindowManagerHelperForeign",
        "QML.Foreign",
        "DWindowManagerHelper",
        "QML.Singleton",
        "true",
        "QML.Element",
        "WindowManagerHelper"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<WindowManagerHelperForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::WindowManagerHelperForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick26WindowManagerHelperForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick26WindowManagerHelperForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick26WindowManagerHelperForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN3Dtk5Quick28DGuiApplicationHelperForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DGuiApplicationHelperForeign::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick28DGuiApplicationHelperForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DGuiApplicationHelperForeign",
        "QML.Foreign",
        "DGuiApplicationHelper",
        "QML.Singleton",
        "true",
        "QML.Element",
        "ApplicationHelper"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DGuiApplicationHelperForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::DGuiApplicationHelperForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick28DGuiApplicationHelperForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick28DGuiApplicationHelperForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick28DGuiApplicationHelperForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN3Dtk5Quick19DFontManagerForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DFontManagerForeign::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick19DFontManagerForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DFontManagerForeign",
        "QML.Foreign",
        "DFontManager",
        "QML.Element",
        "FontManager"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DFontManagerForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::DFontManagerForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick19DFontManagerForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick19DFontManagerForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick19DFontManagerForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN3Dtk5Quick22DPlatformHandleForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DPlatformHandleForeign::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick22DPlatformHandleForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DPlatformHandleForeign",
        "QML.Foreign",
        "DPlatformHandle",
        "QML.Element",
        "PlatformHandle",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    4 },
    });
    return QtMocHelpers::metaObjectData<DPlatformHandleForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::DPlatformHandleForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick22DPlatformHandleForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick22DPlatformHandleForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick22DPlatformHandleForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN3Dtk5Quick13DColorForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DColorForeign::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick13DColorForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DColorForeign",
        "QML.Element",
        "Color",
        "QML.Foreign",
        "DTK_QUICK_NAMESPACE::DColor",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN3Dtk5Quick13DColorForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN3Dtk5Quick13DColorForeignE =
    Dtk::Quick::DColorForeign::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick13DColorForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN3Dtk5Quick13DColorForeignE =
    qt_staticMetaObjectContent_ZN3Dtk5Quick13DColorForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN3Dtk5Quick13DColorForeignE =
    qt_staticMetaObjectContent_ZN3Dtk5Quick13DColorForeignE.relocatingData;

Q_CONSTINIT const QMetaObject Dtk::Quick::DColorForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN3Dtk5Quick13DColorForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN3Dtk5Quick13DColorForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN3Dtk5Quick13DColorForeignE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN3Dtk5Quick15DSysInfoForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DSysInfoForeign::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick15DSysInfoForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DSysInfoForeign",
        "QML.Element",
        "SysInfo",
        "QML.Foreign",
        "DTK_CORE_NAMESPACE::DSysInfo",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN3Dtk5Quick15DSysInfoForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN3Dtk5Quick15DSysInfoForeignE =
    Dtk::Quick::DSysInfoForeign::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick15DSysInfoForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN3Dtk5Quick15DSysInfoForeignE =
    qt_staticMetaObjectContent_ZN3Dtk5Quick15DSysInfoForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN3Dtk5Quick15DSysInfoForeignE =
    qt_staticMetaObjectContent_ZN3Dtk5Quick15DSysInfoForeignE.relocatingData;

Q_CONSTINIT const QMetaObject Dtk::Quick::DSysInfoForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN3Dtk5Quick15DSysInfoForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN3Dtk5Quick15DSysInfoForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN3Dtk5Quick15DSysInfoForeignE.metaTypes,
    nullptr
} };

QT_WARNING_POP
