/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<dsettingscontainer_p.h>)
#  include <dsettingscontainer_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_deepin_dtk_settings()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Dtk::Quick::SettingsContainer>("org.deepin.dtk.settings", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::SettingsGroup>("org.deepin.dtk.settings", 1);
    qmlRegisterTypesAndRevisions<Dtk::Quick::SettingsOption>("org.deepin.dtk.settings", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.deepin.dtk.settings", 1, 0);
}

static const QQmlModuleRegistration orgdeepindtksettingsRegistration("org.deepin.dtk.settings", qml_register_types_org_deepin_dtk_settings);
